diff --git a/changelog b/changelog
index 665492c..9cfc6cf 100644
--- a/changelog
+++ b/changelog
@@ -1,3 +1,6 @@
+20080125 tpd src/input/Makefile add En regression test 
+20080125 tpd src/input/en.input regression test En
+20080125 tpd src/algebra/special.spad add special function En 
 20080120 tpd src/input/Makefile add tbagg.input regression test (7102/412)
 20080120 tpd src/input/tbagg.input regression test equality in TBAGG (7102/412)
 20080120 mxr src/algebra/aggcat.spad fix equality in TBAGG (7102/412)
diff --git a/src/algebra/special.spad.pamphlet b/src/algebra/special.spad.pamphlet
index 0744b97..6b173ae 100644
--- a/src/algebra/special.spad.pamphlet
+++ b/src/algebra/special.spad.pamphlet
@@ -28,6 +28,7 @@
 
 DoubleFloatSpecialFunctions(): Exports == Impl where
     NNI ==> NonNegativeInteger
+    PI  ==> Integer
     R   ==> DoubleFloat
     C   ==> Complex DoubleFloat
     OPR ==> OnePointCompletion R
@@ -45,6 +46,9 @@ DoubleFloatSpecialFunctions(): Exports == Impl where
          ++ The current implementation is a piecewise approximation
          ++ involving one poly from -4..4 and a second poly for x > 4
 
+        En: (PI,R) -> OPR
+         ++ En(n,x) is the nth Exponential Integral Function
+
         Beta: (R, R) -> R
          ++ Beta(x, y) is the Euler beta function, \spad{B(x,y)}, defined by
          ++   \spad{Beta(x,y) = integrate(t^(x-1)*(1-t)^(y-1), t=0..1)}.
@@ -344,7 +348,7 @@ the Chebyshev polynomial for computing $E_1$. This agrees with the
 handbook values to almost the last published digit. See the {\tt e1.input}
 pamphlet for regression testing against the handbook tables.
 
-\subsection{E1:R$\rightarrow$R}
+\subsection{E1:R$\rightarrow$OPR}
 The special function E1 below was originally derived from a function
 written by T.Haavie as the {\tt expint.c} function in the Numlibc library
 by Lars Erik Lund. Haavie approximates the E1 function by two 
@@ -377,6 +381,10 @@ that take into account the scaling used by Haavie. I've also
 rewritten the polynomial using Horner's method so the large
 powers of $x$ are only computed once.
 
+The result can be either a double float or, or if the argument
+is zero, infinity. Thus we need to extend the result to be a
+one-point completion to include infinity.
+
 <<package DFSFUN DoubleFloatSpecialFunctions>>=
         E1(x:R):OPR ==
          x = 0.0::R => infinity()
@@ -481,6 +489,20 @@ powers of $x$ are only computed once.
           aw:R:=- 1.0::R*log(abs(x)) + av
           aw::OPR
          error "E1: no approximation available"
+@
+\subsection{En:(PI,R)$\rightarrow$OPR}
+The $E_n$ function is computed using the recurrence relation:
+$$E_{n+1}(z)=\frac{1}{n}\left(e^{-z}-zE_n(z)\right)\ \ \ (n=1,2,3,\ldots)$$
+
+The base case of the recursion depends on E1 above.
+
+The formula is 5.1.14 in Abramowitz and Stegun, 1965, p229\cite{4}.
+<<package DFSFUN DoubleFloatSpecialFunctions>>=
+        En(n:PI,x:R):OPR == 
+          n=1 => E1(x) 
+          v:R:=retract(En((n-1)::PI,x))
+          w:R:=1/(n-1)*(exp(-x)-x*v)
+          w::OPR
 
         polygamma(k,z)  == CPSI(k, z)$Lisp
         polygamma(k,x)  == RPSI(k, x)$Lisp
diff --git a/src/input/Makefile.pamphlet b/src/input/Makefile.pamphlet
index 65741f8..6cc1513 100644
--- a/src/input/Makefile.pamphlet
+++ b/src/input/Makefile.pamphlet
@@ -305,7 +305,8 @@ REGRES= algaggr.regress algbrbf.regress  algfacob.regress alist.regress  \
     dmp.regress       dpol.regress     e1.regress       easter.regress  \
     efi.regress \
     eigen.regress     elemfun.regress  elemnum.regress  elfuts.regress \
-    elt.regress       eq.regress       eqtbl.regress    equation2.regress \
+    elt.regress       en.regress \
+    eq.regress        eqtbl.regress    equation2.regress \
     equation.regress  evalex.regress   eval.regress     exdiff.regress \
     exint.regress     exit.regress     exlap.regress    exlimit.regress \
     exp.regress \
@@ -544,7 +545,7 @@ FILES= ${OUT}/algaggr.input  ${OUT}/algbrbf.input    ${OUT}/algfacob.input \
        ${OUT}/easter.input   ${OUT}/efi.input        ${OUT}/egg.input      \
        ${OUT}/eigen.input \
        ${OUT}/elemfun.input  ${OUT}/elemnum.input    ${OUT}/elfuts.input \
-       ${OUT}/elt.input \
+       ${OUT}/elt.input      ${OUT}/en.input \
        ${OUT}/eq.input       ${OUT}/eqtbl.input      ${OUT}/equation.input \
        ${OUT}/errortrap.input \
        ${OUT}/eval.input     ${OUT}/exit.input       ${OUT}/exp.input \
@@ -780,6 +781,7 @@ DOCFILES= \
   ${DOC}/egg.input.dvi         ${DOC}/eigen.input.dvi      \
   ${DOC}/elemfun.input.dvi     ${DOC}/elemnum.input.dvi    \
   ${DOC}/elfuts.input.dvi      ${DOC}/elt.input.dvi        \
+  ${DOC}/en.input.dvi \
   ${DOC}/eq.input.dvi          ${DOC}/eqtbl.input.dvi      \
   ${DOC}/equation2.input.dvi   ${DOC}/equation.input.dvi   \
   ${DOC}/errortrap.input.dvi   ${DOC}/evalex.input.dvi     \
diff --git a/src/input/en.input.pamphlet b/src/input/en.input.pamphlet
new file mode 100644
index 0000000..1ae9749
--- /dev/null
+++ b/src/input/en.input.pamphlet
@@ -0,0 +1,3805 @@
+\documentclass{article}
+\usepackage{axiom}
+\begin{document}
+\title{\$SPAD/src/input en.input}
+\author{Timothy Daly}
+\maketitle
+\begin{abstract}
+This compares Axiom's $E_n$ function with the tables published in
+Abramowitz and Stegun.
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+In the following table there are 4 columns. The first column
+is the argument of $E_n$, ranging from 0.01 to 2.00. The
+second column is the reference value of function from the book
+Abramowitz and Stegun, ``Handbook of Mathematical Functions'',
+Dover Publications, Inc. New York 1965. pp245-248
+
+<<*>>=
+)spool en.output
+)set message test on
+)set message auto off
+)clear all
+
+@
+This table expresses the value of 
+$E_2$ with an argument range of 0.01 to 0.50.
+The handbook tabulates these values using this function.
+<<*>>=
+--S 1 of 7
+f(x)==En(2,x)-x*log(x)
+--E 1
+
+--S 2 of 7
+[[0.01,0.9957222,f(0.01),f(0.01)-0.9957222],_
+[0.02,0.9913450,f(0.02),f(0.02)-0.9913450],_
+[0.03,0.9868687,f(0.03),f(0.03)-0.9868687],_
+[0.04,0.9822939,f(0.04),f(0.04)-0.9822939],_
+[0.05,0.9776211,f(0.05),f(0.05)-0.9776211],_
+[0.06,0.9728508,f(0.06),f(0.06)-0.9728508],_
+[0.07,0.9679834,f(0.07),f(0.07)-0.9679834],_
+[0.08,0.9630194,f(0.08),f(0.08)-0.9630194],_
+[0.09,0.9579593,f(0.09),f(0.09)-0.9579593],_
+[0.10,0.9528035,f(0.10),f(0.10)-0.9528035],_
+[0.11,0.9475526,f(0.11),f(0.11)-0.9475526],_
+[0.12,0.9422071,f(0.12),f(0.12)-0.9422071],_
+[0.13,0.9367672,f(0.13),f(0.13)-0.9367672],_
+[0.14,0.9312336,f(0.14),f(0.14)-0.9312336],_
+[0.15,0.9256067,f(0.15),f(0.15)-0.9256067],_
+[0.16,0.9198870,f(0.16),f(0.16)-0.9198870],_
+[0.17,0.9140748,f(0.17),f(0.17)-0.9140748],_
+[0.18,0.9081706,f(0.18),f(0.18)-0.9081706],_
+[0.19,0.9021750,f(0.19),f(0.19)-0.9021750],_
+[0.20,0.8960882,f(0.20),f(0.20)-0.8960882],_
+[0.21,0.8899109,f(0.21),f(0.21)-0.8899109],_
+[0.22,0.8836433,f(0.22),f(0.22)-0.8836433],_
+[0.23,0.8772860,f(0.23),f(0.23)-0.8772860],_
+[0.24,0.8708393,f(0.24),f(0.24)-0.8708393],_
+[0.25,0.8643037,f(0.25),f(0.25)-0.8643037],_
+[0.26,0.8576797,f(0.26),f(0.26)-0.8576797],_
+[0.27,0.8509676,f(0.27),f(0.27)-0.8509676],_
+[0.28,0.8441678,f(0.28),f(0.28)-0.8441678],_
+[0.29,0.8372808,f(0.29),f(0.29)-0.8372808],_
+[0.30,0.8303071,f(0.30),f(0.30)-0.8303071],_
+[0.31,0.8232469,f(0.31),f(0.31)-0.8232469],_
+[0.32,0.8161007,f(0.32),f(0.32)-0.8161007],_
+[0.33,0.8088690,f(0.33),f(0.33)-0.8088690],_
+[0.34,0.8015521,f(0.34),f(0.34)-0.8015521],_
+[0.35,0.7941504,f(0.35),f(0.35)-0.7941504],_
+[0.36,0.7866644,f(0.36),f(0.36)-0.7866644],_
+[0.37,0.7790943,f(0.37),f(0.37)-0.7790943],_
+[0.38,0.7714407,f(0.38),f(0.38)-0.7714407],_
+[0.39,0.7637039,f(0.39),f(0.39)-0.7637039],_
+[0.40,0.7558843,f(0.40),f(0.40)-0.7558843],_
+[0.41,0.7479823,f(0.41),f(0.41)-0.7479823],_
+[0.42,0.7399982,f(0.42),f(0.42)-0.7399982],_
+[0.43,0.7319324,f(0.43),f(0.43)-0.7319324],_
+[0.44,0.7237854,f(0.44),f(0.44)-0.7237854],_
+[0.45,0.7155575,f(0.45),f(0.45)-0.7155575],_
+[0.46,0.7072491,f(0.46),f(0.46)-0.7072491],_
+[0.47,0.6988605,f(0.47),f(0.47)-0.6988605],_
+[0.48,0.6903921,f(0.48),f(0.48)-0.6903921],_
+[0.49,0.6818443,f(0.49),f(0.49)-0.6818443],_
+[0.50,0.6732175,f(0.50),f(0.50)-0.6732175]]
+--R 
+--R   Compiling function f with type Float -> OnePointCompletion 
+--R      DoubleFloat 
+--R
+--R   (2)
+--R   [[1.0E-2,0.9957222,0.99572223984366792,3.9843667920536063E-8],
+--R    [2.0E-2,0.99134500000000003,0.991344977749124,- 2.2250876030582845E-8],
+--R
+--R     [2.9999999999999999E-2, 0.98686870000000004, 0.98686870874746913,
+--R      8.7474690824151935E-9]
+--R     ,
+--R
+--R     [4.0000000000000001E-2, 0.98229390000000005, 0.98229392458604003,
+--R      2.4586039981677743E-8]
+--R     ,
+--R
+--R     [5.0000000000000003E-2, 0.97762110000000002, 0.97762111375291483,
+--R      1.3752914806985927E-8]
+--R     ,
+--R
+--R     [5.9999999999999998E-2, 0.97285080000000002, 0.97285076150122396,
+--R      - 3.8498776055995165E-8]
+--R     ,
+--R
+--R     [7.0000000000000007E-2, 0.96798340000000005, 0.96798334987326684,
+--R      - 5.0126733208699648E-8]
+--R     ,
+--R
+--R     [8.0000000000000002E-2, 0.96301939999999997, 0.96301935772443681,
+--R      - 4.2275563161275898E-8]
+--R     ,
+--R
+--R     [8.9999999999999997E-2, 0.95795929999999996, 0.95795926074695703,
+--R      - 3.9253042927178683E-8]
+--R     ,
+--R
+--R     [0.10000000000000001, 0.95280350000000003, 0.95280353149342489,
+--R      3.149342486796769E-8]
+--R     ,
+--R    [0.11,0.94755259999999997,0.94755263940017342,3.9400173457160292E-8],
+--R    [0.12,0.94220709999999996,0.94220705081044254,- 4.9189557427276043E-8],
+--R    [0.13,0.93676720000000002,0.93676722899736986,2.8997369838634768E-8],
+--R
+--R     [0.14000000000000001, 0.93123359999999999, 0.93123363418679772,
+--R      3.4186797726043494E-8]
+--R     ,
+--R    [0.14999999999999999,0.9256067,0.92560672357989859,2.3579898589254356E-8],
+--R    [0.16,0.91988700000000001,0.91988695137562182,- 4.8624378190531559E-8],
+--R
+--R     [0.17000000000000001, 0.91407479999999997, 0.91407476879296246,
+--R      - 3.1207037509695112E-8]
+--R     ,
+--R
+--R     [0.17999999999999999, 0.90817060000000005, 0.90817062409305238,
+--R      2.4093052330975695E-8]
+--R     ,
+--R    [0.19,0.90217499999999995,0.90217496260107799,- 3.7398921959308495E-8],
+--R    [0.20000000000000001,0.8960882,0.89608822672802324,2.6728023239108722E-8],
+--R
+--R     [0.20999999999999999, 0.88991089999999995, 0.88991085599224007,
+--R      - 4.400775988067096E-8]
+--R     ,
+--R    [0.22,0.88364330000000002,0.88364328704084927,- 1.2959150752500648E-8],
+--R
+--R     [0.23000000000000001, 0.87728600000000001, 0.87728595367097117,
+--R      - 4.6329028835501163E-8]
+--R     ,
+--R
+--R     [0.23999999999999999, 0.87083929999999998, 0.8708392868507886,
+--R      - 1.3149211386398463E-8]
+--R     ,
+--R    [0.25,0.86430370000000001,0.86430371474044287,1.4740442866312264E-8],
+--R
+--R     [0.26000000000000001, 0.85767970000000004, 0.85767966271276586,
+--R      - 3.7287234189165019E-8]
+--R     ,
+--R
+--R     [0.27000000000000002, 0.85096760000000005, 0.85096755337384578,
+--R      - 4.6626154270867914E-8]
+--R     ,
+--R
+--R     [0.28000000000000003, 0.84416780000000002, 0.84416780658343327,
+--R      6.5834332430014797E-9]
+--R     ,
+--R
+--R     [0.28999999999999998, 0.83728080000000005, 0.8372808394751845,
+--R      3.9475184454573764E-8]
+--R     ,
+--R
+--R     [0.29999999999999999, 0.83030709999999996, 0.83030706647674468,
+--R      - 3.3523255282830178E-8]
+--R     ,
+--R    [0.31,0.8232469,0.82324689932967399,- 6.7032601691607852E-10],
+--R
+--R     [0.32000000000000001, 0.81610070000000001, 0.81610074710921554,
+--R      4.7109215528529091E-8]
+--R     ,
+--R
+--R     [0.33000000000000002, 0.80886899999999995, 0.80886901624390695,
+--R      1.6243906997281954E-8]
+--R     ,
+--R
+--R     [0.34000000000000002, 0.80155209999999999, 0.80155211053503872,
+--R      1.0535038730274948E-8]
+--R     ,
+--R
+--R     [0.34999999999999998, 0.79415040000000003, 0.79415043117595796,
+--R      3.1175957926343756E-8]
+--R     ,
+--R
+--R     [0.35999999999999999, 0.78666440000000004, 0.78666437677122092,
+--R      - 2.3228779122419496E-8]
+--R     ,
+--R    [0.37,0.77909430000000002,0.77909434335559369,4.3355593670746373E-8],
+--R    [0.38,0.77144069999999998,0.77144072441290445,2.4412904475745734E-8],
+--R
+--R     [0.39000000000000001, 0.76370389999999999, 0.76370391089474698,
+--R      1.089474699345061E-8]
+--R     ,
+--R
+--R     [0.40000000000000002, 0.75588429999999995, 0.75588429123903633,
+--R      - 8.7609636212349074E-9]
+--R     ,
+--R
+--R     [0.40999999999999998, 0.74798229999999999, 0.74798225138841923,
+--R      - 4.8611580760749007E-8]
+--R     ,
+--R
+--R     [0.41999999999999998, 0.73999820000000005, 0.73999817480853991,
+--R      - 2.5191460140128186E-8]
+--R     ,
+--R
+--R     [0.42999999999999999, 0.73193240000000004, 0.73193244250616207,
+--R      4.2506162034605666E-8]
+--R     ,
+--R    [0.44,0.72378540000000002,0.7237854330471486,3.3047148573217555E-8],
+--R
+--R     [0.45000000000000001, 0.71555749999999996, 0.71555752257429939,
+--R      2.2574299429756195E-8]
+--R     ,
+--R
+--R     [0.46000000000000002, 0.70724909999999996, 0.70724908482505056,
+--R      - 1.517494940816988E-8]
+--R     ,
+--R    [0.46999999999999997,0.6988605,0.6988604911490337,- 8.8509662932167998E-9],
+--R
+--R     [0.47999999999999998, 0.69039209999999995, 0.69039211052549776,
+--R      1.0525497806668227E-8]
+--R     ,
+--R
+--R     [0.48999999999999999, 0.68184429999999996, 0.68184430958059394,
+--R      9.5805939848148114E-9]
+--R     ,
+--R    [0.5,0.67321750000000002,0.67321745260452559,- 4.739547443399772E-8]]
+--R                               Type: List List OnePointCompletion DoubleFloat
+--E 2
+
+@
+This table expresses the value of 
+$E_2$ with an argument range of 0.50 to 2.00.
+<<*>>=
+--S 3 of 7
+[[0.50,0.3266439,En(2,0.50),En(2,0.50)-0.3266439],_
+[0.51,0.3211062,En(2,0.51),En(2,0.51)-0.3211062],_
+[0.52,0.3156863,En(2,0.52),En(2,0.52)-0.3156863],_
+[0.53,0.3103807,En(2,0.53),En(2,0.53)-0.3103807],_
+[0.54,0.3051862,En(2,0.54),En(2,0.54)-0.3051862],_
+[0.55,0.3000996,En(2,0.55),En(2,0.55)-0.3000996],_
+[0.56,0.2951179,En(2,0.56),En(2,0.56)-0.2951179],_
+[0.57,0.2902382,En(2,0.57),En(2,0.57)-0.2902382],_
+[0.58,0.2854578,En(2,0.58),En(2,0.58)-0.2854578],_
+[0.59,0.2807739,En(2,0.59),En(2,0.59)-0.2807739],_
+[0.60,0.2761839,En(2,0.60),En(2,0.60)-0.2761839],_
+[0.61,0.2716855,En(2,0.61),En(2,0.61)-0.2716855],_
+[0.62,0.2672761,En(2,0.62),En(2,0.62)-0.2672761],_
+[0.63,0.2629535,En(2,0.63),En(2,0.63)-0.2629535],_
+[0.64,0.2587154,En(2,0.64),En(2,0.64)-0.2587154],_
+[0.65,0.2545597,En(2,0.65),En(2,0.65)-0.2545597],_
+[0.66,0.2504844,En(2,0.66),En(2,0.66)-0.2504844],_
+[0.67,0.2464874,En(2,0.67),En(2,0.67)-0.2464874],_
+[0.68,0.2425667,En(2,0.68),En(2,0.68)-0.2425667],_
+[0.69,0.2387206,En(2,0.69),En(2,0.69)-0.2387206],_
+[0.70,0.2349471,En(2,0.70),En(2,0.70)-0.2349471],_
+[0.71,0.2312446,En(2,0.71),En(2,0.71)-0.2312446],_
+[0.72,0.2276114,En(2,0.72),En(2,0.72)-0.2276114],_
+[0.73,0.2240457,En(2,0.73),En(2,0.73)-0.2240457],_
+[0.74,0.2205461,En(2,0.74),En(2,0.74)-0.2205461],_
+[0.75,0.2171109,En(2,0.75),En(2,0.75)-0.2171109],_
+[0.76,0.2137388,En(2,0.76),En(2,0.76)-0.2137388],_
+[0.77,0.2104282,En(2,0.77),En(2,0.77)-0.2104282],_
+[0.78,0.2071777,En(2,0.78),En(2,0.78)-0.2071777],_
+[0.79,0.2039860,En(2,0.79),En(2,0.79)-0.2039860],_
+[0.80,0.2008517,En(2,0.80),En(2,0.80)-0.2008517],_
+[0.81,0.1977736,En(2,0.81),En(2,0.81)-0.1977736],_
+[0.82,0.1947504,En(2,0.82),En(2,0.82)-0.1947504],_
+[0.83,0.1917810,En(2,0.83),En(2,0.83)-0.1917810],_
+[0.84,0.1888641,En(2,0.84),En(2,0.84)-0.1888641],_
+[0.85,0.1859986,En(2,0.85),En(2,0.85)-0.1859986],_
+[0.86,0.1831833,En(2,0.86),En(2,0.86)-0.1831833],_
+[0.87,0.1804173,En(2,0.87),En(2,0.87)-0.1804173],_
+[0.88,0.1776994,En(2,0.88),En(2,0.88)-0.1776994],_
+[0.89,0.1750287,En(2,0.89),En(2,0.89)-0.1750287],_
+[0.90,0.1724041,En(2,0.90),En(2,0.90)-0.1724041],_
+[0.91,0.1698247,En(2,0.91),En(2,0.91)-0.1698247],_
+[0.92,0.1672895,En(2,0.92),En(2,0.92)-0.1672895],_
+[0.93,0.1647977,En(2,0.93),En(2,0.93)-0.1647977],_
+[0.94,0.1623482,En(2,0.94),En(2,0.94)-0.1623482],_
+[0.95,0.1599404,En(2,0.95),En(2,0.95)-0.1599404],_
+[0.96,0.1575732,En(2,0.96),En(2,0.96)-0.1575732],_
+[0.97,0.1552459,En(2,0.97),En(2,0.97)-0.1552459],_
+[0.98,0.1529578,En(2,0.98),En(2,0.98)-0.1529578],_
+[0.99,0.1507079,En(2,0.99),En(2,0.99)-0.1507079],_
+[1.00,0.1484955,En(2,1.00),En(2,1.00)-0.1484955],_
+[1.01,0.1463199,En(2,1.01),En(2,1.01)-0.1463199],_
+[1.02,0.1441804,En(2,1.02),En(2,1.02)-0.1441804],_
+[1.03,0.1420763,En(2,1.03),En(2,1.03)-0.1420763],_
+[1.04,0.1400068,En(2,1.04),En(2,1.04)-0.1400068],_
+[1.05,0.1379713,En(2,1.05),En(2,1.05)-0.1379713],_
+[1.06,0.1359691,En(2,1.06),En(2,1.06)-0.1359691],_
+[1.07,0.1339996,En(2,1.07),En(2,1.07)-0.1339996],_
+[1.08,0.1320622,En(2,1.08),En(2,1.08)-0.1320622],_
+[1.09,0.1301562,En(2,1.09),En(2,1.09)-0.1301562],_
+[1.10,0.1282811,En(2,1.10),En(2,1.10)-0.1282811],_
+[1.11,0.1264362,En(2,1.11),En(2,1.11)-0.1264362],_
+[1.12,0.1246210,En(2,1.12),En(2,1.12)-0.1246210],_
+[1.13,0.1228350,En(2,1.13),En(2,1.13)-0.1228350],_
+[1.14,0.1210775,En(2,1.14),En(2,1.14)-0.1210775],_
+[1.15,0.1193481,En(2,1.15),En(2,1.15)-0.1193481],_
+[1.16,0.1176462,En(2,1.16),En(2,1.16)-0.1176462],_
+[1.17,0.1159714,En(2,1.17),En(2,1.17)-0.1159714],_
+[1.18,0.1143231,En(2,1.18),En(2,1.18)-0.1143231],_
+[1.19,0.1127008,En(2,1.19),En(2,1.19)-0.1127008],_
+[1.20,0.1111041,En(2,1.20),En(2,1.20)-0.1111041],_
+[1.21,0.1095325,En(2,1.21),En(2,1.21)-0.1095325],_
+[1.22,0.1079855,En(2,1.22),En(2,1.22)-0.1079855],_
+[1.23,0.1064627,En(2,1.23),En(2,1.23)-0.1064627],_
+[1.24,0.1049637,En(2,1.24),En(2,1.24)-0.1049637],_
+[1.25,0.1034881,En(2,1.25),En(2,1.25)-0.1034881],_
+[1.26,0.1020353,En(2,1.26),En(2,1.26)-0.1020353],_
+[1.27,0.1006051,En(2,1.27),En(2,1.27)-0.1006051],_
+[1.28,0.0991970,En(2,1.28),En(2,1.28)-0.0991970],_
+[1.29,0.0978106,En(2,1.29),En(2,1.29)-0.0978106],_
+[1.30,0.0964455,En(2,1.30),En(2,1.30)-0.0964455],_
+[1.31,0.0951015,En(2,1.31),En(2,1.31)-0.0951015],_
+[1.32,0.0937780,En(2,1.32),En(2,1.32)-0.0937780],_
+[1.33,0.0924747,En(2,1.33),En(2,1.33)-0.0924747],_
+[1.34,0.0911913,En(2,1.34),En(2,1.34)-0.0911913],_
+[1.35,0.0899275,En(2,1.35),En(2,1.35)-0.0899275],_
+[1.36,0.0886829,En(2,1.36),En(2,1.36)-0.0886829],_
+[1.37,0.0874571,En(2,1.37),En(2,1.37)-0.0874571],_
+[1.38,0.0862499,En(2,1.38),En(2,1.38)-0.0862499],_
+[1.39,0.0850610,En(2,1.39),En(2,1.39)-0.0850610],_
+[1.40,0.0838899,En(2,1.40),En(2,1.40)-0.0838899],_
+[1.41,0.0827365,En(2,1.41),En(2,1.41)-0.0827365],_
+[1.42,0.0816004,En(2,1.42),En(2,1.42)-0.0816004],_
+[1.43,0.0804813,En(2,1.43),En(2,1.43)-0.0804813],_
+[1.44,0.0793789,En(2,1.44),En(2,1.44)-0.0793789],_
+[1.45,0.0782930,En(2,1.45),En(2,1.45)-0.0782930],_
+[1.46,0.0772233,En(2,1.46),En(2,1.46)-0.0772233],_
+[1.47,0.0761694,En(2,1.47),En(2,1.47)-0.0761694],_
+[1.48,0.0751313,En(2,1.48),En(2,1.48)-0.0751313],_
+[1.49,0.0741085,En(2,1.49),En(2,1.49)-0.0741085],_
+[1.50,0.0731008,En(2,1.50),En(2,1.50)-0.0731008],_
+[1.51,0.0721080,En(2,1.51),En(2,1.51)-0.0721080],_
+[1.52,0.0711298,En(2,1.52),En(2,1.52)-0.0711298],_
+[1.53,0.0701660,En(2,1.53),En(2,1.53)-0.0701660],_
+[1.54,0.0692164,En(2,1.54),En(2,1.54)-0.0692164],_
+[1.55,0.0682807,En(2,1.55),En(2,1.55)-0.0682807],_
+[1.56,0.0673587,En(2,1.56),En(2,1.56)-0.0673587],_
+[1.57,0.0664502,En(2,1.57),En(2,1.57)-0.0664502],_
+[1.58,0.0655549,En(2,1.58),En(2,1.58)-0.0655549],_
+[1.59,0.0646726,En(2,1.59),En(2,1.59)-0.0646726],_
+[1.60,0.0638032,En(2,1.60),En(2,1.60)-0.0638032],_
+[1.61,0.0629464,En(2,1.61),En(2,1.61)-0.0629464],_
+[1.62,0.0621020,En(2,1.62),En(2,1.62)-0.0621020],_
+[1.63,0.0612698,En(2,1.63),En(2,1.63)-0.0612698],_
+[1.64,0.0604497,En(2,1.64),En(2,1.64)-0.0604497],_
+[1.65,0.0596413,En(2,1.65),En(2,1.65)-0.0596413],_
+[1.66,0.0588446,En(2,1.66),En(2,1.66)-0.0588446],_
+[1.67,0.0580594,En(2,1.67),En(2,1.67)-0.0580594],_
+[1.68,0.0572854,En(2,1.68),En(2,1.68)-0.0572854],_
+[1.69,0.0565226,En(2,1.69),En(2,1.69)-0.0565226],_
+[1.70,0.0557706,En(2,1.70),En(2,1.70)-0.0557706],_
+[1.71,0.0550294,En(2,1.71),En(2,1.71)-0.0550294],_
+[1.72,0.0542988,En(2,1.72),En(2,1.72)-0.0542988],_
+[1.73,0.0535786,En(2,1.73),En(2,1.73)-0.0535786],_
+[1.74,0.0528686,En(2,1.74),En(2,1.74)-0.0528686],_
+[1.75,0.0521687,En(2,1.75),En(2,1.75)-0.0521687],_
+[1.76,0.0514788,En(2,1.76),En(2,1.76)-0.0514788],_
+[1.77,0.0507986,En(2,1.77),En(2,1.77)-0.0507986],_
+[1.78,0.0501281,En(2,1.78),En(2,1.78)-0.0501281],_
+[1.79,0.0494670,En(2,1.79),En(2,1.79)-0.0494670],_
+[1.80,0.0488153,En(2,1.80),En(2,1.80)-0.0488153],_
+[1.81,0.0481727,En(2,1.81),En(2,1.81)-0.0481727],_
+[1.82,0.0475392,En(2,1.82),En(2,1.82)-0.0475392],_
+[1.83,0.0469146,En(2,1.83),En(2,1.83)-0.0469146],_
+[1.84,0.0462987,En(2,1.84),En(2,1.84)-0.0462987],_
+[1.85,0.0456915,En(2,1.85),En(2,1.85)-0.0456915],_
+[1.86,0.0450928,En(2,1.86),En(2,1.86)-0.0450928],_
+[1.87,0.0445024,En(2,1.87),En(2,1.87)-0.0445024],_
+[1.88,0.0439203,En(2,1.88),En(2,1.88)-0.0439203],_
+[1.89,0.0433463,En(2,1.89),En(2,1.89)-0.0433463],_
+[1.90,0.0427803,En(2,1.90),En(2,1.90)-0.0427803],_
+[1.91,0.0422222,En(2,1.91),En(2,1.91)-0.0422222],_
+[1.92,0.0416718,En(2,1.92),En(2,1.92)-0.0416718],_
+[1.93,0.0411291,En(2,1.93),En(2,1.93)-0.0411291],_
+[1.94,0.0405938,En(2,1.94),En(2,1.94)-0.0405938],_
+[1.95,0.0400660,En(2,1.95),En(2,1.95)-0.0400660],_
+[1.96,0.0395455,En(2,1.96),En(2,1.96)-0.0395455],_
+[1.97,0.0390322,En(2,1.97),En(2,1.97)-0.0390322],_
+[1.98,0.0385259,En(2,1.98),En(2,1.98)-0.0385259],_
+[1.99,0.0380267,En(2,1.99),En(2,1.99)-0.0380267],_
+[2.00,0.0375343,En(2,2.00),En(2,2.00)-0.0375343]]
+--R 
+--R
+--R   (3)
+--R   [[0.5,0.32664389999999999,0.326643862324553,- 3.7675446984408723E-8],
+--R
+--R     [0.51000000000000001, 0.32110620000000001, 0.32110617940404323,
+--R      - 2.0595956773394875E-8]
+--R     ,
+--R
+--R     [0.52000000000000002, 0.31568629999999998, 0.31568625309046355,
+--R      - 4.6909536421946285E-8]
+--R     ,
+--R
+--R     [0.53000000000000003, 0.31038070000000001, 0.31038066931747649,
+--R      - 3.0682523521896599E-8]
+--R     ,
+--R
+--R     [0.54000000000000004, 0.30518620000000002, 0.30518615409477512,
+--R      - 4.5905224899112085E-8]
+--R     ,
+--R
+--R     [0.55000000000000004, 0.30009960000000002, 0.30009956561466999,
+--R      - 3.4385330027753014E-8]
+--R     ,
+--R
+--R     [0.56000000000000005, 0.29511789999999999, 0.29511788693397883,
+--R      - 1.3066021153917973E-8]
+--R     ,
+--R    [0.56999999999999995,0.2902382,0.29023821917982273,1.9179822730031049E-8],
+--R
+--R     [0.57999999999999996, 0.28545779999999998, 0.28545777523334881,
+--R      - 2.4766651174346066E-8]
+--R     ,
+--R
+--R     [0.58999999999999997, 0.28077390000000002, 0.28077387385015457,
+--R      - 2.6149845455680776E-8]
+--R     ,
+--R
+--R     [0.59999999999999998, 0.27618389999999998, 0.27618393418038506,
+--R      3.4180385077853259E-8]
+--R     ,
+--R
+--R     [0.60999999999999999, 0.27168550000000002, 0.27168547065517928,
+--R      - 2.9344820740018207E-8]
+--R     ,
+--R    [0.62,0.26727610000000002,0.26727608820941573,- 1.1790584286686112E-8],
+--R    [0.63,0.26295350000000001,0.26295347781362555,- 2.2186374459831626E-8],
+--R
+--R     [0.64000000000000001, 0.25871539999999998, 0.25871541229051526,
+--R      1.2290515272184166E-8]
+--R     ,
+--R    [0.65000000000000002,0.2545597,0.25455974239385432,4.2393854315925239E-8],
+--R    [0.66000000000000003,0.2504844,0.25048439312952969,- 6.8704703037880677E-9],
+--R    [0.67000000000000004,0.2464874,0.24648736030041074,- 3.969958925487127E-8],
+--R    [0.68000000000000005,0.2425667,0.24256670725830815,7.2583081489607792E-9],
+--R
+--R     [0.68999999999999995, 0.23872060000000001, 0.23872056184779239,
+--R      - 3.8152207615382849E-8]
+--R     ,
+--R
+--R     [0.69999999999999996, 0.23494709999999999, 0.23494711352795306,
+--R      1.3527953063308118E-8]
+--R     ,
+--R
+--R     [0.70999999999999996, 0.23124459999999999, 0.23124461065938429,
+--R      1.0659384291900054E-8]
+--R     ,
+--R
+--R     [0.71999999999999997, 0.22761139999999999, 0.22761135794474674,
+--R      - 4.2055253252071267E-8]
+--R     ,
+--R
+--R     [0.72999999999999998, 0.22404569999999999, 0.22404571401223494,
+--R      1.4012234955673719E-8]
+--R     ,
+--R
+--R     [0.73999999999999999, 0.22054609999999999, 0.22054608913215246,
+--R      - 1.0867847538564845E-8]
+--R     ,
+--R    [0.75,0.2171109,0.21711094305759215,4.3057592158390889E-8],
+--R
+--R     [0.76000000000000001, 0.21373880000000001, 0.21373878298094046,
+--R      - 1.7019059550538174E-8]
+--R     ,
+--R
+--R     [0.77000000000000002, 0.21042820000000001, 0.21042816159857808,
+--R      - 3.8401421931233415E-8]
+--R     ,
+--R
+--R     [0.78000000000000003, 0.20717769999999999, 0.2071776752767438,
+--R      - 2.4723256192293874E-8]
+--R     ,
+--R    [0.79000000000000004,0.203986,0.20398596231206947,- 3.7687930526386637E-8],
+--R
+--R     [0.80000000000000004, 0.20085169999999999, 0.20085170128078714,
+--R      1.2807871430098317E-9]
+--R     ,
+--R
+--R     [0.81000000000000005, 0.19777359999999999, 0.19777360947106051,
+--R      9.4710605191838937E-9]
+--R     ,
+--R
+--R     [0.81999999999999995, 0.19475039999999999, 0.19475044139330239,
+--R      4.1393302396830478E-8]
+--R     ,
+--R
+--R     [0.82999999999999996, 0.19178100000000001, 0.19178098736371621,
+--R      - 1.2636283797107239E-8]
+--R     ,
+--R
+--R     [0.83999999999999997, 0.18886410000000001, 0.18886407215664666,
+--R      - 2.7843353345158306E-8]
+--R     ,
+--R
+--R     [0.84999999999999998, 0.18599859999999999, 0.18599855372163451,
+--R      - 4.627836547310693E-8]
+--R     ,
+--R
+--R     [0.85999999999999999, 0.18318329999999999, 0.1831833219613668,
+--R      2.1961366808431748E-8]
+--R     ,
+--R    [0.87,0.1804173,0.18041729756697517,- 2.4330248371562391E-9],
+--R    [0.88,0.17769940000000001,0.17769943090737958,3.0907379572342464E-8],
+--R
+--R     [0.89000000000000001, 0.17502870000000001, 0.17502870096960518,
+--R      9.696051739283007E-10]
+--R     ,
+--R    [0.90000000000000002,0.1724041,0.17240411434719952,1.4347199511766107E-8],
+--R    [0.91000000000000003,0.1698247,0.16982470427407523,4.2740752326242415E-9],
+--R
+--R     [0.92000000000000004, 0.16728950000000001, 0.1672895297012775,
+--R      2.9701277493021649E-8]
+--R     ,
+--R
+--R     [0.93000000000000005, 0.16479769999999999, 0.16479767441433715,
+--R      - 2.5585662838389922E-8]
+--R     ,
+--R    [0.93999999999999995,0.1623482,0.16234824618902396,4.6189023966691778E-8],
+--R
+--R     [0.94999999999999996, 0.15994040000000001, 0.15994037598345329,
+--R      - 2.4016546723570897E-8]
+--R     ,
+--R    [0.95999999999999996,0.1575732,0.15757321716462735,1.7164627358345896E-8],
+--R
+--R     [0.96999999999999997, 0.15524589999999999, 0.15524594476761389,
+--R      4.4767613893714753E-8]
+--R     ,
+--R    [0.97999999999999998,0.1529578,0.15295775478567628,- 4.5214323729503292E-8],
+--R
+--R     [0.98999999999999999, 0.15070790000000001, 0.15070786348977031,
+--R      - 3.6510229700636998E-8]
+--R     ,
+--R    [1.,0.1484955,0.14849550677592205,6.7759220456764524E-9],
+--R    [1.01,0.1463199,0.14631993953908851,3.9539088503293129E-8],
+--R    [1.02,0.14418039999999999,0.14418043507218453,3.5072184545459351E-8],
+--R    [1.03,0.14207629999999999,0.1420762844890415,- 1.551095848983941E-8],
+--R    [1.04,0.14000679999999999,0.14000679617012995,- 3.8298700322236812E-9],
+--R    [1.05,0.13797129999999999,0.13797129522994891,- 4.7700510763526438E-9],
+--R
+--R     [1.0600000000000001, 0.13596910000000001, 0.13596912300504763,
+--R      2.3005047616875274E-8]
+--R     ,
+--R    [1.0700000000000001,0.1339996,0.13399963656170108,3.6561701083348552E-8],
+--R
+--R     [1.0800000000000001, 0.13206219999999999, 0.13206220822231926,
+--R      8.2223192698904768E-9]
+--R     ,
+--R    [1.0900000000000001,0.1301562,0.13015622510971911,2.5109719109517314E-8],
+--R
+--R     [1.1000000000000001, 0.12828110000000001, 0.12828108870843541,
+--R      - 1.1291564600002246E-8]
+--R     ,
+--R    [1.1100000000000001,0.1264362,0.12643621444229519,1.4442295193095589E-8],
+--R    [1.1200000000000001,0.124621,0.12462103126751783,3.1267517838773351E-8],
+--R    [1.1299999999999999,0.122835,0.12283498128064541,- 1.871935459418772E-8],
+--R    [1.1399999999999999,0.1210775,0.12107751934064451,1.934064450259676E-8],
+--R    [1.1499999999999999,0.1193481,0.11934811270455489,1.270455489421618E-8],
+--R
+--R     [1.1599999999999999, 0.11764620000000001, 0.11764624067609286,
+--R      4.0676092855074231E-8]
+--R     ,
+--R    [1.1699999999999999,0.1159714,0.11597139426664799,- 5.7333520153690642E-9],
+--R    [1.1799999999999999,0.1143231,0.11432307586814175,- 2.4131858247788962E-8],
+--R    [1.1899999999999999,0.1127008,0.11270079893724061,- 1.0627593943768332E-9],
+--R    [1.2,0.1111041,0.11110408769044711,- 1.2309552890887865E-8],
+--R    [1.21,0.1095325,0.10953247680961009,- 2.3190389913940734E-8],
+--R    [1.22,0.1079855,0.10798551115742314,1.1157423138175027E-8],
+--R    [1.23,0.10646269999999999,0.10646274550249626,4.5502496270888315E-8],
+--R    [1.24,0.10496369999999999,0.10496374425361385,4.4253613856737317E-8],
+--R    [1.25,0.1034881,0.10348808120280234,- 1.8797197659514708E-8],
+--R    [1.26,0.1020353,0.10203533927685385,3.9276853852632243E-8],
+--R    [1.27,0.1006051,0.10060511029696789,1.0296967889455999E-8],
+--R    [1.28,9.9196999999999994E-2,9.9196994746190731E-2,- 5.2538092626397415E-9],
+--R    [1.29,9.7810599999999998E-2,9.7810601544343179E-2,1.5443431811146269E-9],
+--R    [1.3,9.6445500000000003E-2,9.6445547830144779E-2,4.7830144775384831E-8],
+--R
+--R     [1.3100000000000001, 9.5101500000000005E-2, 9.5101458750257717E-2,
+--R      - 4.1249742288584912E-8]
+--R     ,
+--R    [1.3200000000000001,9.3778E-2,9.3777967254982664E-2,- 3.2745017336521798E-8]
+--R     ,
+--R
+--R     [1.3300000000000001, 9.2474700000000007E-2, 9.2474713900349198E-2,
+--R      1.3900349191131589E-8]
+--R     ,
+--R
+--R     [1.3400000000000001, 9.1191300000000003E-2, 9.1191346656366773E-2,
+--R      4.6656366770037039E-8]
+--R     ,
+--R
+--R     [1.3500000000000001, 8.9927499999999994E-2, 8.9927520721194559E-2,
+--R      2.072119456575372E-8]
+--R     ,
+--R
+--R     [1.3600000000000001, 8.8682899999999995E-2, 8.8682898341016198E-2,
+--R      - 1.6589837975589106E-9]
+--R     ,
+--R
+--R     [1.3700000000000001, 8.7457099999999996E-2, 8.7457148635403298E-2,
+--R      4.8635403301910962E-8]
+--R     ,
+--R
+--R     [1.3799999999999999, 8.6249900000000004E-2, 8.6249947427970763E-2,
+--R      4.7427970759073013E-8]
+--R     ,
+--R
+--R     [1.3899999999999999, 8.5060999999999998E-2, 8.5060977082121597E-2,
+--R      - 2.2917878400585678E-8]
+--R     ,
+--R
+--R     [1.3999999999999999, 8.3889900000000003E-2, 8.3889926341705251E-2,
+--R      2.6341705247623359E-8]
+--R     ,
+--R
+--R     [1.4099999999999999, 8.2736500000000004E-2, 8.2736490176409327E-2,
+--R      - 9.8235906770272052E-9]
+--R     ,
+--R
+--R     [1.4199999999999999, 8.1600400000000003E-2, 8.1600369631709052E-2,
+--R      - 3.0368290951376942E-8]
+--R     ,
+--R
+--R     [1.4299999999999999, 8.0481300000000006E-2, 8.0481271683224637E-2,
+--R      - 2.8316775368963931E-8]
+--R     ,
+--R
+--R     [1.4399999999999999, 7.9378900000000002E-2, 7.9378909095316863E-2,
+--R      9.0953168607743606E-9]
+--R     ,
+--R    [1.45,7.8293000000000001E-2,7.8293000283781833E-2,2.8378183136723578E-10],
+--R    [1.46,7.7223299999999995E-2,7.7223269182499166E-2,- 3.0817500829005695E-8],
+--R    [1.47,7.6169399999999998E-2,7.6169445113894313E-2,4.5113894314718905E-8],
+--R    [1.48,7.5131299999999998E-2,7.5131262663086618E-2,- 3.7336913380481285E-8],
+--R    [1.49,7.4108499999999994E-2,7.4108461555594529E-2,- 3.844440546463268E-8],
+--R    [1.5,7.3100799999999994E-2,7.3100786538480983E-2,- 1.3461519010604661E-8],
+--R    [1.51,7.2108000000000005E-2,7.2107987264816237E-2,- 1.2735183768652902E-8],
+--R    [1.52,7.1129800000000007E-2,7.1129818181354831E-2,1.8181354824453599E-8],
+--R    [1.53,7.0166000000000006E-2,7.0166038419312571E-2,3.8419312564652586E-8],
+--R    [1.54,6.9216399999999997E-2,6.9216411688142798E-2,1.168814280083641E-8],
+--R    [1.55,6.82807E-2,6.8280706172218819E-2,6.172218819378017E-9],
+--R
+--R     [1.5600000000000001, 6.7358699999999994E-2, 6.735869443031553E-2,
+--R      - 5.5696844636354825E-9]
+--R     ,
+--R
+--R     [1.5700000000000001, 6.6450200000000001E-2, 6.6450153297810788E-2,
+--R      - 4.670218921309921E-8]
+--R     ,
+--R
+--R     [1.5800000000000001, 6.5554899999999999E-2, 6.5554863791512402E-2,
+--R      - 3.6208487597111372E-8]
+--R     ,
+--R
+--R     [1.5900000000000001, 6.4672599999999997E-2, 6.4672611017026815E-2,
+--R      1.1017026818604947E-8]
+--R     ,
+--R
+--R     [1.6000000000000001, 6.3803200000000004E-2, 6.380318407859184E-2,
+--R      - 1.5921408164087936E-8]
+--R     ,
+--R    [1.6100000000000001,6.29464E-2,6.2946375991286996E-2,- 2.400871300378693E-8]
+--R     ,
+--R
+--R     [1.6200000000000001, 6.2101999999999997E-2, 6.210198359555763E-2,
+--R      - 1.6404442367001781E-8]
+--R     ,
+--R
+--R     [1.6299999999999999, 6.1269799999999999E-2, 6.1269807473971261E-2,
+--R      7.4739712613292042E-9]
+--R     ,
+--R
+--R     [1.6399999999999999, 6.0449700000000002E-2, 6.0449651870139426E-2,
+--R      - 4.8129860576173744E-8]
+--R     ,
+--R
+--R     [1.6499999999999999, 5.9641300000000001E-2, 5.9641324609737895E-2,
+--R      2.460973789336629E-8]
+--R     ,
+--R
+--R     [1.6599999999999999, 5.8844599999999997E-2, 5.884463702356188E-2,
+--R      3.702356188295397E-8]
+--R     ,
+--R
+--R     [1.6699999999999999, 5.8059399999999997E-2, 5.8059403872549598E-2,
+--R      3.8725496004365922E-9]
+--R     ,
+--R    [1.6799999999999999,5.72854E-2,5.7285443274719294E-2,4.3274719294106312E-8],
+--R
+--R     [1.6899999999999999, 5.6522599999999999E-2, 5.6522576633957849E-2,
+--R      - 2.3366042149752797E-8]
+--R     ,
+--R    [1.7,5.5770599999999997E-2,5.5770628570604719E-2,2.8570604722333304E-8],
+--R    [1.71,5.5029399999999999E-2,5.5029426853783953E-2,2.685378395345106E-8],
+--R    [1.72,5.4298800000000001E-2,5.4298802335420795E-2,2.3354207942527516E-9],
+--R    [1.73,5.3578599999999997E-2,5.3578588885902612E-2,- 1.1114097385467314E-8],
+--R    [1.74,5.2868600000000002E-2,5.2868623331333131E-2,2.3331333129372744E-8],
+--R    [1.75,5.2168699999999998E-2,5.2168745392327326E-2,4.539232732747589E-8],
+--R    [1.76,5.1478799999999998E-2,5.1478797624312636E-2,- 2.375687362110579E-9],
+--R    [1.77,5.0798599999999999E-2,5.0798625359279745E-2,2.5359279745562624E-8],
+--R    [1.78,5.0128100000000002E-2,5.0128076648957798E-2,- 2.3351042204022843E-8],
+--R    [1.79,4.9466999999999997E-2,4.9467002209351796E-2,2.209351798732051E-9],
+--R    [1.8,4.8815299999999999E-2,4.8815255366622776E-2,- 4.4633377223324278E-8],
+--R
+--R     [1.8100000000000001, 4.8172699999999999E-2, 4.8172692004261553E-2,
+--R      - 7.995738446342493E-9]
+--R     ,
+--R
+--R     [1.8200000000000001, 4.7539199999999997E-2, 4.7539170511522538E-2,
+--R      - 2.9488477458483597E-8]
+--R     ,
+--R
+--R     [1.8300000000000001, 4.6914600000000001E-2, 4.691455173308047E-2,
+--R      - 4.8266919530637331E-8]
+--R     ,
+--R
+--R     [1.8400000000000001, 4.6298699999999998E-2, 4.6298698919879575E-2,
+--R      - 1.0801204236576822E-9]
+--R     ,
+--R
+--R     [1.8500000000000001, 4.5691500000000003E-2, 4.5691477681136752E-2,
+--R      - 2.2318863250603282E-8]
+--R     ,
+--R
+--R     [1.8600000000000001, 4.5092800000000002E-2, 4.5092755937471779E-2,
+--R      - 4.4062528223309805E-8]
+--R     ,
+--R
+--R     [1.8700000000000001, 4.4502399999999998E-2, 4.4502403875127772E-2,
+--R      3.8751277742221646E-9]
+--R     ,
+--R
+--R     [1.8799999999999999, 4.3920300000000002E-2, 4.3920293901256249E-2,
+--R      - 6.0987437530690691E-9]
+--R     ,
+--R
+--R     [1.8899999999999999, 4.3346299999999997E-2, 4.3346300600241791E-2,
+--R      6.0024179376894082E-10]
+--R     ,
+--R    [1.8999999999999999,4.27803E-2,4.2780300691019318E-2,6.9101931815529483E-10]
+--R     ,
+--R
+--R     [1.9099999999999999, 4.2222200000000001E-2, 4.2222172985387205E-2,
+--R      - 2.701461279674966E-8]
+--R     ,
+--R
+--R     [1.9199999999999999, 4.1671800000000002E-2, 4.1671798347258343E-2,
+--R      - 1.6527416588085764E-9]
+--R     ,
+--R
+--R     [1.9299999999999999, 4.1129100000000002E-2, 4.1129059652846772E-2,
+--R      - 4.0347153229536303E-8]
+--R     ,
+--R
+--R     [1.9399999999999999, 4.0593799999999999E-2, 4.0593841751750112E-2,
+--R      4.1751750112783981E-8]
+--R     ,
+--R    [1.95,4.0065999999999997E-2,4.0066031428916418E-2,3.1428916420772612E-8],
+--R    [1.96,3.9545499999999997E-2,3.9545517367460342E-2,1.7367460344863694E-8],
+--R    [1.97,3.9032200000000003E-2,3.9032190112315068E-2,- 9.8876849347062645E-9],
+--R    [1.98,3.8525900000000002E-2,3.8525942034688052E-2,4.2034688049752411E-8],
+--R    [1.99,3.8026699999999997E-2,3.8026667297318961E-2,- 3.2702681035390313E-8],
+--R    [2.,3.75343E-2,3.7534261820490689E-2,- 3.817950931100933E-8]]
+--R                               Type: List List OnePointCompletion DoubleFloat
+--E 3
+
+@
+This table expresses the value of 
+$E_3$ with an argument range of 0.01 to 2.00.
+<<*>>=
+--S 4 of 7
+[[0.01,0.4902766,En(3,0.01),En(3,0.01)-0.4902766],_
+[0.02,0.4809683,En(3,0.02),En(3,0.02)-0.4809683],_
+[0.03,0.4719977,En(3,0.03),En(3,0.03)-0.4719977],_
+[0.04,0.4633239,En(3,0.04),En(3,0.04)-0.4633239],_
+[0.05,0.4549188,En(3,0.05),En(3,0.05)-0.4549188],_
+[0.06,0.4467609,En(3,0.06),En(3,0.06)-0.4467609],_
+[0.07,0.4388327,En(3,0.07),En(3,0.07)-0.4388327],_
+[0.08,0.4311197,En(3,0.08),En(3,0.08)-0.4311197],_
+[0.09,0.4236096,En(3,0.09),En(3,0.09)-0.4236096],_
+[0.10,0.4162915,En(3,0.10),En(3,0.10)-0.4162915],_
+[0.11,0.4091557,En(3,0.11),En(3,0.11)-0.4091557],_
+[0.12,0.4021937,En(3,0.12),En(3,0.12)-0.4021937],_
+[0.13,0.3953977,En(3,0.13),En(3,0.13)-0.3953977],_
+[0.14,0.3887607,En(3,0.14),En(3,0.14)-0.3887607],_
+[0.15,0.3822761,En(3,0.15),En(3,0.15)-0.3822761],_
+[0.16,0.3759380,En(3,0.16),En(3,0.16)-0.3759380],_
+[0.17,0.3697408,En(3,0.17),En(3,0.17)-0.3697408],_
+[0.18,0.3636795,En(3,0.18),En(3,0.18)-0.3636795],_
+[0.19,0.3577491,En(3,0.19),En(3,0.19)-0.3577491],_
+[0.20,0.3519453,En(3,0.20),En(3,0.20)-0.3519453],_
+[0.21,0.3462638,En(3,0.21),En(3,0.21)-0.3462638],_
+[0.22,0.3407005,En(3,0.22),En(3,0.22)-0.3407005],_
+[0.23,0.3352518,En(3,0.23),En(3,0.23)-0.3352518],_
+[0.24,0.3299142,En(3,0.24),En(3,0.24)-0.3299142],_
+[0.25,0.3246841,En(3,0.25),En(3,0.25)-0.3246841],_
+[0.26,0.3195585,En(3,0.26),En(3,0.26)-0.3195585],_
+[0.27,0.3145343,En(3,0.27),En(3,0.27)-0.3145343],_
+[0.28,0.3096086,En(3,0.28),En(3,0.28)-0.3096086],_
+[0.29,0.3047787,En(3,0.29),En(3,0.29)-0.3047787],_
+[0.30,0.3000418,En(3,0.30),En(3,0.30)-0.3000418],_
+[0.31,0.2953956,En(3,0.31),En(3,0.31)-0.2953956],_
+[0.32,0.2908374,En(3,0.32),En(3,0.32)-0.2908374],_
+[0.33,0.2863652,En(3,0.33),En(3,0.33)-0.2863652],_
+[0.34,0.2819765,En(3,0.34),En(3,0.34)-0.2819765],_
+[0.35,0.2776693,En(3,0.35),En(3,0.35)-0.2776693],_
+[0.36,0.2734416,En(3,0.36),En(3,0.36)-0.2734416],_
+[0.37,0.2692913,En(3,0.37),En(3,0.37)-0.2692913],_
+[0.38,0.2652165,En(3,0.38),En(3,0.38)-0.2652165],_
+[0.39,0.2612155,En(3,0.39),En(3,0.39)-0.2612155],_
+[0.40,0.2572864,En(3,0.40),En(3,0.40)-0.2572864],_
+[0.41,0.2534276,En(3,0.41),En(3,0.41)-0.2534276],_
+[0.42,0.2496373,En(3,0.42),En(3,0.42)-0.2496373],_
+[0.43,0.2459141,En(3,0.43),En(3,0.43)-0.2459141],_
+[0.44,0.2422563,En(3,0.44),En(3,0.44)-0.2422563],_
+[0.45,0.2386625,En(3,0.45),En(3,0.45)-0.2386625],_
+[0.46,0.2351313,En(3,0.46),En(3,0.46)-0.2351313],_
+[0.47,0.2316612,En(3,0.47),En(3,0.47)-0.2316612],_
+[0.48,0.2282508,En(3,0.48),En(3,0.48)-0.2282508],_
+[0.49,0.2248990,En(3,0.49),En(3,0.49)-0.2248990],_
+[0.50,0.2216044,En(3,0.50),En(3,0.50)-0.2216044],_
+[0.51,0.2183657,En(3,0.51),En(3,0.51)-0.2183657],_
+[0.52,0.2151818,En(3,0.52),En(3,0.52)-0.2151818],_
+[0.53,0.2120516,En(3,0.53),En(3,0.53)-0.2120516],_
+[0.54,0.2089739,En(3,0.54),En(3,0.54)-0.2089739],_
+[0.55,0.2059475,En(3,0.55),En(3,0.55)-0.2059475],_
+[0.56,0.2029715,En(3,0.56),En(3,0.56)-0.2029715],_
+[0.57,0.2000448,En(3,0.57),En(3,0.57)-0.2000448],_
+[0.58,0.1971664,En(3,0.58),En(3,0.58)-0.1971664],_
+[0.59,0.1943353,En(3,0.59),En(3,0.59)-0.1943353],_
+[0.60,0.1915506,En(3,0.60),En(3,0.60)-0.1915506],_
+[0.61,0.1888114,En(3,0.61),En(3,0.61)-0.1888114],_
+[0.62,0.1861166,En(3,0.62),En(3,0.62)-0.1861166],_
+[0.63,0.1834656,En(3,0.63),En(3,0.63)-0.1834656],_
+[0.64,0.1808573,En(3,0.64),En(3,0.64)-0.1808573],_
+[0.65,0.1782910,En(3,0.65),En(3,0.65)-0.1782910],_
+[0.66,0.1757658,En(3,0.66),En(3,0.66)-0.1757658],_
+[0.67,0.1732810,En(3,0.67),En(3,0.67)-0.1732810],_
+[0.68,0.1708358,En(3,0.68),En(3,0.68)-0.1708358],_
+[0.69,0.1684294,En(3,0.69),En(3,0.69)-0.1684294],_
+[0.70,0.1660612,En(3,0.70),En(3,0.70)-0.1660612],_
+[0.71,0.1637303,En(3,0.71),En(3,0.71)-0.1637303],_
+[0.72,0.1614360,En(3,0.72),En(3,0.72)-0.1614360],_
+[0.73,0.1591778,En(3,0.73),En(3,0.73)-0.1591778],_
+[0.74,0.1569549,En(3,0.74),En(3,0.74)-0.1569549],_
+[0.75,0.1547667,En(3,0.75),En(3,0.75)-0.1547667],_
+[0.76,0.1526125,En(3,0.76),En(3,0.76)-0.1526125],_
+[0.77,0.1504917,En(3,0.77),En(3,0.77)-0.1504917],_
+[0.78,0.1484037,En(3,0.78),En(3,0.78)-0.1484037],_
+[0.79,0.1463479,En(3,0.79),En(3,0.79)-0.1463479],_
+[0.80,0.1443238,En(3,0.80),En(3,0.80)-0.1443238],_
+[0.81,0.1423307,En(3,0.81),En(3,0.81)-0.1423307],_
+[0.82,0.1403681,En(3,0.82),En(3,0.82)-0.1403681],_
+[0.83,0.1384355,En(3,0.83),En(3,0.83)-0.1384355],_
+[0.84,0.1365324,En(3,0.84),En(3,0.84)-0.1365324],_
+[0.85,0.1346581,En(3,0.85),En(3,0.85)-0.1346581],_
+[0.86,0.1328122,En(3,0.86),En(3,0.86)-0.1328122],_
+[0.87,0.1309943,En(3,0.87),En(3,0.87)-0.1309943],_
+[0.88,0.1292037,En(3,0.88),En(3,0.88)-0.1292037],_
+[0.89,0.1274401,En(3,0.89),En(3,0.89)-0.1274401],_
+[0.90,0.1257030,En(3,0.90),En(3,0.90)-0.1257030],_
+[0.91,0.1239919,En(3,0.91),En(3,0.91)-0.1239919],_
+[0.92,0.1223063,En(3,0.92),En(3,0.92)-0.1223063],_
+[0.93,0.1206459,En(3,0.93),En(3,0.93)-0.1206459],_
+[0.94,0.1190102,En(3,0.94),En(3,0.94)-0.1190102],_
+[0.95,0.1173988,En(3,0.95),En(3,0.95)-0.1173988],_
+[0.96,0.1158113,En(3,0.96),En(3,0.96)-0.1158113],_
+[0.97,0.1142472,En(3,0.97),En(3,0.97)-0.1142472],_
+[0.98,0.1127063,En(3,0.98),En(3,0.98)-0.1127063],_
+[0.99,0.1111880,En(3,0.99),En(3,0.99)-0.1111880],_
+[1.00,0.1096920,En(3,1.00),En(3,1.00)-0.1096920],_
+[1.01,0.1082179,En(3,1.01),En(3,1.01)-0.1082179],_
+[1.02,0.1067654,En(3,1.02),En(3,1.02)-0.1067654],_
+[1.03,0.1053342,En(3,1.03),En(3,1.03)-0.1053342],_
+[1.04,0.1039238,En(3,1.04),En(3,1.04)-0.1039238],_
+[1.05,0.1025339,En(3,1.05),En(3,1.05)-0.1025339],_
+[1.06,0.1011643,En(3,1.06),En(3,1.06)-0.1011643],_
+[1.07,0.0998145,En(3,1.07),En(3,1.07)-0.0998145],_
+[1.08,0.0984842,En(3,1.08),En(3,1.08)-0.0984842],_
+[1.09,0.0971731,En(3,1.09),En(3,1.09)-0.0971731],_
+[1.10,0.0958809,En(3,1.10),En(3,1.10)-0.0958809],_
+[1.11,0.0946074,En(3,1.11),En(3,1.11)-0.0946074],_
+[1.12,0.0933521,En(3,1.12),En(3,1.12)-0.0933521],_
+[1.13,0.0921149,En(3,1.13),En(3,1.13)-0.0921149],_
+[1.14,0.0908953,En(3,1.14),En(3,1.14)-0.0908953],_
+[1.15,0.0896932,En(3,1.15),En(3,1.15)-0.0896932],_
+[1.16,0.0885083,En(3,1.16),En(3,1.16)-0.0885083],_
+[1.17,0.0873402,En(3,1.17),En(3,1.17)-0.0873402],_
+[1.18,0.0861888,En(3,1.18),En(3,1.18)-0.0861888],_
+[1.19,0.0850537,En(3,1.19),En(3,1.19)-0.0850537],_
+[1.20,0.0839347,En(3,1.20),En(3,1.20)-0.0839347],_
+[1.21,0.0828315,En(3,1.21),En(3,1.21)-0.0828315],_
+[1.22,0.0817439,En(3,1.22),En(3,1.22)-0.0817439],_
+[1.23,0.0806717,En(3,1.23),En(3,1.23)-0.0806717],_
+[1.24,0.0796146,En(3,1.24),En(3,1.24)-0.0796146],_
+[1.25,0.0785723,En(3,1.25),En(3,1.25)-0.0785723],_
+[1.26,0.0775447,En(3,1.26),En(3,1.26)-0.0775447],_
+[1.27,0.0765316,En(3,1.27),En(3,1.27)-0.0765316],_
+[1.28,0.0755326,En(3,1.28),En(3,1.28)-0.0755326],_
+[1.29,0.0745476,En(3,1.29),En(3,1.29)-0.0745476],_
+[1.30,0.0735763,En(3,1.30),En(3,1.30)-0.0735763],_
+[1.31,0.0726186,En(3,1.31),En(3,1.31)-0.0726186],_
+[1.32,0.0716742,En(3,1.32),En(3,1.32)-0.0716742],_
+[1.33,0.0707429,En(3,1.33),En(3,1.33)-0.0707429],_
+[1.34,0.0698246,En(3,1.34),En(3,1.34)-0.0698246],_
+[1.35,0.0689191,En(3,1.35),En(3,1.35)-0.0689191],_
+[1.36,0.0680260,En(3,1.36),En(3,1.36)-0.0680260],_
+[1.37,0.0671453,En(3,1.37),En(3,1.37)-0.0671453],_
+[1.38,0.0662768,En(3,1.38),En(3,1.38)-0.0662768],_
+[1.39,0.0654203,En(3,1.39),En(3,1.39)-0.0654203],_
+[1.40,0.0645755,En(3,1.40),En(3,1.40)-0.0645755],_
+[1.41,0.0637424,En(3,1.41),En(3,1.41)-0.0637424],_
+[1.42,0.0629207,En(3,1.42),En(3,1.42)-0.0629207],_
+[1.43,0.0621104,En(3,1.43),En(3,1.43)-0.0621104],_
+[1.44,0.0613111,En(3,1.44),En(3,1.44)-0.0613111],_
+[1.45,0.0605227,En(3,1.45),En(3,1.45)-0.0605227],_
+[1.46,0.0597452,En(3,1.46),En(3,1.46)-0.0597452],_
+[1.47,0.0589782,En(3,1.47),En(3,1.47)-0.0589782],_
+[1.48,0.0582217,En(3,1.48),En(3,1.48)-0.0582217],_
+[1.49,0.0574755,En(3,1.49),En(3,1.49)-0.0574755],_
+[1.50,0.0567395,En(3,1.50),En(3,1.50)-0.0567395],_
+[1.51,0.0560135,En(3,1.51),En(3,1.51)-0.0560135],_
+[1.52,0.0552973,En(3,1.52),En(3,1.52)-0.0552973],_
+[1.53,0.0545908,En(3,1.53),En(3,1.53)-0.0545908],_
+[1.54,0.0538939,En(3,1.54),En(3,1.54)-0.0538939],_
+[1.55,0.0532064,En(3,1.55),En(3,1.55)-0.0532064],_
+[1.56,0.0525283,En(3,1.56),En(3,1.56)-0.0525283],_
+[1.57,0.0518592,En(3,1.57),En(3,1.57)-0.0518592],_
+[1.58,0.0511992,En(3,1.58),En(3,1.58)-0.0511992],_
+[1.59,0.0505481,En(3,1.59),En(3,1.59)-0.0505481],_
+[1.60,0.0499057,En(3,1.60),En(3,1.60)-0.0499057],_
+[1.61,0.0492720,En(3,1.61),En(3,1.61)-0.0492720],_
+[1.62,0.0486467,En(3,1.62),En(3,1.62)-0.0486467],_
+[1.63,0.0480299,En(3,1.63),En(3,1.63)-0.0480299],_
+[1.64,0.0474213,En(3,1.64),En(3,1.64)-0.0474213],_
+[1.65,0.0468209,En(3,1.65),En(3,1.65)-0.0468209],_
+[1.66,0.0462284,En(3,1.66),En(3,1.66)-0.0462284],_
+[1.67,0.0456439,En(3,1.67),En(3,1.67)-0.0456439],_
+[1.68,0.0450672,En(3,1.68),En(3,1.68)-0.0450672],_
+[1.69,0.0444982,En(3,1.69),En(3,1.69)-0.0444982],_
+[1.70,0.0439367,En(3,1.70),En(3,1.70)-0.0439367],_
+[1.71,0.0433827,En(3,1.71),En(3,1.71)-0.0433827],_
+[1.72,0.0428361,En(3,1.72),En(3,1.72)-0.0428361],_
+[1.73,0.0422967,En(3,1.73),En(3,1.73)-0.0422967],_
+[1.74,0.0417645,En(3,1.74),En(3,1.74)-0.0417645],_
+[1.75,0.0412393,En(3,1.75),En(3,1.75)-0.0412393],_
+[1.76,0.0407211,En(3,1.76),En(3,1.76)-0.0407211],_
+[1.77,0.0402097,En(3,1.77),En(3,1.77)-0.0402097],_
+[1.78,0.0397051,En(3,1.78),En(3,1.78)-0.0397051],_
+[1.79,0.0392071,En(3,1.79),En(3,1.79)-0.0392071],_
+[1.80,0.0387157,En(3,1.80),En(3,1.80)-0.0387157],_
+[1.81,0.0382308,En(3,1.81),En(3,1.81)-0.0382308],_
+[1.82,0.0377522,En(3,1.82),En(3,1.82)-0.0377522],_
+[1.83,0.0372800,En(3,1.83),En(3,1.83)-0.0372800],_
+[1.84,0.0368139,En(3,1.84),En(3,1.84)-0.0368139],_
+[1.85,0.0363540,En(3,1.85),En(3,1.85)-0.0363540],_
+[1.86,0.0359001,En(3,1.86),En(3,1.86)-0.0359001],_
+[1.87,0.0354521,En(3,1.87),En(3,1.87)-0.0354521],_
+[1.88,0.0350100,En(3,1.88),En(3,1.88)-0.0350100],_
+[1.89,0.0345737,En(3,1.89),En(3,1.89)-0.0345737],_
+[1.90,0.0341430,En(3,1.90),En(3,1.90)-0.0341430],_
+[1.91,0.0337180,En(3,1.91),En(3,1.91)-0.0337180],_
+[1.92,0.0332986,En(3,1.92),En(3,1.92)-0.0332986],_
+[1.93,0.0328846,En(3,1.93),En(3,1.93)-0.0328846],_
+[1.94,0.0324759,En(3,1.94),En(3,1.94)-0.0324759],_
+[1.95,0.0320727,En(3,1.95),En(3,1.95)-0.0320727],_
+[1.96,0.0316746,En(3,1.96),En(3,1.96)-0.0316746],_
+[1.97,0.0312817,En(3,1.97),En(3,1.97)-0.0312817],_
+[1.98,0.0308939,En(3,1.98),En(3,1.98)-0.0308939],_
+[1.99,0.0305112,En(3,1.99),En(3,1.99)-0.0305112],_
+[2.00,0.0301334,En(3,2.00),En(3,2.00)-0.0301334]]
+--R 
+--R
+--R   (4)
+--R   [[1.0E-2,0.49027660000000001,0.49027656418466514,- 3.5815334864519599E-8],
+--R    [2.0E-2,0.48096830000000002,0.48096829147697201,- 8.5230280055803576E-9],
+--R
+--R     [2.9999999999999999E-2, 0.47199770000000002, 0.47199768719683605,
+--R      - 1.2803163973451603E-8]
+--R     ,
+--R
+--R     [4.0000000000000001E-2, 0.46332390000000001, 0.46332394174433533,
+--R      4.1744335321780568E-8]
+--R     ,
+--R
+--R     [5.0000000000000003E-2, 0.45491880000000001, 0.45491884974847663,
+--R      4.9748476615985027E-8]
+--R     ,
+--R
+--R     [5.9999999999999998E-2, 0.44676090000000002, 0.44676088323725571,
+--R      - 1.6762744303733257E-8]
+--R     ,
+--R
+--R     [7.0000000000000007E-2, 0.43883270000000002, 0.43883267979789509,
+--R      - 2.0202104933364495E-8]
+--R     ,
+--R
+--R     [8.0000000000000002E-2, 0.43111969999999999, 0.43111973054612684,
+--R      3.054612685016167E-8]
+--R     ,
+--R
+--R     [8.9999999999999997E-2, 0.42360959999999998, 0.42360960561704109,
+--R      5.6170411100175954E-9]
+--R     ,
+--R
+--R     [0.10000000000000001, 0.41629149999999998, 0.41629145790827876,
+--R      - 4.2091721219605915E-8]
+--R     ,
+--R    [0.11,0.40915570000000001,0.40915568570605237,- 1.4293947636634385E-8],
+--R    [0.12,0.40219369999999999,0.40219369277059286,- 7.2294071284950689E-9],
+--R    [0.13,0.39539770000000002,0.395397711576501,1.1576500980048365E-8],
+--R
+--R     [0.14000000000000001, 0.38876070000000001, 0.38876066929878084,
+--R      - 3.0701219178030925E-8]
+--R     ,
+--R
+--R     [0.14999999999999999, 0.38227610000000001, 0.38227608377400268,
+--R      - 1.6225997323537911E-8]
+--R     ,
+--R    [0.16,0.37593799999999999,0.37593798110903431,- 1.8890965680640193E-8],
+--R
+--R     [0.17000000000000001, 0.36974079999999998, 0.36974082931670565,
+--R      2.9316705674187205E-8]
+--R     ,
+--R
+--R     [0.17999999999999999, 0.36367949999999999, 0.36367948407235051,
+--R      - 1.5927649477109895E-8]
+--R     ,
+--R    [0.19,0.35774909999999999,0.3577491438077095,4.3807709515508719E-8],
+--R
+--R     [0.20000000000000001, 0.35194530000000002, 0.35194531211487057,
+--R      1.2114870551194201E-8]
+--R     ,
+--R
+--R     [0.20999999999999999, 0.34626380000000001, 0.3462637659551443,
+--R      - 3.4044855712345168E-8]
+--R     ,
+--R    [0.22,0.34070050000000002,0.34070052853638638,2.8536386365018984E-8],
+--R
+--R     [0.23000000000000001, 0.33525179999999999, 0.33525184598756436,
+--R      4.5987564367688805E-8]
+--R     ,
+--R
+--R     [0.23999999999999999, 0.32991419999999999, 0.32991416715361832,
+--R      - 3.2846381670115221E-8]
+--R     ,
+--R    [0.25,0.32468409999999998,0.32468412597814367,2.5978143691762767E-8],
+--R
+--R     [0.26000000000000001, 0.31955850000000002, 0.31955852605039498,
+--R      2.6050394952292777E-8]
+--R     ,
+--R
+--R     [0.27000000000000002, 0.31453429999999999, 0.31453432697636552,
+--R      2.6976365530284596E-8]
+--R     ,
+--R
+--R     [0.28000000000000003, 0.30960860000000001, 0.30960863229804725,
+--R      3.2298047236700711E-8]
+--R     ,
+--R
+--R     [0.28999999999999998, 0.30477870000000001, 0.30477867873524889,
+--R      - 2.126475112662618E-8]
+--R     ,
+--R
+--R     [0.29999999999999999, 0.30004180000000003, 0.30004182656401435,
+--R      2.6564014321550644E-8]
+--R     ,
+--R    [0.31,0.29539559999999998,0.29539555097726167,- 4.9022738313198033E-8],
+--R
+--R     [0.32000000000000001, 0.29083740000000002, 0.29083743429861525,
+--R      3.4298615225747398E-8]
+--R     ,
+--R
+--R     [0.33000000000000002, 0.28636519999999999, 0.28636515894092018,
+--R      - 4.1059079802785448E-8]
+--R     ,
+--R
+--R     [0.34000000000000002, 0.28197650000000002, 0.28197650101764582,
+--R      1.0176458009603095E-9]
+--R     ,
+--R
+--R     [0.34999999999999998, 0.27766930000000001, 0.27766932452910809,
+--R      2.4529108078041872E-8]
+--R     ,
+--R
+--R     [0.35999999999999999, 0.27344160000000001, 0.27344157605676817,
+--R      - 2.3943231841627721E-8]
+--R     ,
+--R    [0.37,0.26929130000000001,0.26929127990828022,- 2.0091719787895812E-8],
+--R    [0.38,0.26521650000000002,0.2652165336638212,3.3663821175089481E-8],
+--R
+--R     [0.39000000000000001, 0.26121549999999999, 0.26121550408084138,
+--R      4.0808413870330185E-9]
+--R     ,
+--R
+--R     [0.40000000000000002, 0.25728640000000003, 0.25728642331994478,
+--R      2.3319944753019684E-8]
+--R     ,
+--R
+--R     [0.40999999999999998, 0.25342759999999998, 0.25342758545933575,
+--R      - 1.45406642282353E-8]
+--R     ,
+--R
+--R     [0.41999999999999998, 0.24963730000000001, 0.24963734326929157,
+--R      4.3269291566394585E-8]
+--R     ,
+--R    [0.42999999999999999,0.2459141,0.24591410522156262,5.2215626267226867E-9],
+--R    [0.44,0.24225630000000001,0.24225633271155758,3.2711557573783523E-8],
+--R    [0.45000000000000001,0.2386625,0.23866253747371868,3.7473718683678214E-8],
+--R
+--R     [0.46000000000000002, 0.23513129999999999, 0.23513127917269516,
+--R      - 2.082730482522166E-8]
+--R     ,
+--R
+--R     [0.46999999999999997, 0.23166120000000001, 0.2316611631548362,
+--R      - 3.6845163808862935E-8]
+--R     ,
+--R    [0.47999999999999998,0.2282508,0.22825083834619003,3.8346190028848426E-8],
+--R
+--R     [0.48999999999999999, 0.22489899999999999, 0.22489899528465218,
+--R      - 4.7153478066608301E-9]
+--R     ,
+--R    [0.5,0.22160440000000001,0.22160436427517846,- 3.572482154545753E-8],
+--R    [0.51000000000000001,0.2183657,0.21836571365810192,1.3658101927216393E-8],
+--R
+--R     [0.52000000000000002, 0.21518180000000001, 0.21518184818157665,
+--R      4.8181576645101032E-8]
+--R     ,
+--R
+--R     [0.53000000000000003, 0.21205160000000001, 0.21205160747004631,
+--R      7.4700463037480347E-9]
+--R     ,
+--R
+--R     [0.54000000000000004, 0.20897389999999999, 0.20897386458140554,
+--R      - 3.541859444622375E-8]
+--R     ,
+--R
+--R     [0.55000000000000004, 0.20594750000000001, 0.20594752464620908,
+--R      2.4646209073608816E-8]
+--R     ,
+--R    [0.56000000000000005,0.2029715,0.20297152358289336,2.3582893360352131E-8],
+--R
+--R     [0.56999999999999995, 0.20004479999999999, 0.20004482688351907,
+--R      2.6883519077536278E-8]
+--R     ,
+--R
+--R     [0.57999999999999996, 0.19716639999999999, 0.19716642846502985,
+--R      2.8465029860980096E-8]
+--R     ,
+--R
+--R     [0.58999999999999997, 0.19433529999999999, 0.19433534958145796,
+--R      4.9581457967073916E-8]
+--R     ,
+--R
+--R     [0.59999999999999998, 0.19155059999999999, 0.19155063779289766,
+--R      3.7792897672472847E-8]
+--R     ,
+--R
+--R     [0.60999999999999999, 0.18881139999999999, 0.18881136598742021,
+--R      - 3.4012579780418051E-8]
+--R     ,
+--R    [0.62,0.18611659999999999,0.18611663145241836,3.1452418364219525E-8],
+--R    [0.63,0.18346560000000001,0.18346555499215655,- 4.5007843452182783E-8],
+--R    [0.64000000000000001,0.1808573,0.18085728008855939,- 1.9911440607423003E-8],
+--R
+--R     [0.65000000000000002, 0.17829100000000001, 0.17829097210250539,
+--R      - 2.7897494619955054E-8]
+--R     ,
+--R    [0.66000000000000003,0.1757658,0.17576581751310477,1.7513104771937904E-8],
+--R
+--R     [0.67000000000000004, 0.17328099999999999, 0.17328102319263361,
+--R      2.3192633619162351E-8]
+--R     ,
+--R
+--R     [0.68000000000000005, 0.17083580000000001, 0.17083581571497,
+--R      1.5714969991975636E-8]
+--R     ,
+--R
+--R     [0.68999999999999995, 0.16842940000000001, 0.16842944069553942,
+--R      4.0695539410551262E-8]
+--R     ,
+--R
+--R     [0.69999999999999996, 0.16606119999999999, 0.16606116216092121,
+--R      - 3.7839078786960911E-8]
+--R     ,
+--R    [0.70999999999999996,0.1637303,0.16373026194640114,- 3.8053598855336546E-8],
+--R    [0.71999999999999997,0.161436,0.16143603911987703,3.9119877032200989E-8],
+--R
+--R     [0.72999999999999998, 0.15917780000000001, 0.15917780943063548,
+--R      9.4306354669893011E-9]
+--R     ,
+--R
+--R     [0.73999999999999999, 0.15695490000000001, 0.15695490478162077,
+--R      4.7816207660034138E-9]
+--R     ,
+--R    [0.75,0.15476670000000001,0.15476667272391029,- 2.7276089720196239E-8],
+--R
+--R     [0.76000000000000001, 0.15261250000000001, 0.15261247597219724,
+--R      - 2.4027802775217211E-8]
+--R     ,
+--R
+--R     [0.77000000000000002, 0.15049170000000001, 0.15049169194016149,
+--R      - 8.0598385188146437E-9]
+--R     ,
+--R    [0.78000000000000003,0.1484037,0.14840371229468169,1.2294681689395404E-8],
+--R    [0.79000000000000004,0.1463479,0.14634794252791047,4.2527910470990804E-8],
+--R    [0.80000000000000004,0.1443238,0.14432380154629593,1.5462959246370644E-9],
+--R    [0.81000000000000005,0.1423307,0.14233072127569105,2.1275691042266232E-8],
+--R    [0.81999999999999995,0.1403681,0.14036814628174568,4.628174568588328E-8],
+--R
+--R     [0.82999999999999996, 0.13843549999999999, 0.13843553340482559,
+--R      3.3404825600102939E-8]
+--R     ,
+--R    [0.83999999999999997,0.1365324,0.13653235140874825,- 4.8591251744500852E-8],
+--R    [0.84999999999999998,0.1346581,0.13465808064266868,- 1.935733132119033E-8],
+--R
+--R     [0.85999999999999999, 0.13281219999999999, 0.13281221271548668,
+--R      1.2715486691350364E-8]
+--R     ,
+--R    [0.87,0.13099430000000001,0.1309942501821853,- 4.9817814706809571E-8],
+--R    [0.88,0.1292037,0.12920370624154368,6.2415436707929928E-9],
+--R    [0.89000000000000001,0.1274401,0.12744010444469844,4.4446984426294023E-9],
+--R
+--R     [0.90000000000000002, 0.12570300000000001, 0.12570297841405975,
+--R      - 2.1585940257473624E-8]
+--R     ,
+--R    [0.91000000000000003,0.1239919,0.12399187157211375,- 2.8427886253346024E-8],
+--R
+--R     [0.92000000000000004, 0.12230630000000001, 0.12230633687966941,
+--R      3.6879669401690407E-8]
+--R     ,
+--R    [0.93000000000000005,0.1206459,0.12064593658313376,3.6583133758427699E-8],
+--R    [0.93999999999999995,0.1190102,0.1190102419704193,4.1970419306647244E-8],
+--R    [0.94999999999999996,0.1173988,0.11739883313511031,3.3135110308335491E-8],
+--R
+--R     [0.95999999999999996, 0.11581130000000001, 0.11581129874853491,
+--R      - 1.2514650982176079E-9]
+--R     ,
+--R
+--R     [0.96999999999999997, 0.11424719999999999, 0.11424723583940669,
+--R      3.5839406692383946E-8]
+--R     ,
+--R    [0.97999999999999998,0.1127063,0.11270624958071841,- 5.0419281583113928E-8],
+--R    [0.98999999999999999,0.111188,0.11118795308358656,- 4.6916413434794357E-8],
+--R    [1.,0.109692,0.10969196719776014,- 3.2802239854912152E-8],
+--R    [1.01,0.10821790000000001,0.10821792031852197,2.031852196215933E-8],
+--R    [1.02,0.1067654,0.10676544819972504,4.8199725044550945E-8],
+--R    [1.03,0.1053342,0.10533419377271731,- 6.2272826895082289E-9],
+--R    [1.04,0.1039238,0.1039238069709225,6.9709225059000346E-9],
+--R    [1.05,0.1025339,0.10253394455985448,4.455985448681421E-8],
+--R    [1.0600000000000001,0.1011643,0.10116426997235345,- 3.0027646549801723E-8],
+--R
+--R     [1.0700000000000001, 9.98145E-2, 9.9814453148843241E-2,
+--R      - 4.6851156759730728E-8]
+--R     ,
+--R
+--R     [1.0800000000000001, 9.8484199999999994E-2, 9.8484170382417149E-2,
+--R      - 2.9617582844587709E-8]
+--R     ,
+--R
+--R     [1.0900000000000001, 9.7173099999999998E-2, 9.7173104168569752E-2,
+--R      4.1685697532711785E-9]
+--R     ,
+--R
+--R     [1.1000000000000001, 9.5880900000000005E-2, 9.58809430594003E-2,
+--R      4.305940029536437E-8]
+--R     ,
+--R
+--R     [1.1100000000000001, 9.4607399999999994E-2, 9.4607381522120698E-2,
+--R      - 1.8477879296097122E-8]
+--R     ,
+--R
+--R     [1.1200000000000001, 9.3352099999999993E-2, 9.3352119801709738E-2,
+--R      1.9801709744138307E-8]
+--R     ,
+--R
+--R     [1.1299999999999999, 9.21149E-2, 9.2114863787561826E-2,
+--R      - 3.6212438173088835E-8]
+--R     ,
+--R
+--R     [1.1399999999999999, 9.0895299999999998E-2, 9.0895324883984607E-2,
+--R      2.4883984608981002E-8]
+--R     ,
+--R
+--R     [1.1499999999999999, 8.9693200000000001E-2, 8.969321988440758E-2,
+--R      1.9884407578829588E-8]
+--R     ,
+--R
+--R     [1.1599999999999999, 8.8508299999999998E-2, 8.8508270849168805E-2,
+--R      - 2.9150831193369697E-8]
+--R     ,
+--R
+--R     [1.1699999999999999, 8.7340200000000007E-2, 8.7340204986753447E-2,
+--R      4.9867534407388447E-9]
+--R     ,
+--R
+--R     [1.1799999999999999, 8.6188799999999996E-2, 8.6188754538362E-2,
+--R      - 4.5461637995791726E-8]
+--R     ,
+--R
+--R     [1.1899999999999999, 8.5053699999999996E-2, 8.505365666569388E-2,
+--R      - 4.3334306115694332E-8]
+--R     ,
+--R    [1.2,8.3934700000000001E-2,8.393465334183281E-2,- 4.6658167190960498E-8],
+--R    [1.21,8.2831500000000002E-2,8.283149124512959E-2,- 8.7548704119644327E-9],
+--R    [1.22,8.1743899999999994E-2,8.1743921655978991E-2,2.1655978996171221E-8],
+--R    [1.23,8.0671699999999999E-2,8.067170035639451E-2,3.5639451112512432E-10],
+--R    [1.24,7.9614599999999994E-2,7.9614587532284717E-2,- 1.2467715276853752E-8],
+--R    [1.25,7.8572299999999998E-2,7.857234767834359E-2,4.7678343592649775E-8],
+--R    [1.26,7.7544699999999994E-2,7.7544749505467275E-2,4.950546728110794E-8],
+--R    [1.27,7.6531600000000005E-2,7.6531565850615282E-2,- 3.4149384722792497E-8],
+--R    [1.28,7.5532600000000005E-2,7.5532573589034993E-2,- 2.6410965012213516E-8],
+--R    [1.29,7.4547600000000006E-2,7.454755354877482E-2,- 4.6451225185761835E-8],
+--R    [1.3,7.3576299999999997E-2,7.3576290427412191E-2,- 9.5725878057617564E-9],
+--R
+--R     [1.3100000000000001, 7.2618600000000005E-2, 7.2618572710924589E-2,
+--R      - 2.7289075416048192E-8]
+--R     ,
+--R
+--R     [1.3200000000000001, 7.1674199999999993E-2, 7.1674192594636615E-2,
+--R      - 7.4053633780657435E-9]
+--R     ,
+--R
+--R     [1.3300000000000001, 7.0742899999999997E-2, 7.0742945906179772E-2,
+--R      4.5906179774179989E-8]
+--R     ,
+--R
+--R     [1.3400000000000001, 6.9824600000000001E-2, 6.9824632030397252E-2,
+--R      3.203039725119261E-8]
+--R     ,
+--R
+--R     [1.3500000000000001, 6.8919099999999997E-2, 6.8919053836139416E-2,
+--R      - 4.6163860581427407E-8]
+--R     ,
+--R
+--R     [1.3600000000000001, 6.8026000000000003E-2, 6.8026017604886913E-2,
+--R      1.7604886909383666E-8]
+--R     ,
+--R
+--R     [1.3700000000000001, 6.7145300000000005E-2, 6.7145332961148871E-2,
+--R      3.29611488658621E-8]
+--R     ,
+--R
+--R     [1.3799999999999999, 6.6276799999999997E-2, 6.6276812804578436E-2,
+--R      1.2804578439218339E-8]
+--R     ,
+--R
+--R     [1.3899999999999999, 6.5420300000000001E-2, 6.5420273243759597E-2,
+--R      - 2.6756240403824627E-8]
+--R     ,
+--R
+--R     [1.3999999999999999, 6.4575499999999994E-2, 6.457553353160958E-2,
+--R      3.3531609586190392E-8]
+--R     ,
+--R
+--R     [1.4099999999999999, 6.3742400000000005E-2, 6.3742416002349978E-2,
+--R      1.6002349972898955E-8]
+--R     ,
+--R
+--R     [1.4199999999999999, 6.2920699999999996E-2, 6.2920746010004802E-2,
+--R      4.6010004806085192E-8]
+--R     ,
+--R
+--R     [1.4299999999999999, 6.2110400000000003E-2, 6.211035186837166E-2,
+--R      - 4.8131628342662491E-8]
+--R     ,
+--R
+--R     [1.4399999999999999, 6.13111E-2, 6.1311064792432743E-2,
+--R      - 3.5207567257444783E-8]
+--R     ,
+--R    [1.45,6.0522699999999999E-2,6.0522718841157001E-2,1.8841157002624787E-8],
+--R    [1.46,5.9745199999999998E-2,5.9745150861655022E-2,- 4.9138344976329407E-8],
+--R    [1.47,5.8978200000000001E-2,5.8978200434649602E-2,4.3464960103323236E-10],
+--R    [1.48,5.8221700000000001E-2,5.8221709821222274E-2,9.8212222729432419E-9],
+--R    [1.49,5.7475499999999999E-2,5.7475523910801435E-2,2.3910801436044515E-8],
+--R    [1.5,5.6739499999999998E-2,5.6739490170354172E-2,- 9.8296458264646169E-9],
+--R    [1.51,5.6013500000000001E-2,5.6013458594752839E-2,- 4.140524716145233E-8],
+--R    [1.52,5.5297300000000001E-2,5.52972816582777E-2,- 1.8341722300696528E-8],
+--R    [1.53,5.4590800000000002E-2,5.4590814267229414E-2,1.4267229411779603E-8],
+--R    [1.54,5.3893900000000002E-2,5.3893913713619013E-2,1.3713619011201938E-8],
+--R    [1.55,5.3206400000000001E-2,5.3206439629901937E-2,3.9629901936455436E-8],
+--R
+--R     [1.5600000000000001, 5.25283E-2, 5.2528253944736245E-2,
+--R      - 4.6055263755451215E-8]
+--R     ,
+--R
+--R     [1.5700000000000001, 5.1859200000000001E-2, 5.1859220839728763E-2,
+--R      2.083972876210094E-8]
+--R     ,
+--R    [1.5800000000000001,5.11992E-2,5.1199206707146921E-2,6.7071469211921197E-9],
+--R
+--R     [1.5900000000000001, 5.0548099999999999E-2, 5.0548080108570391E-2,
+--R      - 1.9891429607621358E-8]
+--R     ,
+--R
+--R     [1.6000000000000001, 4.9905699999999997E-2, 4.9905711734454218E-2,
+--R      1.1734454220813095E-8]
+--R     ,
+--R
+--R     [1.6100000000000001, 4.9272000000000003E-2, 4.9271974364586212E-2,
+--R      - 2.5635413791746942E-8]
+--R     ,
+--R
+--R     [1.6200000000000001, 4.8646700000000001E-2, 4.8646742829405641E-2,
+--R      4.2829405640099072E-8]
+--R     ,
+--R
+--R     [1.6299999999999999, 4.80299E-2, 4.8029893972168107E-2,
+--R      - 6.0278318933515429E-9]
+--R     ,
+--R    [1.6399999999999999,4.74213E-2,4.7421306611931634E-2,6.6119316341484158E-9],
+--R
+--R     [1.6499999999999999, 4.6820899999999999E-2, 4.6820861507343305E-2,
+--R      - 3.8492656694033567E-8]
+--R     ,
+--R
+--R     [1.6599999999999999, 4.6228400000000003E-2, 4.622844132120392E-2,
+--R      4.1321203916866445E-8]
+--R     ,
+--R
+--R     [1.6699999999999999, 4.5643900000000001E-2, 4.5643930585794489E-2,
+--R      3.0585794487392182E-8]
+--R     ,
+--R
+--R     [1.6799999999999999, 4.5067200000000002E-2, 4.5067215668940779E-2,
+--R      1.5668940776814022E-8]
+--R     ,
+--R
+--R     [1.6899999999999999, 4.4498200000000002E-2, 4.4498184740800251E-2,
+--R      - 1.5259199750983221E-8]
+--R     ,
+--R    [1.7,4.3936700000000002E-2,4.3936727741353321E-2,2.7741353318677664E-8],
+--R    [1.71,4.3382700000000003E-2,4.3382736348575771E-2,3.6348575767342073E-8],
+--R    [1.72,4.2836100000000002E-2,4.283610394728473E-2,3.9472847282451262E-9],
+--R    [1.73,4.22967E-2,4.229672559863315E-2,2.559863315071409E-8],
+--R    [1.74,4.1764500000000003E-2,4.1764498010238606E-2,- 1.9897613973141048E-9],
+--R    [1.75,4.12393E-2,4.1239319506936156E-2,1.9506936156654664E-8],
+--R    [1.76,4.0721100000000003E-2,4.0721090002130152E-2,- 9.9978698514524567E-9],
+--R    [1.77,4.0209700000000001E-2,4.0209710969742136E-2,1.0969742135491511E-8],
+--R    [1.78,3.97051E-2,3.9705085416725308E-2,- 1.4583274692003823E-8],
+--R    [1.79,3.9207100000000002E-2,3.920711785615049E-2,1.7856150488770872E-8],
+--R    [1.8,3.8715699999999999E-2,3.8715714280832765E-2,1.4280832766333518E-8],
+--R
+--R     [1.8100000000000001, 3.8230800000000002E-2, 3.8230782137495319E-2,
+--R      - 1.7862504683718861E-8]
+--R     ,
+--R    [1.8200000000000001,3.77522E-2,3.7752230301454859E-2,3.0301454859160692E-8],
+--R
+--R     [1.8300000000000001, 3.7280000000000001E-2, 3.7279969051817741E-2,
+--R      - 3.0948182259959989E-8]
+--R     ,
+--R
+--R     [1.8400000000000001, 3.6813899999999997E-2, 3.6813910047171126E-2,
+--R      1.0047171129790033E-8]
+--R     ,
+--R
+--R     [1.8500000000000001, 3.6353999999999997E-2, 3.6353966301762304E-2,
+--R      - 3.3698237693335908E-8]
+--R     ,
+--R
+--R     [1.8600000000000001, 3.5900099999999997E-2, 3.5900052162149899E-2,
+--R      - 4.7837850097876E-8]
+--R     ,
+--R
+--R     [1.8700000000000001, 3.54521E-2, 3.5452083284321229E-2,
+--R      - 1.6715678771705988E-8]
+--R     ,
+--R
+--R     [1.8799999999999999, 3.5009999999999999E-2, 3.5009976611261075E-2,
+--R      - 2.3388738924767782E-8]
+--R     ,
+--R
+--R     [1.8899999999999999, 3.4573699999999999E-2, 3.4573650350956942E-2,
+--R      - 4.9649043057375941E-8]
+--R     ,
+--R    [1.8999999999999999,3.4143E-2,3.414302395484918E-2,2.3954849180662929E-8],
+--R
+--R     [1.9099999999999999, 3.3717999999999998E-2, 3.3718018096686453E-2,
+--R      1.8096686454915911E-8]
+--R     ,
+--R
+--R     [1.9199999999999999, 3.3298599999999998E-2, 3.3298554651807068E-2,
+--R      - 4.5348192929950404E-8]
+--R     ,
+--R
+--R     [1.9299999999999999, 3.28846E-2, 3.2884556676814732E-2,
+--R      - 4.3323185268395736E-8]
+--R     ,
+--R
+--R     [1.9399999999999999, 3.2475900000000002E-2, 3.2475948389653855E-2,
+--R      4.8389653853342374E-8]
+--R     ,
+--R    [1.95,3.2072700000000003E-2,3.2072655150063287E-2,- 4.4849936715884997E-8],
+--R    [1.96,3.1674599999999997E-2,3.167460344041137E-2,3.4404113724573193E-9],
+--R    [1.97,3.1281700000000003E-2,3.1281720846895129E-2,2.0846895126824805E-8],
+--R    [1.98,3.0893899999999998E-2,3.0893936041105241E-2,3.6041105242606841E-8],
+--R    [1.99,3.0511199999999999E-2,3.0511178761929561E-2,- 2.1238070437717971E-8],
+--R    [2.,3.0133400000000001E-2,3.0133379797815663E-2,- 2.0202184338596885E-8]]
+--R                               Type: List List OnePointCompletion DoubleFloat
+--E 4
+
+@
+This table expresses the value of 
+$E_4$ with an argument range of 0.01 to 2.00.
+<<*>>=
+--S 5 of 7
+[[0.01,0.3283824,En(4,0.01),En(4,0.01)-0.3283824],_
+[0.02,0.3235264,En(4,0.02),En(4,0.02)-0.3235264],_
+[0.03,0.3187619,En(4,0.03),En(4,0.03)-0.3187619],_
+[0.04,0.3140855,En(4,0.04),En(4,0.04)-0.3140855],_
+[0.05,0.3094945,En(4,0.05),En(4,0.05)-0.3094945],_
+[0.06,0.3049863,En(4,0.06),En(4,0.06)-0.3049863],_
+[0.07,0.3005585,En(4,0.07),En(4,0.07)-0.3005585],_
+[0.08,0.2962089,En(4,0.08),En(4,0.08)-0.2962089],_
+[0.09,0.2919354,En(4,0.09),En(4,0.09)-0.2919354],_
+[0.10,0.2877361,En(4,0.10),En(4,0.10)-0.2877361],_
+[0.11,0.2836090,En(4,0.11),En(4,0.11)-0.2836090],_
+[0.12,0.2795524,En(4,0.12),En(4,0.12)-0.2795524],_
+[0.13,0.2755646,En(4,0.13),En(4,0.13)-0.2755646],_
+[0.14,0.2716439,En(4,0.14),En(4,0.14)-0.2716439],_
+[0.15,0.2677889,En(4,0.15),En(4,0.15)-0.2677889],_
+[0.16,0.2639979,En(4,0.16),En(4,0.16)-0.2639979],_
+[0.17,0.2602696,En(4,0.17),En(4,0.17)-0.2602696],_
+[0.18,0.2566026,En(4,0.18),En(4,0.18)-0.2566026],_
+[0.19,0.2529956,En(4,0.19),En(4,0.19)-0.2529956],_
+[0.20,0.2494472,En(4,0.20),En(4,0.20)-0.2494472],_
+[0.21,0.2459563,En(4,0.21),En(4,0.21)-0.2459563],_
+[0.22,0.2425216,En(4,0.22),En(4,0.22)-0.2425216],_
+[0.23,0.2391419,En(4,0.23),En(4,0.23)-0.2391419],_
+[0.24,0.2358162,En(4,0.24),En(4,0.24)-0.2358162],_
+[0.25,0.2325432,En(4,0.25),En(4,0.25)-0.2325432],_
+[0.26,0.2293221,En(4,0.26),En(4,0.26)-0.2293221],_
+[0.27,0.2261517,En(4,0.27),En(4,0.27)-0.2261517],_
+[0.28,0.2230311,En(4,0.28),En(4,0.28)-0.2230311],_
+[0.29,0.2199593,En(4,0.29),En(4,0.29)-0.2199593],_
+[0.30,0.2169352,En(4,0.30),En(4,0.30)-0.2169352],_
+[0.31,0.2139581,En(4,0.31),En(4,0.31)-0.2139581],_
+[0.32,0.2110270,En(4,0.32),En(4,0.32)-0.2110270],_
+[0.33,0.2081411,En(4,0.33),En(4,0.33)-0.2081411],_
+[0.34,0.2052994,En(4,0.34),En(4,0.34)-0.2052994],_
+[0.35,0.2025013,En(4,0.35),En(4,0.35)-0.2025013],_
+[0.36,0.1997458,En(4,0.36),En(4,0.36)-0.1997458],_
+[0.37,0.1970322,En(4,0.37),En(4,0.37)-0.1970322],_
+[0.38,0.1943597,En(4,0.38),En(4,0.38)-0.1943597],_
+[0.39,0.1917276,En(4,0.39),En(4,0.39)-0.1917276],_
+[0.40,0.1891352,En(4,0.40),En(4,0.40)-0.1891352],_
+[0.41,0.1865816,En(4,0.41),En(4,0.41)-0.1865816],_
+[0.42,0.1840664,En(4,0.42),En(4,0.42)-0.1840664],_
+[0.43,0.1815887,En(4,0.43),En(4,0.43)-0.1815887],_
+[0.44,0.1791479,En(4,0.44),En(4,0.44)-0.1791479],_
+[0.45,0.1767433,En(4,0.45),En(4,0.45)-0.1767433],_
+[0.46,0.1743744,En(4,0.46),En(4,0.46)-0.1743744],_
+[0.47,0.1720405,En(4,0.47),En(4,0.47)-0.1720405],_
+[0.48,0.1697410,En(4,0.48),En(4,0.48)-0.1697410],_
+[0.49,0.1674753,En(4,0.49),En(4,0.49)-0.1674753],_
+[0.50,0.1652428,En(4,0.50),En(4,0.50)-0.1652428],_
+[0.51,0.1630430,En(4,0.51),En(4,0.51)-0.1630430],_
+[0.52,0.1608753,En(4,0.52),En(4,0.52)-0.1608753],_
+[0.53,0.1587392,En(4,0.53),En(4,0.53)-0.1587392],_
+[0.54,0.1566341,En(4,0.54),En(4,0.54)-0.1566341],_
+[0.55,0.1545596,En(4,0.55),En(4,0.55)-0.1545596],_
+[0.56,0.1525150,En(4,0.56),En(4,0.56)-0.1525150],_
+[0.57,0.1505000,En(4,0.57),En(4,0.57)-0.1505000],_
+[0.58,0.1485139,En(4,0.58),En(4,0.58)-0.1485139],_
+[0.59,0.1465565,En(4,0.59),En(4,0.59)-0.1465565],_
+[0.60,0.1446271,En(4,0.60),En(4,0.60)-0.1446271],_
+[0.61,0.1427253,En(4,0.61),En(4,0.61)-0.1427253],_
+[0.62,0.1408507,En(4,0.62),En(4,0.62)-0.1408507],_
+[0.63,0.1390028,En(4,0.63),En(4,0.63)-0.1390028],_
+[0.64,0.1371813,En(4,0.64),En(4,0.64)-0.1371813],_
+[0.65,0.1353855,En(4,0.65),En(4,0.65)-0.1353855],_
+[0.66,0.1336153,En(4,0.66),En(4,0.66)-0.1336153],_
+[0.67,0.1318701,En(4,0.67),En(4,0.67)-0.1318701],_
+[0.68,0.1301495,En(4,0.68),En(4,0.68)-0.1301495],_
+[0.69,0.1284533,En(4,0.69),En(4,0.69)-0.1284533],_
+[0.70,0.1267808,En(4,0.70),En(4,0.70)-0.1267808],_
+[0.71,0.1251319,En(4,0.71),En(4,0.71)-0.1251319],_
+[0.72,0.1235061,En(4,0.72),En(4,0.72)-0.1235061],_
+[0.73,0.1219031,En(4,0.73),En(4,0.73)-0.1219031],_
+[0.74,0.1203224,En(4,0.74),En(4,0.74)-0.1203224],_
+[0.75,0.1187638,En(4,0.75),En(4,0.75)-0.1187638],_
+[0.76,0.1172270,En(4,0.76),En(4,0.76)-0.1172270],_
+[0.77,0.1157115,En(4,0.77),En(4,0.77)-0.1157115],_
+[0.78,0.1142170,En(4,0.78),En(4,0.78)-0.1142170],_
+[0.79,0.1127433,En(4,0.79),En(4,0.79)-0.1127433],_
+[0.80,0.1112900,En(4,0.80),En(4,0.80)-0.1112900],_
+[0.81,0.1098567,En(4,0.81),En(4,0.81)-0.1098567],_
+[0.82,0.1084433,En(4,0.82),En(4,0.82)-0.1084433],_
+[0.83,0.1070493,En(4,0.83),En(4,0.83)-0.1070493],_
+[0.84,0.1056744,En(4,0.84),En(4,0.84)-0.1056744],_
+[0.85,0.1043185,En(4,0.85),En(4,0.85)-0.1043185],_
+[0.86,0.1029812,En(4,0.86),En(4,0.86)-0.1029812],_
+[0.87,0.1016622,En(4,0.87),En(4,0.87)-0.1016622],_
+[0.88,0.1003612,En(4,0.88),En(4,0.88)-0.1003612],_
+[0.89,0.0990780,En(4,0.89),En(4,0.89)-0.0990780],_
+[0.90,0.0978123,En(4,0.90),En(4,0.90)-0.0978123],_
+[0.91,0.0965639,En(4,0.91),En(4,0.91)-0.0965639],_
+[0.92,0.0953324,En(4,0.92),En(4,0.92)-0.0953324],_
+[0.93,0.0941177,En(4,0.93),En(4,0.93)-0.0941177],_
+[0.94,0.0929194,En(4,0.94),En(4,0.94)-0.0929194],_
+[0.95,0.0917374,En(4,0.95),En(4,0.95)-0.0917374],_
+[0.96,0.0905713,En(4,0.96),En(4,0.96)-0.0905713],_
+[0.97,0.0894211,En(4,0.97),En(4,0.97)-0.0894211],_
+[0.98,0.0882863,En(4,0.98),En(4,0.98)-0.0882863],_
+[0.99,0.0871669,En(4,0.99),En(4,0.99)-0.0871669],_
+[1.00,0.0860625,En(4,1.00),En(4,1.00)-0.0860625],_
+[1.01,0.0849730,En(4,1.01),En(4,1.01)-0.0849730],_
+[1.02,0.0838981,En(4,1.02),En(4,1.02)-0.0838981],_
+[1.03,0.0828376,En(4,1.03),En(4,1.03)-0.0828376],_
+[1.04,0.0817913,En(4,1.04),En(4,1.04)-0.0817913],_
+[1.05,0.0807590,En(4,1.05),En(4,1.05)-0.0807590],_
+[1.06,0.0797406,En(4,1.06),En(4,1.06)-0.0797406],_
+[1.07,0.0787357,En(4,1.07),En(4,1.07)-0.0787357],_
+[1.08,0.0777442,En(4,1.08),En(4,1.08)-0.0777442],_
+[1.09,0.0767659,En(4,1.09),En(4,1.09)-0.0767659],_
+[1.10,0.0758007,En(4,1.10),En(4,1.10)-0.0758007],_
+[1.11,0.0748483,En(4,1.11),En(4,1.11)-0.0748483],_
+[1.12,0.0739085,En(4,1.12),En(4,1.12)-0.0739085],_
+[1.13,0.0729812,En(4,1.13),En(4,1.13)-0.0729812],_
+[1.14,0.0720661,En(4,1.14),En(4,1.14)-0.0720661],_
+[1.15,0.0711632,En(4,1.15),En(4,1.15)-0.0711632],_
+[1.16,0.0702722,En(4,1.16),En(4,1.16)-0.0702722],_
+[1.17,0.0693930,En(4,1.17),En(4,1.17)-0.0693930],_
+[1.18,0.0685253,En(4,1.18),En(4,1.18)-0.0685253],_
+[1.19,0.0676691,En(4,1.19),En(4,1.19)-0.0676691],_
+[1.20,0.0668242,En(4,1.20),En(4,1.20)-0.0668242],_
+[1.21,0.0659904,En(4,1.21),En(4,1.21)-0.0659904],_
+[1.22,0.0651675,En(4,1.22),En(4,1.22)-0.0651675],_
+[1.23,0.0643555,En(4,1.23),En(4,1.23)-0.0643555],_
+[1.24,0.0635540,En(4,1.24),En(4,1.24)-0.0635540],_
+[1.25,0.0627631,En(4,1.25),En(4,1.25)-0.0627631],_
+[1.26,0.0619825,En(4,1.26),En(4,1.26)-0.0619825],_
+[1.27,0.0612122,En(4,1.27),En(4,1.27)-0.0612122],_
+[1.28,0.0604519,En(4,1.28),En(4,1.28)-0.0604519],_
+[1.29,0.0597015,En(4,1.29),En(4,1.29)-0.0597015],_
+[1.30,0.0589609,En(4,1.30),En(4,1.30)-0.0589609],_
+[1.31,0.0582299,En(4,1.31),En(4,1.31)-0.0582299],_
+[1.32,0.0575085,En(4,1.32),En(4,1.32)-0.0575085],_
+[1.33,0.0567964,En(4,1.33),En(4,1.33)-0.0567964],_
+[1.34,0.0560936,En(4,1.34),En(4,1.34)-0.0560936],_
+[1.35,0.0553998,En(4,1.35),En(4,1.35)-0.0553998],_
+[1.36,0.0547151,En(4,1.36),En(4,1.36)-0.0547151],_
+[1.37,0.0540393,En(4,1.37),En(4,1.37)-0.0540393],_
+[1.38,0.0533722,En(4,1.38),En(4,1.38)-0.0533722],_
+[1.39,0.0527137,En(4,1.39),En(4,1.39)-0.0527137],_
+[1.40,0.0520637,En(4,1.40),En(4,1.40)-0.0520637],_
+[1.41,0.0514222,En(4,1.41),En(4,1.41)-0.0514222],_
+[1.42,0.0507889,En(4,1.42),En(4,1.42)-0.0507889],_
+[1.43,0.0501637,En(4,1.43),En(4,1.43)-0.0501637],_
+[1.44,0.0495466,En(4,1.44),En(4,1.44)-0.0495466],_
+[1.45,0.0489374,En(4,1.45),En(4,1.45)-0.0489374],_
+[1.46,0.0483361,En(4,1.46),En(4,1.46)-0.0483361],_
+[1.47,0.0477425,En(4,1.47),En(4,1.47)-0.0477425],_
+[1.48,0.0471565,En(4,1.48),En(4,1.48)-0.0471565],_
+[1.49,0.0465780,En(4,1.49),En(4,1.49)-0.0465780],_
+[1.50,0.0460070,En(4,1.50),En(4,1.50)-0.0460070],_
+[1.51,0.0454432,En(4,1.51),En(4,1.51)-0.0454432],_
+[1.52,0.0448867,En(4,1.52),En(4,1.52)-0.0448867],_
+[1.53,0.0443372,En(4,1.53),En(4,1.53)-0.0443372],_
+[1.54,0.0437948,En(4,1.54),En(4,1.54)-0.0437948],_
+[1.55,0.0432593,En(4,1.55),En(4,1.55)-0.0432593],_
+[1.56,0.0427307,En(4,1.56),En(4,1.56)-0.0427307],_
+[1.57,0.0422087,En(4,1.57),En(4,1.57)-0.0422087],_
+[1.58,0.0416935,En(4,1.58),En(4,1.58)-0.0416935],_
+[1.59,0.0411847,En(4,1.59),En(4,1.59)-0.0411847],_
+[1.60,0.0406825,En(4,1.60),En(4,1.60)-0.0406825],_
+[1.61,0.0401866,En(4,1.61),En(4,1.61)-0.0401866],_
+[1.62,0.0396970,En(4,1.62),En(4,1.62)-0.0396970],_
+[1.63,0.0392136,En(4,1.63),En(4,1.63)-0.0392136],_
+[1.64,0.0387364,En(4,1.64),En(4,1.64)-0.0387364],_
+[1.65,0.0382652,En(4,1.65),En(4,1.65)-0.0382652],_
+[1.66,0.0377999,En(4,1.66),En(4,1.66)-0.0377999],_
+[1.67,0.0373406,En(4,1.67),En(4,1.67)-0.0373406],_
+[1.68,0.0368870,En(4,1.68),En(4,1.68)-0.0368870],_
+[1.69,0.0364392,En(4,1.69),En(4,1.69)-0.0364392],_
+[1.70,0.0359970,En(4,1.70),En(4,1.70)-0.0359970],_
+[1.71,0.0355604,En(4,1.71),En(4,1.71)-0.0355604],_
+[1.72,0.0351293,En(4,1.72),En(4,1.72)-0.0351293],_
+[1.73,0.0347037,En(4,1.73),En(4,1.73)-0.0347037],_
+[1.74,0.0342834,En(4,1.74),En(4,1.74)-0.0342834],_
+[1.75,0.0338684,En(4,1.75),En(4,1.75)-0.0338684],_
+[1.76,0.0334586,En(4,1.76),En(4,1.76)-0.0334586],_
+[1.77,0.0330539,En(4,1.77),En(4,1.77)-0.0330539],_
+[1.78,0.0326544,En(4,1.78),En(4,1.78)-0.0326544],_
+[1.79,0.0322598,En(4,1.79),En(4,1.79)-0.0322598],_
+[1.80,0.0318702,En(4,1.80),En(4,1.80)-0.0318702],_
+[1.81,0.0314855,En(4,1.81),En(4,1.81)-0.0314855],_
+[1.82,0.0311056,En(4,1.82),En(4,1.82)-0.0311056],_
+[1.83,0.0307304,En(4,1.83),En(4,1.83)-0.0307304],_
+[1.84,0.0303599,En(4,1.84),En(4,1.84)-0.0303599],_
+[1.85,0.0299941,En(4,1.85),En(4,1.85)-0.0299941],_
+[1.86,0.0296328,En(4,1.86),En(4,1.86)-0.0296328],_
+[1.87,0.0292761,En(4,1.87),En(4,1.87)-0.0292761],_
+[1.88,0.0289238,En(4,1.88),En(4,1.88)-0.0289238],_
+[1.89,0.0285759,En(4,1.89),En(4,1.89)-0.0285759],_
+[1.90,0.0282323,En(4,1.90),En(4,1.90)-0.0282323],_
+[1.91,0.0278930,En(4,1.91),En(4,1.91)-0.0278930],_
+[1.92,0.0275579,En(4,1.92),En(4,1.92)-0.0275579],_
+[1.93,0.0272270,En(4,1.93),En(4,1.93)-0.0272270],_
+[1.94,0.0269002,En(4,1.94),En(4,1.94)-0.0269002],_
+[1.95,0.0265775,En(4,1.95),En(4,1.95)-0.0265775],_
+[1.96,0.0262587,En(4,1.96),En(4,1.96)-0.0262587],_
+[1.97,0.0259440,En(4,1.97),En(4,1.97)-0.0259440],_
+[1.98,0.0256331,En(4,1.98),En(4,1.98)-0.0256331],_
+[1.99,0.0253261,En(4,1.99),En(4,1.99)-0.0253261],_
+[2.00,0.0250228,En(4,2.00),En(4,2.00)-0.0250228]]
+--R 
+--R
+--R   (5)
+--R   [[1.0E-2,0.32838240000000002,0.32838235603577381,- 4.3964226204007417E-8],
+--R    [2.0E-2,0.32352639999999999,0.32352643582573859,3.5825738597949908E-8],
+--R
+--R     [2.9999999999999999E-2, 0.31876189999999999, 0.318761867644201,
+--R      - 3.2355798984529116E-8]
+--R     ,
+--R
+--R     [4.0000000000000001E-2, 0.31408550000000002, 0.3140854938275166,
+--R      - 6.1724834132803608E-9]
+--R     ,
+--R
+--R     [5.0000000000000003E-2, 0.30949450000000001, 0.30949449400443008,
+--R      - 5.9955699294178544E-9]
+--R     ,
+--R
+--R     [5.9999999999999998E-2, 0.30498629999999999, 0.30498629353000445,
+--R      - 6.4699955393265896E-9]
+--R     ,
+--R
+--R     [7.0000000000000007E-2, 0.30055850000000001, 0.30055851077336515,
+--R      1.0773365144434166E-8]
+--R     ,
+--R    [8.0000000000000002E-2,0.2962089,0.29620892264764853,2.2647648534324105E-8],
+--R
+--R     [8.9999999999999997E-2, 0.29193540000000001, 0.29193544025523149,
+--R      4.0255231481545195E-8]
+--R     ,
+--R
+--R     [0.10000000000000001, 0.28773609999999999, 0.28773609074837719,
+--R      - 9.2516228011874091E-9]
+--R     ,
+--R    [0.11,0.283609,0.2836090032896208,3.2896207979860037E-9],
+--R    [0.12,0.27955239999999998,0.27955239786156211,- 2.1384378712241414E-9],
+--R    [0.13,0.27556459999999999,0.27556457613853869,- 2.3861461306839971E-8],
+--R
+--R     [0.14000000000000001, 0.27164389999999999, 0.27164391389899217,
+--R      1.3898992179406378E-8]
+--R     ,
+--R    [0.14999999999999999,0.2677889,0.26778885461965246,- 4.5380347535317611E-8],
+--R    [0.16,0.26399790000000001,0.26399790399625528,3.9962552711436672E-9],
+--R
+--R     [0.17000000000000001, 0.26026959999999999, 0.26026962520418123,
+--R      2.5204181242077794E-8]
+--R     ,
+--R
+--R     [0.17999999999999999, 0.25660260000000001, 0.25660263475941625,
+--R      3.4759416234209084E-8]
+--R     ,
+--R    [0.19,0.25299559999999999,0.25299559887329914,- 1.1267008437343407E-9],
+--R
+--R     [0.20000000000000001, 0.24944720000000001, 0.24944723021833587,
+--R      3.021833586136502E-8]
+--R     ,
+--R
+--R     [0.20999999999999999, 0.24595629999999999, 0.24595628503986891,
+--R      - 1.496013107837868E-8]
+--R     ,
+--R    [0.22,0.2425216,0.24252156056149116,- 3.9438508847577936E-8],
+--R
+--R     [0.23000000000000001, 0.23914189999999999, 0.23914189264206476,
+--R      - 7.3579352333208448E-9]
+--R     ,
+--R    [0.23999999999999999,0.2358162,0.235816153649895,- 4.6350105004089315E-8],
+--R    [0.25,0.23254320000000001,0.232543250525623,5.0525622991015595E-8],
+--R    [0.26000000000000001,0.2293221,0.22932212301015453,2.3010154531766247E-8],
+--R
+--R     [0.27000000000000002, 0.22615170000000001, 0.22615174201774482,
+--R      4.2017744811273516E-8]
+--R     ,
+--R
+--R     [0.28000000000000003, 0.22303110000000001, 0.22303110813742405,
+--R      8.1374240401554943E-9]
+--R     ,
+--R    [0.28999999999999998,0.2199593,0.21995925024844767,- 4.9751552322341297E-8],
+--R
+--R     [0.29999999999999999, 0.21693519999999999, 0.2169352242375045,
+--R      2.4237504503421547E-8]
+--R     ,
+--R    [0.31,0.21395810000000001,0.21395811180711269,1.1807112676454068E-8],
+--R
+--R     [0.32000000000000001, 0.21102699999999999, 0.21102701936604468,
+--R      1.9366044684554495E-8]
+--R     ,
+--R    [0.33000000000000002,0.2081411,0.20814107699380749,- 2.3006192506613843E-8],
+--R
+--R     [0.34000000000000002, 0.20529939999999999, 0.20529943747220336,
+--R      3.7472203368027479E-8]
+--R     ,
+--R    [0.34999999999999998,0.2025013,0.20250127537784185,- 2.4622158145692907E-8],
+--R    [0.35999999999999999,0.1997458,0.19974578623019815,- 1.3769801854301988E-8],
+--R    [0.37,0.19703219999999999,0.19703218569043029,- 1.4309569695836188E-8],
+--R    [0.38,0.1943597,0.19435970880670123,8.8067012293802094E-9],
+--R    [0.39000000000000001,0.1917276,0.19172760930221217,9.3022121672170499E-9],
+--R    [0.40000000000000002,0.1891352,0.18913515890255378,- 4.1097446223936629E-8],
+--R
+--R     [0.40999999999999998, 0.18658159999999999, 0.18658164669933056,
+--R      4.6699330569222042E-8]
+--R     ,
+--R
+--R     [0.41999999999999998, 0.18406639999999999, 0.18406637854731811,
+--R      - 2.1452681880917979E-8]
+--R     ,
+--R
+--R     [0.42999999999999999, 0.18158869999999999, 0.18158867649268154,
+--R      - 2.3507318452908876E-8]
+--R     ,
+--R    [0.44,0.1791479,0.17914787823001868,- 2.1769981317643072E-8],
+--R
+--R     [0.45000000000000001, 0.17674329999999999, 0.17674333658619995,
+--R      3.6586199958499321E-8]
+--R     ,
+--R
+--R     [0.46000000000000002, 0.17437440000000001, 0.17437441902916206,
+--R      1.9029162051653614E-8]
+--R     ,
+--R
+--R     [0.46999999999999997, 0.17204050000000001, 0.17204050719997591,
+--R      7.1999758932683733E-9]
+--R     ,
+--R    [0.47999999999999998,0.169741,0.16974099646665652,- 3.5333434789119877E-9],
+--R
+--R     [0.48999999999999999, 0.16747529999999999, 0.16747529549831219,
+--R      - 4.5016878003067973E-9]
+--R     ,
+--R    [0.5,0.1652428,0.16524282585834804,2.5858348046137181E-8],
+--R
+--R     [0.51000000000000001, 0.16304299999999999, 0.16304302161554463,
+--R      2.161554463198101E-8]
+--R     ,
+--R    [0.52000000000000002,0.1608753,0.16087532897192483,2.8971924831422413E-8],
+--R    [0.53000000000000003,0.1587392,0.15873920590641022,5.9064102220229842E-9],
+--R    [0.54000000000000004,0.1566341,0.15663412183334352,2.1833343522015269E-8],
+--R
+--R     [0.55000000000000004, 0.15455959999999999, 0.15455955727502388,
+--R      - 4.2724976112573643E-8]
+--R     ,
+--R
+--R     [0.56000000000000005, 0.15251500000000001, 0.15251500354746483,
+--R      3.5474648218958293E-9]
+--R     ,
+--R
+--R     [0.56999999999999995, 0.15049999999999999, 0.15049996245864372,
+--R      - 3.7541356273651516E-8]
+--R     ,
+--R    [0.57999999999999996,0.1485139,0.14851394601856155,4.6018561544736158E-8],
+--R
+--R     [0.58999999999999997, 0.14655650000000001, 0.14655647616048229,
+--R      - 2.3839517721002679E-8]
+--R     ,
+--R
+--R     [0.59999999999999998, 0.14462710000000001, 0.1446270844727626,
+--R      - 1.5527237412493733E-8]
+--R     ,
+--R    [0.60999999999999999,0.1427253,0.14272531194072449,1.1940724492509602E-8],
+--R    [0.62,0.1408507,0.14085070869805835,8.6980583569040704E-9],
+--R    [0.63,0.13900280000000001,0.13900283378727951,3.3787279501984457E-8],
+--R
+--R     [0.64000000000000001, 0.13718130000000001, 0.13718125492879019,
+--R      - 4.5071209819891322E-8]
+--R     ,
+--R
+--R     [0.65000000000000002, 0.13538549999999999, 0.13538554829812915,
+--R      4.8298129162738235E-8]
+--R     ,
+--R
+--R     [0.66000000000000003, 0.13361529999999999, 0.13361529831101665,
+--R      - 1.688983342074124E-9]
+--R     ,
+--R
+--R     [0.67000000000000004, 0.13187009999999999, 0.13187009741582595,
+--R      - 2.5841740414200842E-9]
+--R     ,
+--R    [0.68000000000000005,0.1301495,0.13014954589313665,4.5893136652042088E-8],
+--R
+--R     [0.68999999999999995, 0.12845329999999999, 0.12845325166204447,
+--R      - 4.8337955527166798E-8]
+--R     ,
+--R    [0.69999999999999996,0.1267808,0.12678083009292157,3.0092921571300835E-8],
+--R
+--R     [0.70999999999999996, 0.12513189999999999, 0.1251319038263401,
+--R      3.8263401058724611E-9]
+--R     ,
+--R
+--R     [0.71999999999999997, 0.12350609999999999, 0.12350610259788675,
+--R      2.5978867529419247E-9]
+--R     ,
+--R    [0.72999999999999998,0.1219031,0.12190306306861284,- 3.6931387156768913E-8],
+--R    [0.73999999999999999,0.1203224,0.12032242866087833,2.8660878337305462E-8],
+--R    [0.75,0.1187638,0.11876384939936065,4.9399360643742618E-8],
+--R    [0.76000000000000001,0.117227,0.1172269817570131,- 1.8242986898897584E-8],
+--R
+--R     [0.77000000000000002, 0.11571149999999999, 0.1157114885057679,
+--R      - 1.1494232093900436E-8]
+--R     ,
+--R    [0.78000000000000003,0.114217,0.11421703857179058,3.8571790580976817E-8],
+--R    [0.79000000000000004,0.1127433,0.11274330689510217,6.895102169779399E-9],
+--R    [0.80000000000000004,0.11129,0.11128997429339493,- 2.570660506684419E-8],
+--R    [0.81000000000000005,0.1098567,0.10985672732987711,2.7329877111403889E-8],
+--R
+--R     [0.81999999999999995, 0.10844330000000001, 0.10844325818498929,
+--R      - 4.1815010717871637E-8]
+--R     ,
+--R    [0.82999999999999996,0.1070493,0.10704926453184345,- 3.5468156550644281E-8],
+--R    [0.83999999999999997,0.1056744,0.10567444941524373,4.9415243730255298E-8],
+--R
+--R     [0.84999999999999998, 0.10431849999999999, 0.10431852113415277,
+--R      2.1134152775048598E-8]
+--R     ,
+--R
+--R     [0.85999999999999999, 0.10298119999999999, 0.10298119312747675,
+--R      - 6.8725232449384777E-9]
+--R     ,
+--R    [0.87,0.10166219999999999,0.10166218386304593,- 1.6136954064660536E-8],
+--R    [0.88,0.1003612,0.10036121672967431,1.6729674312543352E-8],
+--R
+--R     [0.89000000000000001, 9.9077999999999999E-2, 9.9078019932187969E-2,
+--R      1.9932187969584625E-8]
+--R     ,
+--R
+--R     [0.90000000000000002, 9.7812300000000005E-2, 9.7812326389315099E-2,
+--R      2.6389315094244026E-8]
+--R     ,
+--R
+--R     [0.91000000000000003, 9.6563899999999994E-2, 9.6563873634337494E-2,
+--R      - 2.6365662500471565E-8]
+--R     ,
+--R
+--R     [0.92000000000000004, 9.5332399999999998E-2, 9.5332403718406081E-2,
+--R      3.7184060830419696E-9]
+--R     ,
+--R
+--R     [0.93000000000000005, 9.4117699999999999E-2, 9.4117663116428885E-2,
+--R      - 3.6883571113976998E-8]
+--R     ,
+--R
+--R     [0.93999999999999995, 9.2919399999999999E-2, 9.2919402635442322E-2,
+--R      2.6354423227070711E-9]
+--R     ,
+--R
+--R     [0.94999999999999996, 9.1737399999999997E-2, 9.1737377325382147E-2,
+--R      - 2.2674617849993695E-8]
+--R     ,
+--R
+--R     [0.95999999999999996, 9.0571299999999993E-2, 9.0571346392172847E-2,
+--R      4.6392172853293445E-8]
+--R     ,
+--R
+--R     [0.96999999999999997, 8.9421100000000003E-2, 8.9421073113058108E-2,
+--R      - 2.6886941895121197E-8]
+--R     ,
+--R
+--R     [0.97999999999999998, 8.8286299999999998E-2, 8.8286324754098505E-2,
+--R      2.4754098507107081E-8]
+--R     ,
+--R
+--R     [0.98999999999999999, 8.7166900000000005E-2, 8.7166872489765013E-2,
+--R      - 2.7510234992811355E-8]
+--R     ,
+--R    [1.,8.60625E-2,8.606249132456073E-2,- 8.6754392697452332E-9],
+--R    [1.01,8.4973000000000007E-2,8.497296001660537E-2,- 3.9983394636844416E-8],
+--R    [1.02,8.3898100000000003E-2,8.3898061003119584E-2,- 3.8996880419306379E-8],
+--R    [1.03,8.2837599999999997E-2,8.2837580327749516E-2,- 1.967225048138399E-8],
+--R    [1.04,8.1791299999999997E-2,8.179130756967358E-2,7.5696735823971295E-9],
+--R    [1.05,8.0758999999999997E-2,8.0759035774436022E-2,3.5774436024649248E-8],
+--R
+--R     [1.0600000000000001, 7.9740599999999995E-2, 7.9740561386454245E-2,
+--R      - 3.8613545749743849E-8]
+--R     ,
+--R
+--R     [1.0700000000000001, 7.8735700000000006E-2, 7.8735684183148108E-2,
+--R      - 1.5816851897665352E-8]
+--R     ,
+--R
+--R     [1.0800000000000001, 7.7744199999999999E-2, 7.774420721064286E-2,
+--R      7.2106428605778206E-9]
+--R     ,
+--R
+--R     [1.0900000000000001, 7.6765899999999998E-2, 7.6765936720997435E-2,
+--R      3.6720997437234004E-8]
+--R     ,
+--R
+--R     [1.1000000000000001, 7.5800699999999999E-2, 7.5800682110913065E-2,
+--R      - 1.7889086934008702E-8]
+--R     ,
+--R
+--R     [1.1100000000000001, 7.4848300000000006E-2, 7.4848255861878349E-2,
+--R      - 4.4138121657599783E-8]
+--R     ,
+--R
+--R     [1.1200000000000001, 7.3908500000000002E-2, 7.3908473481708176E-2,
+--R      - 2.6518291826316265E-8]
+--R     ,
+--R
+--R     [1.1299999999999999, 7.2981199999999996E-2, 7.2981153447436026E-2,
+--R      - 4.6552563970347904E-8]
+--R     ,
+--R
+--R     [1.1399999999999999, 7.2066099999999994E-2, 7.2066117149520492E-2,
+--R      1.7149520498138671E-8]
+--R     ,
+--R
+--R     [1.1499999999999999, 7.1163199999999996E-2, 7.1163188837328195E-2,
+--R      - 1.1162671800790669E-8]
+--R     ,
+--R
+--R     [1.1599999999999999, 7.0272200000000007E-2, 7.027219556585651E-2,
+--R      - 4.4341434968231397E-9]
+--R     ,
+--R
+--R     [1.1699999999999999, 6.9392999999999996E-2, 6.9392967143661166E-2,
+--R      - 3.2856338830211662E-8]
+--R     ,
+--R
+--R     [1.1799999999999999, 6.8525299999999997E-2, 6.8525336081954685E-2,
+--R      3.6081954687960938E-8]
+--R     ,
+--R
+--R     [1.1899999999999999, 6.7669099999999996E-2, 6.7669137544842786E-2,
+--R      3.7544842790282473E-8]
+--R     ,
+--R    [1.2,6.68242E-2,6.6824209300667584E-2,9.300667583311828E-9],
+--R    [1.21,6.5990400000000005E-2,6.5990391674426857E-2,- 8.3255731475606609E-9],
+--R    [1.22,6.5167500000000003E-2,6.5167527501239941E-2,2.7501239938110267E-8],
+--R    [1.23,6.4355499999999996E-2,6.4355462080831385E-2,- 3.7919168610622833E-8],
+--R    [1.24,6.3553999999999999E-2,6.3554043133005847E-2,4.313300584757318E-8],
+--R    [1.25,6.2763100000000002E-2,6.2763120754086868E-2,2.0754086865748533E-8],
+--R    [1.26,6.1982500000000003E-2,6.1982547374293873E-2,4.7374293869750783E-8],
+--R    [1.27,6.1212200000000001E-2,6.1212177716032781E-2,- 2.2283967220093626E-8],
+--R    [1.28,6.0451900000000003E-2,6.0451868753076454E-2,- 3.124692354861125E-8],
+--R    [1.29,5.9701499999999998E-2,5.9701479670610937E-2,- 2.0329389061046754E-8],
+--R    [1.3,5.8960899999999997E-2,5.8960871826125583E-2,- 2.8173874414005873E-8],
+--R
+--R     [1.3100000000000001, 5.8229900000000001E-2, 5.822990871112519E-2,
+--R      8.7111251892424413E-9]
+--R     ,
+--R
+--R     [1.3200000000000001, 5.7508499999999997E-2, 5.7508455913643328E-2,
+--R      - 4.4086356669470472E-8]
+--R     ,
+--R
+--R     [1.3300000000000001, 5.6796399999999997E-2, 5.6796381081534952E-2,
+--R      - 1.8918465044537314E-8]
+--R     ,
+--R
+--R     [1.3400000000000001, 5.60936E-2, 5.6093553886531214E-2,
+--R      - 4.6113468786523892E-8]
+--R     ,
+--R
+--R     [1.3500000000000001, 5.5399799999999999E-2, 5.5399845989034427E-2,
+--R      4.5989034427873499E-8]
+--R     ,
+--R
+--R     [1.3600000000000001, 5.4715100000000003E-2, 5.4715131003636563E-2,
+--R      3.1003636560833492E-8]
+--R     ,
+--R
+--R     [1.3700000000000001, 5.4039299999999998E-2, 5.4039284465342098E-2,
+--R      - 1.5534657900329041E-8]
+--R     ,
+--R
+--R     [1.3799999999999999, 5.3372200000000002E-2, 5.3372183796479428E-2,
+--R      - 1.6203520573909724E-8]
+--R     ,
+--R
+--R     [1.3899999999999999, 5.2713700000000002E-2, 5.2713708274280791E-2,
+--R      8.2742807883118275E-9]
+--R     ,
+--R
+--R     [1.3999999999999999, 5.2063699999999997E-2, 5.206373899911769E-2,
+--R      3.8999117692173346E-8]
+--R     ,
+--R
+--R     [1.4099999999999999, 5.1422200000000001E-2, 5.1422158863374548E-2,
+--R      - 4.1136625453241926E-8]
+--R     ,
+--R
+--R     [1.4199999999999999, 5.0788899999999998E-2, 5.0788852520943208E-2,
+--R      - 4.7479056790311613E-8]
+--R     ,
+--R
+--R     [1.4299999999999999, 5.0163699999999999E-2, 5.0163706357327698E-2,
+--R      6.357327698991444E-9]
+--R     ,
+--R
+--R     [1.4399999999999999, 4.9546600000000003E-2, 4.9546608460339536E-2,
+--R      8.4603395331117603E-9]
+--R     ,
+--R    [1.45,4.8937399999999999E-2,4.8937448591373334E-2,4.859137333473873E-8],
+--R    [1.46,4.83361E-2,4.833611815724749E-2,1.8157247490269146E-8],
+--R    [1.47,4.77425E-2,4.7742510182596301E-2,1.0182596300867264E-8],
+--R    [1.48,4.7156499999999997E-2,4.7156519282801249E-2,1.9282801251574444E-8],
+--R    [1.49,4.6578000000000001E-2,4.6578041637448199E-2,4.1637448197628935E-8],
+--R    [1.5,4.6006999999999999E-2,4.6006974964299521E-2,- 2.503570047801551E-8],
+--R    [1.51,4.5443200000000003E-2,4.5443218493767132E-2,1.8493767128813232E-8],
+--R    [1.52,4.4886700000000002E-2,4.4886672943877548E-2,- 2.7056122453572584E-8],
+--R    [1.53,4.43372E-2,4.4337240495715358E-2,4.0495715357413697E-8],
+--R    [1.54,4.3794800000000002E-2,4.3794824769334884E-2,2.4769334881769023E-8],
+--R    [1.55,4.3259300000000001E-2,4.3259330800131675E-2,3.0800131674280085E-8],
+--R
+--R     [1.5600000000000001, 4.2730700000000003E-2, 4.2730665015658725E-2,
+--R      - 3.4984341278077036E-8]
+--R     ,
+--R
+--R     [1.5700000000000001, 4.2208700000000002E-2, 4.2208735212882098E-2,
+--R      3.5212882096291587E-8]
+--R     ,
+--R
+--R     [1.5800000000000001, 4.1693500000000001E-2, 4.1693450535863763E-2,
+--R      - 4.9464136238352996E-8]
+--R     ,
+--R
+--R     [1.5900000000000001, 4.1184699999999998E-2, 4.1184721453862164E-2,
+--R      2.1453862165954352E-8]
+--R     ,
+--R
+--R     [1.6000000000000001, 4.0682500000000003E-2, 4.0682459739842872E-2,
+--R      - 4.0260157131710717E-8]
+--R     ,
+--R
+--R     [1.6100000000000001, 4.0186600000000003E-2, 4.0186578449386889E-2,
+--R      - 2.1550613113485717E-8]
+--R     ,
+--R
+--R     [1.6200000000000001, 3.9697000000000003E-2, 3.9696991899992498E-2,
+--R      - 8.1000075050075004E-9]
+--R     ,
+--R
+--R     [1.6299999999999999, 3.9213600000000001E-2, 3.9213615650758454E-2,
+--R      1.5650758453111813E-8]
+--R     ,
+--R
+--R     [1.6399999999999999, 3.8736399999999997E-2, 3.8736366482441345E-2,
+--R      - 3.3517558652162993E-8]
+--R     ,
+--R
+--R     [1.6499999999999999, 3.8265199999999999E-2, 3.8265162377879226E-2,
+--R      - 3.7622120772906609E-8]
+--R     ,
+--R
+--R     [1.6599999999999999, 3.7799899999999997E-2, 3.7799922502774017E-2,
+--R      2.2502774019161897E-8]
+--R     ,
+--R
+--R     [1.6699999999999999, 3.7340600000000002E-2, 3.7340567186823333E-2,
+--R      - 3.2813176668866628E-8]
+--R     ,
+--R
+--R     [1.6799999999999999, 3.6887000000000003E-2, 3.6887017905196488E-2,
+--R      1.7905196485201724E-8]
+--R     ,
+--R
+--R     [1.6899999999999999, 3.6439199999999998E-2, 3.6439197260345613E-2,
+--R      - 2.7396543852975519E-9]
+--R     ,
+--R    [1.7,3.5997000000000001E-2,3.5997028964144667E-2,2.8964144666021596E-8],
+--R    [1.71,3.5560399999999999E-2,3.5560437820352508E-2,3.7820352509487787E-8],
+--R    [1.72,3.5129300000000002E-2,3.5129349707387826E-2,4.9707387823894056E-8],
+--R    [1.73,3.4703699999999997E-2,3.4703691561414153E-2,- 8.4385858439839367E-9],
+--R    [1.74,3.4283399999999999E-2,3.4283391359727231E-2,- 8.6402727680900959E-9],
+--R    [1.75,3.38684E-2,3.3868378104435617E-2,- 2.1895564382423682E-8],
+--R    [1.76,3.3458599999999998E-2,3.3458581806433824E-2,- 1.8193566174440345E-8],
+--R    [1.77,3.3053899999999997E-2,3.3053933469655281E-2,3.3469655283391297E-8],
+--R    [1.78,3.26544E-2,3.2654365075608149E-2,- 3.4924391850710279E-8],
+--R    [1.79,3.2259799999999998E-2,3.2259809568177103E-2,9.5681771047906317E-9],
+--R    [1.8,3.1870200000000001E-2,3.187020083869585E-2,8.3869584888152104E-10],
+--R    [1.8100000000000001,3.14855E-2,3.1485473711279174E-2,- 2.628872082521827E-8]
+--R     ,
+--R
+--R     [1.8200000000000001, 3.1105600000000001E-2, 3.1105563928410965E-2,
+--R      - 3.6071589035180374E-8]
+--R     ,
+--R
+--R     [1.8300000000000001, 3.0730400000000001E-2, 3.073040813678209E-2,
+--R      8.1367820883859743E-9]
+--R     ,
+--R
+--R     [1.8400000000000001, 3.0359899999999999E-2, 3.0359943873375265E-2,
+--R      4.387337526612356E-8]
+--R     ,
+--R
+--R     [1.8500000000000001, 2.9994099999999999E-2, 2.9994109551789112E-2,
+--R      9.5517891131324806E-9]
+--R     ,
+--R
+--R     [1.8600000000000001, 2.9632800000000001E-2, 2.9632844448799496E-2,
+--R      4.4448799495222513E-8]
+--R     ,
+--R
+--R     [1.8700000000000001, 2.9276099999999999E-2, 2.9276088691150233E-2,
+--R      - 1.1308849766356044E-8]
+--R     ,
+--R
+--R     [1.8799999999999999, 2.89238E-2, 2.8923783242571027E-2,
+--R      - 1.6757428972224986E-8]
+--R     ,
+--R
+--R     [1.8899999999999999, 2.8575900000000001E-2, 2.8575869891020747E-2,
+--R      - 3.0108979254261925E-8]
+--R     ,
+--R
+--R     [1.8999999999999999, 2.8232299999999998E-2, 2.8232291236140537E-2,
+--R      - 8.7638594610528475E-9]
+--R     ,
+--R
+--R     [1.9099999999999999, 2.7893000000000001E-2, 2.7892990676930449E-2,
+--R      - 9.3230695524804119E-9]
+--R     ,
+--R    [1.9199999999999999,2.75579E-2,2.7557912399626863E-2,1.2399626863474067E-8],
+--R
+--R     [1.9299999999999999, 2.7227000000000001E-2, 2.7227001365790433E-2,
+--R      1.3657904321395797E-9]
+--R     ,
+--R
+--R     [1.9399999999999999, 2.6900199999999999E-2, 2.6900203300591483E-2,
+--R      3.300591484151072E-9]
+--R     ,
+--R    [1.95,2.65775E-2,2.6577464681296726E-2,- 3.5318703274500596E-8],
+--R    [1.96,2.6258699999999999E-2,2.6258732725946241E-2,3.2725946241124459E-8],
+--R    [1.97,2.5943999999999998E-2,2.5943955382222512E-2,- 4.4617777486544163E-8],
+--R    [1.98,2.5633099999999999E-2,2.5633081316501483E-2,- 1.8683498515664754E-8],
+--R    [1.99,2.5326100000000001E-2,2.5326059903094673E-2,- 4.0096905327274834E-8],
+--R    [2.,2.5022800000000001E-2,2.5022841213660458E-2,4.1213660456618229E-8]]
+--R                               Type: List List OnePointCompletion DoubleFloat
+--E 5
+
+@
+This table expresses the value of 
+$E_10$ with an argument range of 0.01 to 2.00.
+<<*>>=
+--S 6 of 7
+[[0.01,0.1098682,En(10,0.01),En(10,0.01)-0.1098682],_
+[0.02,0.1086395,En(10,0.02),En(10,0.02)-0.1086395],_
+[0.03,0.1074246,En(10,0.03),En(10,0.03)-0.1074246],_
+[0.04,0.1062236,En(10,0.04),En(10,0.04)-0.1062236],_
+[0.05,0.1050363,En(10,0.05),En(10,0.05)-0.1050363],_
+[0.06,0.1038624,En(10,0.06),En(10,0.06)-0.1038624],_
+[0.07,0.1027018,En(10,0.07),En(10,0.07)-0.1027018],_
+[0.08,0.1015544,En(10,0.08),En(10,0.08)-0.1015544],_
+[0.09,0.1004200,En(10,0.09),En(10,0.09)-0.1004200],_
+[0.10,0.0992984,En(10,0.10),En(10,0.10)-0.0992984],_
+[0.11,0.0981896,En(10,0.11),En(10,0.11)-0.0981896],_
+[0.12,0.0970934,En(10,0.12),En(10,0.12)-0.0970934],_
+[0.13,0.0960095,En(10,0.13),En(10,0.13)-0.0960095],_
+[0.14,0.0949380,En(10,0.14),En(10,0.14)-0.0949380],_
+[0.15,0.0938786,En(10,0.15),En(10,0.15)-0.0938786],_
+[0.16,0.0928312,En(10,0.16),En(10,0.16)-0.0928312],_
+[0.17,0.0917956,En(10,0.17),En(10,0.17)-0.0917956],_
+[0.18,0.0907718,En(10,0.18),En(10,0.18)-0.0907718],_
+[0.19,0.0897595,En(10,0.19),En(10,0.19)-0.0897595],_
+[0.20,0.0887587,En(10,0.20),En(10,0.20)-0.0887587],_
+[0.21,0.0877693,En(10,0.21),En(10,0.21)-0.0877693],_
+[0.22,0.0867910,En(10,0.22),En(10,0.22)-0.0867910],_
+[0.23,0.0858238,En(10,0.23),En(10,0.23)-0.0858238],_
+[0.24,0.0848675,En(10,0.24),En(10,0.24)-0.0848675],_
+[0.25,0.0839220,En(10,0.25),En(10,0.25)-0.0839220],_
+[0.26,0.0829872,En(10,0.26),En(10,0.26)-0.0829872],_
+[0.27,0.0820630,En(10,0.27),En(10,0.27)-0.0820630],_
+[0.28,0.0811492,En(10,0.28),En(10,0.28)-0.0811492],_
+[0.29,0.0802457,En(10,0.29),En(10,0.29)-0.0802457],_
+[0.30,0.0793524,En(10,0.30),En(10,0.30)-0.0793524],_
+[0.31,0.0784693,En(10,0.31),En(10,0.31)-0.0784693],_
+[0.32,0.0775960,En(10,0.32),En(10,0.32)-0.0775960],_
+[0.33,0.0767327,En(10,0.33),En(10,0.33)-0.0767327],_
+[0.34,0.0758790,En(10,0.34),En(10,0.34)-0.0758790],_
+[0.35,0.0750350,En(10,0.35),En(10,0.35)-0.0750350],_
+[0.36,0.0742006,En(10,0.36),En(10,0.36)-0.0742006],_
+[0.37,0.0733755,En(10,0.37),En(10,0.37)-0.0733755],_
+[0.38,0.0725597,En(10,0.38),En(10,0.38)-0.0725597],_
+[0.39,0.0717531,En(10,0.39),En(10,0.39)-0.0717531],_
+[0.40,0.0709557,En(10,0.40),En(10,0.40)-0.0709557],_
+[0.41,0.0701671,En(10,0.41),En(10,0.41)-0.0701671],_
+[0.42,0.0693875,En(10,0.42),En(10,0.42)-0.0693875],_
+[0.43,0.0686167,En(10,0.43),En(10,0.43)-0.0686167],_
+[0.44,0.0678545,En(10,0.44),En(10,0.44)-0.0678545],_
+[0.45,0.0671009,En(10,0.45),En(10,0.45)-0.0671009],_
+[0.46,0.0663558,En(10,0.46),En(10,0.46)-0.0663558],_
+[0.47,0.0656191,En(10,0.47),En(10,0.47)-0.0656191],_
+[0.48,0.0648907,En(10,0.48),En(10,0.48)-0.0648907],_
+[0.49,0.0641704,En(10,0.49),En(10,0.49)-0.0641704],_
+[0.50,0.0634583,En(10,0.50),En(10,0.50)-0.0634583],_
+[0.51,0.0627542,En(10,0.51),En(10,0.51)-0.0627542],_
+[0.52,0.0620580,En(10,0.52),En(10,0.52)-0.0620580],_
+[0.53,0.0613696,En(10,0.53),En(10,0.53)-0.0613696],_
+[0.54,0.0606889,En(10,0.54),En(10,0.54)-0.0606889],_
+[0.55,0.0600159,En(10,0.55),En(10,0.55)-0.0600159],_
+[0.56,0.0593505,En(10,0.56),En(10,0.56)-0.0593505],_
+[0.57,0.0586925,En(10,0.57),En(10,0.57)-0.0586925],_
+[0.58,0.0580419,En(10,0.58),En(10,0.58)-0.0580419],_
+[0.59,0.0573986,En(10,0.59),En(10,0.59)-0.0573986],_
+[0.60,0.0567626,En(10,0.60),En(10,0.60)-0.0567626],_
+[0.61,0.0561336,En(10,0.61),En(10,0.61)-0.0561336],_
+[0.62,0.0555118,En(10,0.62),En(10,0.62)-0.0555118],_
+[0.63,0.0548969,En(10,0.63),En(10,0.63)-0.0548969],_
+[0.64,0.0542889,En(10,0.64),En(10,0.64)-0.0542889],_
+[0.65,0.0536877,En(10,0.65),En(10,0.65)-0.0536877],_
+[0.66,0.0530933,En(10,0.66),En(10,0.66)-0.0530933],_
+[0.67,0.0525055,En(10,0.67),En(10,0.67)-0.0525055],_
+[0.68,0.0519243,En(10,0.68),En(10,0.68)-0.0519243],_
+[0.69,0.0513497,En(10,0.69),En(10,0.69)-0.0513497],_
+[0.70,0.0507815,En(10,0.70),En(10,0.70)-0.0507815],_
+[0.71,0.0502196,En(10,0.71),En(10,0.71)-0.0502196],_
+[0.72,0.0496640,En(10,0.72),En(10,0.72)-0.0496640],_
+[0.73,0.0491147,En(10,0.73),En(10,0.73)-0.0491147],_
+[0.74,0.0485715,En(10,0.74),En(10,0.74)-0.0485715],_
+[0.75,0.0480344,En(10,0.75),En(10,0.75)-0.0480344],_
+[0.76,0.0475033,En(10,0.76),En(10,0.76)-0.0475033],_
+[0.77,0.0469781,En(10,0.77),En(10,0.77)-0.0469781],_
+[0.78,0.0464588,En(10,0.78),En(10,0.78)-0.0464588],_
+[0.79,0.0459453,En(10,0.79),En(10,0.79)-0.0459453],_
+[0.80,0.0454376,En(10,0.80),En(10,0.80)-0.0454376],_
+[0.81,0.0449356,En(10,0.81),En(10,0.81)-0.0449356],_
+[0.82,0.0444391,En(10,0.82),En(10,0.82)-0.0444391],_
+[0.83,0.0439482,En(10,0.83),En(10,0.83)-0.0439482],_
+[0.84,0.0434628,En(10,0.84),En(10,0.84)-0.0434628],_
+[0.85,0.0429829,En(10,0.85),En(10,0.85)-0.0429829],_
+[0.86,0.0425082,En(10,0.86),En(10,0.86)-0.0425082],_
+[0.87,0.0420389,En(10,0.87),En(10,0.87)-0.0420389],_
+[0.88,0.0415749,En(10,0.88),En(10,0.88)-0.0415749],_
+[0.89,0.0411160,En(10,0.89),En(10,0.89)-0.0411160],_
+[0.90,0.0406622,En(10,0.90),En(10,0.90)-0.0406622],_
+[0.91,0.0402135,En(10,0.91),En(10,0.91)-0.0402135],_
+[0.92,0.0397698,En(10,0.92),En(10,0.92)-0.0397698],_
+[0.93,0.0393311,En(10,0.93),En(10,0.93)-0.0393311],_
+[0.94,0.0388973,En(10,0.94),En(10,0.94)-0.0388973],_
+[0.95,0.0384683,En(10,0.95),En(10,0.95)-0.0384683],_
+[0.96,0.0380441,En(10,0.96),En(10,0.96)-0.0380441],_
+[0.97,0.0376246,En(10,0.97),En(10,0.97)-0.0376246],_
+[0.98,0.0372098,En(10,0.98),En(10,0.98)-0.0372098],_
+[0.99,0.0367996,En(10,0.99),En(10,0.99)-0.0367996],_
+[1.00,0.0363940,En(10,1.00),En(10,1.00)-0.0363940],_
+[1.01,0.0359929,En(10,1.01),En(10,1.01)-0.0359929],_
+[1.02,0.0355963,En(10,1.02),En(10,1.02)-0.0355963],_
+[1.03,0.0352041,En(10,1.03),En(10,1.03)-0.0352041],_
+[1.04,0.0348163,En(10,1.04),En(10,1.04)-0.0348163],_
+[1.05,0.0344328,En(10,1.05),En(10,1.05)-0.0344328],_
+[1.06,0.0340535,En(10,1.06),En(10,1.06)-0.0340535],_
+[1.07,0.0336785,En(10,1.07),En(10,1.07)-0.0336785],_
+[1.08,0.0333077,En(10,1.08),En(10,1.08)-0.0333077],_
+[1.09,0.0329410,En(10,1.09),En(10,1.09)-0.0329410],_
+[1.10,0.0325784,En(10,1.10),En(10,1.10)-0.0325784],_
+[1.11,0.0322198,En(10,1.11),En(10,1.11)-0.0322198],_
+[1.12,0.0318652,En(10,1.12),En(10,1.12)-0.0318652],_
+[1.13,0.0315145,En(10,1.13),En(10,1.13)-0.0315145],_
+[1.14,0.0311678,En(10,1.14),En(10,1.14)-0.0311678],_
+[1.15,0.0308249,En(10,1.15),En(10,1.15)-0.0308249],_
+[1.16,0.0304858,En(10,1.16),En(10,1.16)-0.0304858],_
+[1.17,0.0301505,En(10,1.17),En(10,1.17)-0.0301505],_
+[1.18,0.0298189,En(10,1.18),En(10,1.18)-0.0298189],_
+[1.19,0.0294910,En(10,1.19),En(10,1.19)-0.0294910],_
+[1.20,0.0291668,En(10,1.20),En(10,1.20)-0.0291668],_
+[1.21,0.0288461,En(10,1.21),En(10,1.21)-0.0288461],_
+[1.22,0.0285290,En(10,1.22),En(10,1.22)-0.0285290],_
+[1.23,0.0282155,En(10,1.23),En(10,1.23)-0.0282155],_
+[1.24,0.0279054,En(10,1.24),En(10,1.24)-0.0279054],_
+[1.25,0.0275988,En(10,1.25),En(10,1.25)-0.0275988],_
+[1.26,0.0272955,En(10,1.26),En(10,1.26)-0.0272955],_
+[1.27,0.0269957,En(10,1.27),En(10,1.27)-0.0269957],_
+[1.28,0.0266991,En(10,1.28),En(10,1.28)-0.0266991],_
+[1.29,0.0264059,En(10,1.29),En(10,1.29)-0.0264059],_
+[1.30,0.0261159,En(10,1.30),En(10,1.30)-0.0261159],_
+[1.31,0.0258291,En(10,1.31),En(10,1.31)-0.0258291],_
+[1.32,0.0255455,En(10,1.32),En(10,1.32)-0.0255455],_
+[1.33,0.0252651,En(10,1.33),En(10,1.33)-0.0252651],_
+[1.34,0.0249878,En(10,1.34),En(10,1.34)-0.0249878],_
+[1.35,0.0247135,En(10,1.35),En(10,1.35)-0.0247135],_
+[1.36,0.0244423,En(10,1.36),En(10,1.36)-0.0244423],_
+[1.37,0.0241741,En(10,1.37),En(10,1.37)-0.0241741],_
+[1.38,0.0239088,En(10,1.38),En(10,1.38)-0.0239088],_
+[1.39,0.0236465,En(10,1.39),En(10,1.39)-0.0236465],_
+[1.40,0.0233872,En(10,1.40),En(10,1.40)-0.0233872],_
+[1.41,0.0231306,En(10,1.41),En(10,1.41)-0.0231306],_
+[1.42,0.0228770,En(10,1.42),En(10,1.42)-0.0228770],_
+[1.43,0.0226261,En(10,1.43),En(10,1.43)-0.0226261],_
+[1.44,0.0223780,En(10,1.44),En(10,1.44)-0.0223780],_
+[1.45,0.0221327,En(10,1.45),En(10,1.45)-0.0221327],_
+[1.46,0.0218901,En(10,1.46),En(10,1.46)-0.0218901],_
+[1.47,0.0216501,En(10,1.47),En(10,1.47)-0.0216501],_
+[1.48,0.0214128,En(10,1.48),En(10,1.48)-0.0214128],_
+[1.49,0.0211782,En(10,1.49),En(10,1.49)-0.0211782],_
+[1.50,0.0209461,En(10,1.50),En(10,1.50)-0.0209461],_
+[1.51,0.0207167,En(10,1.51),En(10,1.51)-0.0207167],_
+[1.52,0.0204897,En(10,1.52),En(10,1.52)-0.0204897],_
+[1.53,0.0202653,En(10,1.53),En(10,1.53)-0.0202653],_
+[1.54,0.0200433,En(10,1.54),En(10,1.54)-0.0200433],_
+[1.55,0.0198238,En(10,1.55),En(10,1.55)-0.0198238],_
+[1.56,0.0196067,En(10,1.56),En(10,1.56)-0.0196067],_
+[1.57,0.0193921,En(10,1.57),En(10,1.57)-0.0193921],_
+[1.58,0.0191798,En(10,1.58),En(10,1.58)-0.0191798],_
+[1.59,0.0189698,En(10,1.59),En(10,1.59)-0.0189698],_
+[1.60,0.0187622,En(10,1.60),En(10,1.60)-0.0187622],_
+[1.61,0.0185568,En(10,1.61),En(10,1.61)-0.0185568],_
+[1.62,0.0183538,En(10,1.62),En(10,1.62)-0.0183538],_
+[1.63,0.0181530,En(10,1.63),En(10,1.63)-0.0181530],_
+[1.64,0.0179543,En(10,1.64),En(10,1.64)-0.0179543],_
+[1.65,0.0177579,En(10,1.65),En(10,1.65)-0.0177579],_
+[1.66,0.0175637,En(10,1.66),En(10,1.66)-0.0175637],_
+[1.67,0.0173716,En(10,1.67),En(10,1.67)-0.0173716],_
+[1.68,0.0171816,En(10,1.68),En(10,1.68)-0.0171816],_
+[1.69,0.0169937,En(10,1.69),En(10,1.69)-0.0169937],_
+[1.70,0.0168079,En(10,1.70),En(10,1.70)-0.0168079],_
+[1.71,0.0166242,En(10,1.71),En(10,1.71)-0.0166242],_
+[1.72,0.0164424,En(10,1.72),En(10,1.72)-0.0164424],_
+[1.73,0.0162627,En(10,1.73),En(10,1.73)-0.0162627],_
+[1.74,0.0160850,En(10,1.74),En(10,1.74)-0.0160850],_
+[1.75,0.0159092,En(10,1.75),En(10,1.75)-0.0159092],_
+[1.76,0.0157354,En(10,1.76),En(10,1.76)-0.0157354],_
+[1.77,0.0155634,En(10,1.77),En(10,1.77)-0.0155634],_
+[1.78,0.0153934,En(10,1.78),En(10,1.78)-0.0153934],_
+[1.79,0.0152253,En(10,1.79),En(10,1.79)-0.0152253],_
+[1.80,0.0150590,En(10,1.80),En(10,1.80)-0.0150590],_
+[1.81,0.0148945,En(10,1.81),En(10,1.81)-0.0148945],_
+[1.82,0.0147318,En(10,1.82),En(10,1.82)-0.0147318],_
+[1.83,0.0145710,En(10,1.83),En(10,1.83)-0.0145710],_
+[1.84,0.0144119,En(10,1.84),En(10,1.84)-0.0144119],_
+[1.85,0.0142546,En(10,1.85),En(10,1.85)-0.0142546],_
+[1.86,0.0140990,En(10,1.86),En(10,1.86)-0.0140990],_
+[1.87,0.0139451,En(10,1.87),En(10,1.87)-0.0139451],_
+[1.88,0.0137929,En(10,1.88),En(10,1.88)-0.0137929],_
+[1.89,0.0136424,En(10,1.89),En(10,1.89)-0.0136424],_
+[1.90,0.0134935,En(10,1.90),En(10,1.90)-0.0134935],_
+[1.91,0.0133463,En(10,1.91),En(10,1.91)-0.0133463],_
+[1.92,0.0132007,En(10,1.92),En(10,1.92)-0.0132007],_
+[1.93,0.0130567,En(10,1.93),En(10,1.93)-0.0130567],_
+[1.94,0.0129143,En(10,1.94),En(10,1.94)-0.0129143],_
+[1.95,0.0127734,En(10,1.95),En(10,1.95)-0.0127734],_
+[1.96,0.0126341,En(10,1.96),En(10,1.96)-0.0126341],_
+[1.97,0.0124964,En(10,1.97),En(10,1.97)-0.0124964],_
+[1.98,0.0123601,En(10,1.98),En(10,1.98)-0.0123601],_
+[1.99,0.0122254,En(10,1.99),En(10,1.99)-0.0122254],_
+[2.00,0.0120921,En(10,2.00),En(10,2.00)-0.0120921]]
+--R 
+--R
+--R   (6)
+--R   [[1.0E-2,0.1098682,0.10986822627360165,2.6273601655413259E-8],
+--R    [2.0E-2,0.1086395,0.10863946164415648,- 3.8355843515192056E-8],
+--R    [2.9999999999999999E-2,0.1074246,0.10742465352510716,5.3525107165941499E-8],
+--R    [4.0000000000000001E-2,0.1062236,0.10622364016949924,4.016949924079416E-8],
+--R
+--R     [5.0000000000000003E-2, 0.1050363, 0.10503626175690921,
+--R      - 3.8243090791367784E-8]
+--R     ,
+--R
+--R     [5.9999999999999998E-2, 0.10386239999999999, 0.10386236036958028,
+--R      - 3.9630419709779652E-8]
+--R     ,
+--R    [7.0000000000000007E-2,0.1027018,0.1027017799688722,- 2.0031127798136872E-8]
+--R     ,
+--R    [8.0000000000000002E-2,0.1015544,0.1015543663720207,- 3.3627979303951783E-8]
+--R     ,
+--R    [8.9999999999999997E-2,0.10042,0.1004199672292018,- 3.2770798200076889E-8],
+--R
+--R     [0.10000000000000001, 9.9298399999999995E-2, 9.9298432000896802E-2,
+--R      3.2000896807438117E-8]
+--R     ,
+--R    [0.11,9.8189600000000002E-2,9.8189611935553478E-2,1.1935553476116745E-8],
+--R    [0.12,9.7093399999999996E-2,9.7093360047539198E-2,- 3.9952460798020617E-8],
+--R    [0.13,9.6009499999999998E-2,9.6009531095381809E-2,3.109538181111926E-8],
+--R
+--R     [0.14000000000000001, 9.4937999999999995E-2, 9.4937981560294218E-2,
+--R      - 1.8439705776196469E-8]
+--R     ,
+--R
+--R     [0.14999999999999999, 9.3878600000000006E-2, 9.3878569624978384E-2,
+--R      - 3.037502162295258E-8]
+--R     ,
+--R    [0.16,9.2831200000000003E-2,9.2831155152705111E-2,- 4.4847294891625644E-8],
+--R
+--R     [0.17000000000000001, 9.1795600000000005E-2, 9.1795599666665256E-2,
+--R      - 3.3333474869223778E-10]
+--R     ,
+--R
+--R     [0.17999999999999999, 9.07718E-2, 9.0771766329588957E-2,
+--R      - 3.3670411042630022E-8]
+--R     ,
+--R    [0.19,8.9759500000000006E-2,8.9759519923628739E-2,1.9923628732931853E-8],
+--R
+--R     [0.20000000000000001, 8.8758699999999996E-2, 8.8758726830502982E-2,
+--R      2.6830502986019411E-8]
+--R     ,
+--R
+--R     [0.20999999999999999, 8.7769299999999995E-2, 8.7769255011895919E-2,
+--R      - 4.4988104075383006E-8]
+--R     ,
+--R    [0.22,8.6790999999999993E-2,8.6790973990110751E-2,- 2.6009889242395445E-8],
+--R
+--R     [0.23000000000000001, 8.5823800000000006E-2, 8.5823754828972157E-2,
+--R      - 4.5171027848733836E-8]
+--R     ,
+--R
+--R     [0.23999999999999999, 8.4867499999999998E-2, 8.4867470114974794E-2,
+--R      - 2.9885025204512417E-8]
+--R     ,
+--R    [0.25,8.3921999999999997E-2,8.3921993938674291E-2,- 6.0613257052422043E-9],
+--R
+--R     [0.26000000000000001, 8.2987199999999997E-2, 8.2987201876317501E-2,
+--R      1.8763175041458524E-9]
+--R     ,
+--R
+--R     [0.27000000000000002, 8.2062999999999997E-2, 8.2062970971708463E-2,
+--R      - 2.9028291534394235E-8]
+--R     ,
+--R
+--R     [0.28000000000000003, 8.1149200000000005E-2, 8.1149179718306999E-2,
+--R      - 2.0281693005608226E-8]
+--R     ,
+--R
+--R     [0.28999999999999998, 8.0245700000000003E-2, 8.0245708041556577E-2,
+--R      8.041556573412656E-9]
+--R     ,
+--R
+--R     [0.29999999999999999, 7.9352400000000003E-2, 7.9352437281438454E-2,
+--R      3.7281438450276205E-8]
+--R     ,
+--R    [0.31,7.8469300000000006E-2,7.8469250175248736E-2,- 4.9824751269245127E-8],
+--R
+--R     [0.32000000000000001, 7.7595999999999998E-2, 7.7596030840595492E-2,
+--R      3.0840595494074918E-8]
+--R     ,
+--R
+--R     [0.33000000000000002, 7.6732700000000001E-2, 7.6732664758612748E-2,
+--R      - 3.5241387252860079E-8]
+--R     ,
+--R
+--R     [0.34000000000000002, 7.5879000000000002E-2, 7.5879038757388551E-2,
+--R      3.8757388548527061E-8]
+--R     ,
+--R
+--R     [0.34999999999999998, 7.5035000000000004E-2, 7.5035040995603944E-2,
+--R      4.0995603939331104E-8]
+--R     ,
+--R
+--R     [0.35999999999999999, 7.4200600000000005E-2, 7.4200560946380167E-2,
+--R      - 3.9053619838025355E-8]
+--R     ,
+--R    [0.37,7.3375499999999996E-2,7.3375489381331219E-2,- 1.0618668777606644E-8],
+--R    [0.38,7.2559700000000005E-2,7.2559718354818795E-2,1.8354818789867444E-8],
+--R    [0.39000000000000001,7.17531E-2,7.1753141188407144E-2,4.1188407143288863E-8]
+--R     ,
+--R
+--R     [0.40000000000000002, 7.0955699999999997E-2, 7.0955652455514773E-2,
+--R      - 4.7544485223816046E-8]
+--R     ,
+--R
+--R     [0.40999999999999998, 7.0167099999999996E-2, 7.0167147966260709E-2,
+--R      4.7966260713350195E-8]
+--R     ,
+--R
+--R     [0.41999999999999998, 6.9387500000000005E-2, 6.93875247525024E-2,
+--R      2.4752502394975728E-8]
+--R     ,
+--R
+--R     [0.42999999999999999, 6.8616700000000003E-2, 6.8616681053062775E-2,
+--R      - 1.8946937227481975E-8]
+--R     ,
+--R    [0.44,6.7854499999999998E-2,6.7854516299143935E-2,1.6299143937303917E-8],
+--R
+--R     [0.45000000000000001, 6.7100900000000005E-2, 6.7100931099924779E-2,
+--R      3.1099924774347087E-8]
+--R     ,
+--R
+--R     [0.46000000000000002, 6.6355800000000006E-2, 6.6355827228340464E-2,
+--R      2.7228340457319256E-8]
+--R     ,
+--R    [0.46999999999999997,6.56191E-2,6.5619107607040858E-2,7.6070408583372995E-9]
+--R     ,
+--R
+--R     [0.47999999999999998, 6.4890699999999996E-2, 6.4890676294525704E-2,
+--R      - 2.3705474291868533E-8]
+--R     ,
+--R
+--R     [0.48999999999999999, 6.4170400000000002E-2, 6.4170438471454316E-2,
+--R      3.8471454313904196E-8]
+--R     ,
+--R    [0.5,6.3458299999999995E-2,6.3458300427127218E-2,4.2712722247983947E-10],
+--R
+--R     [0.51000000000000001, 6.2754199999999996E-2, 6.2754169546137606E-2,
+--R      - 3.0453862390200648E-8]
+--R     ,
+--R
+--R     [0.52000000000000002, 6.2058000000000002E-2, 6.2057954295190239E-2,
+--R      - 4.5704809763236209E-8]
+--R     ,
+--R
+--R     [0.53000000000000003, 6.1369600000000003E-2, 6.136956421008552E-2,
+--R      - 3.5789914483441709E-8]
+--R     ,
+--R
+--R     [0.54000000000000004, 6.0688899999999997E-2, 6.06889098828668E-2,
+--R      9.8828668027017841E-9]
+--R     ,
+--R
+--R     [0.55000000000000004, 6.0015899999999997E-2, 6.0015902949128445E-2,
+--R      2.9491284483929014E-9]
+--R     ,
+--R
+--R     [0.56000000000000005, 5.93505E-2, 5.9350456075482616E-2,
+--R      - 4.3924517384441586E-8]
+--R     ,
+--R
+--R     [0.56999999999999995, 5.8692500000000002E-2, 5.8692482947182836E-2,
+--R      - 1.7052817165297274E-8]
+--R     ,
+--R
+--R     [0.57999999999999996, 5.80419E-2, 5.8041898255901947E-2,
+--R      - 1.7440980534799699E-9]
+--R     ,
+--R
+--R     [0.58999999999999997, 5.7398600000000001E-2, 5.7398617687662766E-2,
+--R      1.7687662764998002E-8]
+--R     ,
+--R
+--R     [0.59999999999999998, 5.6762600000000003E-2, 5.6762557910919068E-2,
+--R      - 4.2089080935781009E-8]
+--R     ,
+--R
+--R     [0.60999999999999999, 5.6133599999999999E-2, 5.6133636564785275E-2,
+--R      3.6564785275972067E-8]
+--R     ,
+--R    [0.62,5.55118E-2,5.5511772247412536E-2,- 2.7752587464235923E-8],
+--R    [0.63,5.4896899999999998E-2,5.4896884504509566E-2,- 1.5495490432448911E-8],
+--R
+--R     [0.64000000000000001, 5.4288900000000001E-2, 5.4288893818006168E-2,
+--R      - 6.1819938335094804E-9]
+--R     ,
+--R
+--R     [0.65000000000000002, 5.3687699999999998E-2, 5.3687721594857608E-2,
+--R      2.1594857610440776E-8]
+--R     ,
+--R
+--R     [0.66000000000000003, 5.3093300000000003E-2, 5.3093290155987988E-2,
+--R      - 9.8440120152587518E-9]
+--R     ,
+--R
+--R     [0.67000000000000004, 5.2505499999999997E-2, 5.2505522725370901E-2,
+--R      2.2725370904530529E-8]
+--R     ,
+--R    [0.68000000000000005,5.19243E-2,5.1924343419245275E-2,4.341924527556662E-8],
+--R
+--R     [0.68999999999999995, 5.1349699999999998E-2, 5.1349677235465116E-2,
+--R      - 2.2764534882147025E-8]
+--R     ,
+--R
+--R     [0.69999999999999996, 5.07815E-2, 5.0781450042980847E-2,
+--R      - 4.9957019153390458E-8]
+--R     ,
+--R
+--R     [0.70999999999999996, 5.0219600000000003E-2, 5.0219588571451021E-2,
+--R      - 1.1428548982173048E-8]
+--R     ,
+--R    [0.71999999999999997,4.9664E-2,4.9664020400982369E-2,2.0400982368717901E-8],
+--R
+--R     [0.72999999999999998, 4.9114699999999997E-2, 4.9114673951996674E-2,
+--R      - 2.6048003323730917E-8]
+--R     ,
+--R
+--R     [0.73999999999999999, 4.8571499999999997E-2, 4.85714784752228E-2,
+--R      - 2.1524777196746392E-8]
+--R     ,
+--R    [0.75,4.8034399999999998E-2,4.8034364041812182E-2,- 3.595818781620963E-8],
+--R
+--R     [0.76000000000000001, 4.7503299999999998E-2, 4.7503261533576278E-2,
+--R      - 3.8466423719907272E-8]
+--R     ,
+--R
+--R     [0.77000000000000002, 4.6978100000000002E-2, 4.6978102633344329E-2,
+--R      2.6333443273185431E-9]
+--R     ,
+--R
+--R     [0.78000000000000003, 4.6458800000000001E-2, 4.6458819815439867E-2,
+--R      1.9815439865344953E-8]
+--R     ,
+--R
+--R     [0.79000000000000004, 4.5945300000000001E-2, 4.5945346336274485E-2,
+--R      4.6336274484026774E-8]
+--R     ,
+--R
+--R     [0.80000000000000004, 4.5437600000000002E-2, 4.5437616225057327E-2,
+--R      1.6225057325458536E-8]
+--R     ,
+--R
+--R     [0.81000000000000005, 4.4935599999999999E-2, 4.4935564274618756E-2,
+--R      - 3.5725381243578713E-8]
+--R     ,
+--R
+--R     [0.81999999999999995, 4.4439100000000002E-2, 4.4439126032346843E-2,
+--R      2.6032346840676457E-8]
+--R     ,
+--R    [0.82999999999999996,4.39482E-2,4.3948237791235037E-2,3.7791235037165638E-8]
+--R     ,
+--R
+--R     [0.83999999999999997, 4.3462800000000003E-2, 4.3462836581039874E-2,
+--R      3.6581039870864362E-8]
+--R     ,
+--R
+--R     [0.84999999999999998, 4.2982899999999997E-2, 4.2982860159546922E-2,
+--R      - 3.9840453075479232E-8]
+--R     ,
+--R
+--R     [0.85999999999999999, 4.2508200000000003E-2, 4.2508247003943962E-2,
+--R      4.7003943959289529E-8]
+--R     ,
+--R    [0.87,4.2038899999999997E-2,4.2038936302299747E-2,3.6302299749602085E-8],
+--R    [0.88,4.1574899999999998E-2,4.1574867945147087E-2,- 3.2054852910912146E-8],
+--R    [0.89000000000000001,4.1116E-2,4.111598251716897E-2,- 1.7482831030091184E-8]
+--R     ,
+--R
+--R     [0.90000000000000002, 4.0662200000000003E-2, 4.0662221288986326E-2,
+--R      2.1288986323808601E-8]
+--R     ,
+--R
+--R     [0.91000000000000003, 4.0213499999999999E-2, 4.0213526209046141E-2,
+--R      2.6209046141700831E-8]
+--R     ,
+--R
+--R     [0.92000000000000004, 3.9769800000000001E-2, 3.9769839895608665E-2,
+--R      3.9895608663909066E-8]
+--R     ,
+--R
+--R     [0.93000000000000005, 3.9331100000000001E-2, 3.9331105628832443E-2,
+--R      5.628832441817444E-9]
+--R     ,
+--R
+--R     [0.93999999999999995, 3.8897300000000003E-2, 3.8897267342955913E-2,
+--R      - 3.2657044089778875E-8]
+--R     ,
+--R
+--R     [0.94999999999999996, 3.8468299999999997E-2, 3.8468269618574302E-2,
+--R      - 3.038142569466995E-8]
+--R     ,
+--R
+--R     [0.95999999999999996, 3.8044099999999997E-2, 3.8044057675010727E-2,
+--R      - 4.2324989270314806E-8]
+--R     ,
+--R
+--R     [0.96999999999999997, 3.7624600000000001E-2, 3.7624577362780139E-2,
+--R      - 2.2637219862509106E-8]
+--R     ,
+--R
+--R     [0.97999999999999998, 3.7209800000000001E-2, 3.7209775156145049E-2,
+--R      - 2.4843854952438793E-8]
+--R     ,
+--R
+--R     [0.98999999999999999, 3.6799600000000002E-2, 3.6799598145761836E-2,
+--R      - 1.8542381657882245E-9]
+--R     ,
+--R    [1.,3.6394000000000003E-2,3.6393994031416403E-2,- 5.9685835995804126E-9],
+--R    [1.01,3.5992900000000001E-2,3.5992911114848265E-2,1.1114848263993338E-8],
+--R    [1.02,3.5596299999999997E-2,3.5596298292661678E-2,- 1.7073383193344505E-9],
+--R    [1.03,3.5204100000000002E-2,3.5204105049322892E-2,5.0493228903603082E-9],
+--R    [1.04,3.4816300000000001E-2,3.4816281450242362E-2,- 1.8549757639652054E-8],
+--R    [1.05,3.44328E-2,3.4432778134940903E-2,- 2.1865059096626283E-8],
+--R    [1.0600000000000001,3.40535E-2,3.405354631029861E-2,4.6310298609797407E-8],
+--R    [1.0700000000000001,3.36785E-2,3.3678537743885642E-2,3.7743885641927655E-8],
+--R
+--R     [1.0800000000000001, 3.3307700000000003E-2, 3.3307704757373741E-2,
+--R      4.757373738006887E-9]
+--R     ,
+--R
+--R     [1.0900000000000001, 3.2940999999999998E-2, 3.2941000220027501E-2,
+--R      2.20027503161635E-10]
+--R     ,
+--R
+--R     [1.1000000000000001, 3.25784E-2, 3.2578377542274328E-2,
+--R      - 2.2457725672164752E-8]
+--R     ,
+--R
+--R     [1.1100000000000001, 3.22198E-2, 3.2219790669352259E-2,
+--R      - 9.3306477405574739E-9]
+--R     ,
+--R
+--R     [1.1200000000000001, 3.1865200000000003E-2, 3.186519407503445E-2,
+--R      - 5.924965552905892E-9]
+--R     ,
+--R
+--R     [1.1299999999999999, 3.1514500000000001E-2, 3.1514542755429475E-2,
+--R      4.275542947462796E-8]
+--R     ,
+--R
+--R     [1.1399999999999999, 3.1167799999999999E-2, 3.1167792222856549E-2,
+--R      - 7.777143450071744E-9]
+--R     ,
+--R
+--R     [1.1499999999999999, 3.0824899999999999E-2, 3.0824898499794556E-2,
+--R      - 1.5002054425117262E-9]
+--R     ,
+--R    [1.1599999999999999,3.04858E-2,3.0485818112904201E-2,1.811290420081213E-8],
+--R    [1.1699999999999999,3.01505E-2,3.0150508087122076E-2,8.0871220761724594E-9],
+--R
+--R     [1.1799999999999999, 2.9818899999999999E-2, 2.9818925939826001E-2,
+--R      2.5939826002463473E-8]
+--R     ,
+--R    [1.1899999999999999,2.9491E-2,2.9491029675070599E-2,2.9675070598728093E-8],
+--R    [1.2,2.91668E-2,2.9166777777892276E-2,- 2.222210772340194E-8],
+--R    [1.21,2.88461E-2,2.8846129208682729E-2,2.9208682729431334E-8],
+--R    [1.22,2.8528999999999999E-2,2.8529043397630106E-2,4.33976301075778E-8],
+--R    [1.23,2.8215500000000001E-2,2.8215480239227052E-2,- 1.9760772948518301E-8],
+--R    [1.24,2.79054E-2,2.7905400086844646E-2,8.6844646057793184E-11],
+--R    [1.25,2.75988E-2,2.7598763747371625E-2,- 3.6252628374949802E-8],
+--R    [1.26,2.72955E-2,2.7295532475917882E-2,3.2475917881996663E-8],
+--R    [1.27,2.6995700000000001E-2,2.699566797058155E-2,- 3.2029418450818525E-8],
+--R    [1.28,2.66991E-2,2.6699132367278861E-2,3.2367278860606641E-8],
+--R    [1.29,2.64059E-2,2.6405888234635966E-2,- 1.1765364033716752E-8],
+--R    [1.3,2.6115900000000001E-2,2.6115898568942E-2,- 1.4310580012666385E-9],
+--R
+--R     [1.3100000000000001, 2.5829100000000001E-2, 2.5829126789162573E-2,
+--R      2.678916257228825E-8]
+--R     ,
+--R
+--R     [1.3200000000000001, 2.5545499999999999E-2, 2.5545536732012972E-2,
+--R      3.673201297293982E-8]
+--R     ,
+--R
+--R     [1.3300000000000001, 2.5265099999999999E-2, 2.5265092647090353E-2,
+--R      - 7.3529096457358722E-9]
+--R     ,
+--R
+--R     [1.3400000000000001, 2.4987800000000001E-2, 2.4987759192064113E-2,
+--R      - 4.0807935888093061E-8]
+--R     ,
+--R
+--R     [1.3500000000000001, 2.4713499999999999E-2, 2.471350142792382E-2,
+--R      1.42792382085144E-9]
+--R     ,
+--R
+--R     [1.3600000000000001, 2.44423E-2, 2.4442284814283937E-2,
+--R      - 1.5185716063098598E-8]
+--R     ,
+--R
+--R     [1.3700000000000001, 2.41741E-2, 2.4174075204744596E-2,
+--R      - 2.4795255404441718E-8]
+--R     ,
+--R
+--R     [1.3799999999999999, 2.3908800000000001E-2, 2.3908838842307847E-2,
+--R      3.8842307845815549E-8]
+--R     ,
+--R
+--R     [1.3899999999999999, 2.3646500000000001E-2, 2.3646542354848549E-2,
+--R      4.2354848548559199E-8]
+--R     ,
+--R
+--R     [1.3999999999999999, 2.33872E-2, 2.3387152750639354E-2,
+--R      - 4.7249360646262062E-8]
+--R     ,
+--R
+--R     [1.4099999999999999, 2.3130600000000001E-2, 2.3130637413929071E-2,
+--R      3.7413929069446406E-8]
+--R     ,
+--R
+--R     [1.4199999999999999, 2.2877000000000002E-2, 2.2876964100573671E-2,
+--R      - 3.5899426330948669E-8]
+--R     ,
+--R    [1.4299999999999999,2.26261E-2,2.2626100933719476E-2,9.3371947673670519E-10]
+--R     ,
+--R
+--R     [1.4399999999999999, 2.2377999999999999E-2, 2.237801639953766E-2,
+--R      1.6399537661887509E-8]
+--R     ,
+--R    [1.45,2.2132700000000002E-2,2.2132679343009602E-2,- 2.065699039946467E-8],
+--R    [1.46,2.1890099999999999E-2,2.18900589637624E-2,- 4.1036237598962577E-8],
+--R    [1.47,2.1650099999999999E-2,2.1650124811953917E-2,2.4811953918540963E-8],
+--R    [1.48,2.1412799999999999E-2,2.1412846784206772E-2,4.678420677250994E-8],
+--R    [1.49,2.1178200000000001E-2,2.1178195119590685E-2,- 4.8804093162602147E-9],
+--R    [1.5,2.0946099999999999E-2,2.094614039565253E-2,4.0395652531333148E-8],
+--R    [1.51,2.0716700000000001E-2,2.0716653524493592E-2,- 4.647550640862752E-8],
+--R    [1.52,2.04897E-2,2.0489705748893364E-2,5.748893364826424E-9],
+--R    [1.53,2.02653E-2,2.0265268638479383E-2,- 3.1361520616557392E-8],
+--R    [1.54,2.00433E-2,2.0043314085942482E-2,1.4085942481867342E-8],
+--R    [1.55,1.9823799999999999E-2,1.9823814303296966E-2,1.4303296966972079E-8],
+--R
+--R     [1.5600000000000001, 1.9606700000000001E-2, 1.9606741818185093E-2,
+--R      4.1818185091829774E-8]
+--R     ,
+--R
+--R     [1.5700000000000001, 1.9392099999999999E-2, 1.9392069470225374E-2,
+--R      - 3.0529774625032147E-8]
+--R     ,
+--R
+--R     [1.5800000000000001, 1.91798E-2, 1.9179770407404116E-2,
+--R      - 2.9592595884170292E-8]
+--R     ,
+--R
+--R     [1.5900000000000001, 1.8969799999999998E-2, 1.8969818082509717E-2,
+--R      1.8082509718742035E-8]
+--R     ,
+--R
+--R     [1.6000000000000001, 1.87622E-2, 1.8762186249609149E-2,
+--R      - 1.3750390850247873E-8]
+--R     ,
+--R
+--R     [1.6100000000000001, 1.8556799999999998E-2, 1.8556848960566173E-2,
+--R      4.8960566174233167E-8]
+--R     ,
+--R    [1.6200000000000001,1.83538E-2,1.835378056160069E-2,- 1.9438399310317545E-8]
+--R     ,
+--R
+--R     [1.6299999999999999, 1.8152999999999999E-2, 1.8152955689888815E-2,
+--R      - 4.431011118438688E-8]
+--R     ,
+--R
+--R     [1.6399999999999999, 1.7954299999999999E-2, 1.7954349270203122E-2,
+--R      4.927020312225916E-8]
+--R     ,
+--R    [1.6499999999999999,1.77579E-2,1.77579365115926E-2,3.6511592600013687E-8],
+--R
+--R     [1.6599999999999999, 1.7563700000000002E-2, 1.7563692904101796E-2,
+--R      - 7.0958982058277886E-9]
+--R     ,
+--R
+--R     [1.6699999999999999, 1.7371600000000001E-2, 1.7371594215528752E-2,
+--R      - 5.7844712492149952E-9]
+--R     ,
+--R
+--R     [1.6799999999999999, 1.7181600000000002E-2, 1.718161648822112E-2,
+--R      1.6488221118299284E-8]
+--R     ,
+--R    [1.6899999999999999,1.69937E-2,1.6993736035910194E-2,3.6035910193354947E-8],
+--R    [1.7,1.6807900000000001E-2,1.6807929440582167E-2,2.9440582166584406E-8],
+--R    [1.71,1.6624199999999999E-2,1.6624173549386351E-2,- 2.6450613647283072E-8],
+--R    [1.72,1.6442399999999999E-2,1.6442445471579824E-2,4.5471579824402086E-8],
+--R    [1.73,1.6262700000000001E-2,1.6262722575508065E-2,2.2575508063643612E-8],
+--R    [1.74,1.6084999999999999E-2,1.6084982485621131E-2,- 1.7514378867350411E-8],
+--R    [1.75,1.5909199999999998E-2,1.590920307952504E-2,3.0795250412218866E-9],
+--R    [1.76,1.57354E-2,1.5735362485067742E-2,- 3.7514932257898259E-8],
+--R    [1.77,1.55634E-2,1.5563439077459485E-2,3.9077459485295507E-8],
+--R    [1.78,1.53934E-2,1.5393411476427005E-2,1.1476427004900036E-8],
+--R    [1.79,1.5225300000000001E-2,1.5225258543401145E-2,- 4.1456598855182936E-8],
+--R    [1.8,1.5058999999999999E-2,1.5058959378737585E-2,- 4.0621262414539117E-8],
+--R
+--R     [1.8100000000000001, 1.48945E-2, 1.4894493318970201E-2,
+--R      - 6.6810297988384448E-9]
+--R     ,
+--R    [1.8200000000000001,1.47318E-2,1.4731839934096682E-2,3.9934096682237019E-8],
+--R
+--R     [1.8300000000000001, 1.4571000000000001E-2, 1.4570979024896022E-2,
+--R      - 2.0975103978346232E-8]
+--R     ,
+--R
+--R     [1.8400000000000001, 1.44119E-2, 1.4411890620277503E-2,
+--R      - 9.3797224969688342E-9]
+--R     ,
+--R
+--R     [1.8500000000000001, 1.4254599999999999E-2, 1.4254554974660784E-2,
+--R      - 4.5025339215701288E-8]
+--R     ,
+--R    [1.8600000000000001,1.4099E-2,1.4098952565386716E-2,- 4.7434613284144667E-8]
+--R     ,
+--R    [1.8700000000000001,1.39451E-2,1.3945064090158516E-2,- 3.590984148406362E-8]
+--R     ,
+--R
+--R     [1.8799999999999999, 1.37929E-2, 1.3792870464512974E-2,
+--R      - 2.9535487026596807E-8]
+--R     ,
+--R
+--R     [1.8899999999999999, 1.3642400000000001E-2, 1.3642352819321199E-2,
+--R      - 4.7180678801328479E-8]
+--R     ,
+--R
+--R     [1.8999999999999999, 1.34935E-2, 1.3493492498318767E-2,
+--R      - 7.5016812327993732E-9]
+--R     ,
+--R
+--R     [1.9099999999999999, 1.33463E-2, 1.3346271055664704E-2,
+--R      - 2.8944335296599011E-8]
+--R     ,
+--R
+--R     [1.9199999999999999, 1.3200699999999999E-2, 1.3200670253529076E-2,
+--R      - 2.9746470923616708E-8]
+--R     ,
+--R
+--R     [1.9299999999999999, 1.3056699999999999E-2, 1.3056672059708809E-2,
+--R      - 2.794029119006225E-8]
+--R     ,
+--R
+--R     [1.9399999999999999, 1.29143E-2, 1.2914258645271409E-2,
+--R      - 4.1354728591222467E-8]
+--R     ,
+--R    [1.95,1.2773400000000001E-2,1.2773412382226235E-2,1.2382226233925708E-8],
+--R    [1.96,1.2634100000000001E-2,1.2634115841222995E-2,1.5841222994819604E-8],
+--R    [1.97,1.24964E-2,1.2496351789277165E-2,- 4.8210722834035602E-8],
+--R    [1.98,1.2360100000000001E-2,1.236010318752195E-2,3.1875219495131057E-9],
+--R    [1.99,1.2225400000000001E-2,1.222535318898654E-2,- 4.6811013461323103E-8],
+--R    [2.,1.20921E-2,1.2092085136400298E-2,- 1.4863599701736563E-8]]
+--R                               Type: List List OnePointCompletion DoubleFloat
+--E 6
+
+@
+This table expresses the value of 
+$E_20$ with an argument range of 0.01 to 2.00.
+<<*>>=
+--S 7 of 7
+[[0.01,0.0520790,En(20,0.01),En(20,0.01)-0.0520790],_
+[0.02,0.0515321,En(20,0.02),En(20,0.02)-0.0515321],_
+[0.03,0.0509911,En(20,0.03),En(20,0.03)-0.0509911],_
+[0.04,0.0504558,En(20,0.04),En(20,0.04)-0.0504558],_
+[0.05,0.0499260,En(20,0.05),En(20,0.05)-0.0499260],_
+[0.06,0.0494019,En(20,0.06),En(20,0.06)-0.0494019],_
+[0.07,0.0488833,En(20,0.07),En(20,0.07)-0.0488833],_
+[0.08,0.0483702,En(20,0.08),En(20,0.08)-0.0483702],_
+[0.09,0.0478624,En(20,0.09),En(20,0.09)-0.0478624],_
+[0.10,0.0473600,En(20,0.10),En(20,0.10)-0.0473600],_
+[0.11,0.0468629,En(20,0.11),En(20,0.11)-0.0468629],_
+[0.12,0.0463710,En(20,0.12),En(20,0.12)-0.0463710],_
+[0.13,0.0458843,En(20,0.13),En(20,0.13)-0.0458843],_
+[0.14,0.0454027,En(20,0.14),En(20,0.14)-0.0454027],_
+[0.15,0.0449262,En(20,0.15),En(20,0.15)-0.0449262],_
+[0.16,0.0444547,En(20,0.16),En(20,0.16)-0.0444547],_
+[0.17,0.0439882,En(20,0.17),En(20,0.17)-0.0439882],_
+[0.18,0.0435266,En(20,0.18),En(20,0.18)-0.0435266],_
+[0.19,0.0430698,En(20,0.19),En(20,0.19)-0.0430698],_
+[0.20,0.0426179,En(20,0.20),En(20,0.20)-0.0426179],_
+[0.21,0.0421707,En(20,0.21),En(20,0.21)-0.0421707],_
+[0.22,0.0417282,En(20,0.22),En(20,0.22)-0.0417282],_
+[0.23,0.0412903,En(20,0.23),En(20,0.23)-0.0412903],_
+[0.24,0.0408571,En(20,0.24),En(20,0.24)-0.0408571],_
+[0.25,0.0404285,En(20,0.25),En(20,0.25)-0.0404285],_
+[0.26,0.0400043,En(20,0.26),En(20,0.26)-0.0400043],_
+[0.27,0.0395846,En(20,0.27),En(20,0.27)-0.0395846],_
+[0.28,0.0391693,En(20,0.28),En(20,0.28)-0.0391693],_
+[0.29,0.0387584,En(20,0.29),En(20,0.29)-0.0387584],_
+[0.30,0.0383518,En(20,0.30),En(20,0.30)-0.0383518],_
+[0.31,0.0379495,En(20,0.31),En(20,0.31)-0.0379495],_
+[0.32,0.0375515,En(20,0.32),En(20,0.32)-0.0375515],_
+[0.33,0.0371576,En(20,0.33),En(20,0.33)-0.0371576],_
+[0.34,0.0367678,En(20,0.34),En(20,0.34)-0.0367678],_
+[0.35,0.0363822,En(20,0.35),En(20,0.35)-0.0363822],_
+[0.36,0.0360006,En(20,0.36),En(20,0.36)-0.0360006],_
+[0.37,0.0356231,En(20,0.37),En(20,0.37)-0.0356231],_
+[0.38,0.0352495,En(20,0.38),En(20,0.38)-0.0352495],_
+[0.39,0.0348798,En(20,0.39),En(20,0.39)-0.0348798],_
+[0.40,0.0345140,En(20,0.40),En(20,0.40)-0.0345140],_
+[0.41,0.0341521,En(20,0.41),En(20,0.41)-0.0341521],_
+[0.42,0.0337939,En(20,0.42),En(20,0.42)-0.0337939],_
+[0.43,0.0334396,En(20,0.43),En(20,0.43)-0.0334396],_
+[0.44,0.0330889,En(20,0.44),En(20,0.44)-0.0330889],_
+[0.45,0.0327420,En(20,0.45),En(20,0.45)-0.0327420],_
+[0.46,0.0323987,En(20,0.46),En(20,0.46)-0.0323987],_
+[0.47,0.0320590,En(20,0.47),En(20,0.47)-0.0320590],_
+[0.48,0.0317229,En(20,0.48),En(20,0.48)-0.0317229],_
+[0.49,0.0313903,En(20,0.49),En(20,0.49)-0.0313903],_
+[0.50,0.0310612,En(20,0.50),En(20,0.50)-0.0310612],_
+[0.51,0.0307356,En(20,0.51),En(20,0.51)-0.0307356],_
+[0.52,0.0304134,En(20,0.52),En(20,0.52)-0.0304134],_
+[0.53,0.0300946,En(20,0.53),En(20,0.53)-0.0300946],_
+[0.54,0.0297791,En(20,0.54),En(20,0.54)-0.0297791],_
+[0.55,0.0294670,En(20,0.55),En(20,0.55)-0.0294670],_
+[0.56,0.0291581,En(20,0.56),En(20,0.56)-0.0291581],_
+[0.57,0.0288525,En(20,0.57),En(20,0.57)-0.0288525],_
+[0.58,0.0285501,En(20,0.58),En(20,0.58)-0.0285501],_
+[0.59,0.0282508,En(20,0.59),En(20,0.59)-0.0282508],_
+[0.60,0.0279548,En(20,0.60),En(20,0.60)-0.0279548],_
+[0.61,0.0276618,En(20,0.61),En(20,0.61)-0.0276618],_
+[0.62,0.0273719,En(20,0.62),En(20,0.62)-0.0273719],_
+[0.63,0.0270850,En(20,0.63),En(20,0.63)-0.0270850],_
+[0.64,0.0268012,En(20,0.64),En(20,0.64)-0.0268012],_
+[0.65,0.0265204,En(20,0.65),En(20,0.65)-0.0265204],_
+[0.66,0.0262425,En(20,0.66),En(20,0.66)-0.0262425],_
+[0.67,0.0259675,En(20,0.67),En(20,0.67)-0.0259675],_
+[0.68,0.0256954,En(20,0.68),En(20,0.68)-0.0256954],_
+[0.69,0.0254262,En(20,0.69),En(20,0.69)-0.0254262],_
+[0.70,0.0251598,En(20,0.70),En(20,0.70)-0.0251598],_
+[0.71,0.0248962,En(20,0.71),En(20,0.71)-0.0248962],_
+[0.72,0.0246353,En(20,0.72),En(20,0.72)-0.0246353],_
+[0.73,0.0243772,En(20,0.73),En(20,0.73)-0.0243772],_
+[0.74,0.0241219,En(20,0.74),En(20,0.74)-0.0241219],_
+[0.75,0.0238692,En(20,0.75),En(20,0.75)-0.0238692],_
+[0.76,0.0236191,En(20,0.76),En(20,0.76)-0.0236191],_
+[0.77,0.0233717,En(20,0.77),En(20,0.77)-0.0233717],_
+[0.78,0.0231269,En(20,0.78),En(20,0.78)-0.0231269],_
+[0.79,0.0228846,En(20,0.79),En(20,0.79)-0.0228846],_
+[0.80,0.0226449,En(20,0.80),En(20,0.80)-0.0226449],_
+[0.81,0.0224078,En(20,0.81),En(20,0.81)-0.0224078],_
+[0.82,0.0221731,En(20,0.82),En(20,0.82)-0.0221731],_
+[0.83,0.0219408,En(20,0.83),En(20,0.83)-0.0219408],_
+[0.84,0.0217111,En(20,0.84),En(20,0.84)-0.0217111],_
+[0.85,0.0214837,En(20,0.85),En(20,0.85)-0.0214837],_
+[0.86,0.0212587,En(20,0.86),En(20,0.86)-0.0212587],_
+[0.87,0.0210361,En(20,0.87),En(20,0.87)-0.0210361],_
+[0.88,0.0208158,En(20,0.88),En(20,0.88)-0.0208158],_
+[0.89,0.0205978,En(20,0.89),En(20,0.89)-0.0205978],_
+[0.90,0.0203821,En(20,0.90),En(20,0.90)-0.0203821],_
+[0.91,0.0201687,En(20,0.91),En(20,0.91)-0.0201687],_
+[0.92,0.0199575,En(20,0.92),En(20,0.92)-0.0199575],_
+[0.93,0.0197486,En(20,0.93),En(20,0.93)-0.0197486],_
+[0.94,0.0195418,En(20,0.94),En(20,0.94)-0.0195418],_
+[0.95,0.0193372,En(20,0.95),En(20,0.95)-0.0193372],_
+[0.96,0.0191347,En(20,0.96),En(20,0.96)-0.0191347],_
+[0.97,0.0189344,En(20,0.97),En(20,0.97)-0.0189344],_
+[0.98,0.0187362,En(20,0.98),En(20,0.98)-0.0187362],_
+[0.99,0.0185401,En(20,0.99),En(20,0.99)-0.0185401],_
+[1.00,0.0183460,En(20,1.00),En(20,1.00)-0.0183460],_
+[1.01,0.0181539,En(20,1.01),En(20,1.01)-0.0181539],_
+[1.02,0.0179639,En(20,1.02),En(20,1.02)-0.0179639],_
+[1.03,0.0177759,En(20,1.03),En(20,1.03)-0.0177759],_
+[1.04,0.0175898,En(20,1.04),En(20,1.04)-0.0175898],_
+[1.05,0.0174057,En(20,1.05),En(20,1.05)-0.0174057],_
+[1.06,0.0172235,En(20,1.06),En(20,1.06)-0.0172235],_
+[1.07,0.0170433,En(20,1.07),En(20,1.07)-0.0170433],_
+[1.08,0.0168649,En(20,1.08),En(20,1.08)-0.0168649],_
+[1.09,0.0166884,En(20,1.09),En(20,1.09)-0.0166884],_
+[1.10,0.0165137,En(20,1.10),En(20,1.10)-0.0165137],_
+[1.11,0.0163409,En(20,1.11),En(20,1.11)-0.0163409],_
+[1.12,0.0161699,En(20,1.12),En(20,1.12)-0.0161699],_
+[1.13,0.0160007,En(20,1.13),En(20,1.13)-0.0160007],_
+[1.14,0.0158333,En(20,1.14),En(20,1.14)-0.0158333],_
+[1.15,0.0156676,En(20,1.15),En(20,1.15)-0.0156676],_
+[1.16,0.0155037,En(20,1.16),En(20,1.16)-0.0155037],_
+[1.17,0.0153414,En(20,1.17),En(20,1.17)-0.0153414],_
+[1.18,0.0151809,En(20,1.18),En(20,1.18)-0.0151809],_
+[1.19,0.0150221,En(20,1.19),En(20,1.19)-0.0150221],_
+[1.20,0.0148649,En(20,1.20),En(20,1.20)-0.0148649],_
+[1.21,0.0147094,En(20,1.21),En(20,1.21)-0.0147094],_
+[1.22,0.0145555,En(20,1.22),En(20,1.22)-0.0145555],_
+[1.23,0.0144032,En(20,1.23),En(20,1.23)-0.0144032],_
+[1.24,0.0142526,En(20,1.24),En(20,1.24)-0.0142526],_
+[1.25,0.0141035,En(20,1.25),En(20,1.25)-0.0141035],_
+[1.26,0.0139559,En(20,1.26),En(20,1.26)-0.0139559],_
+[1.27,0.0138100,En(20,1.27),En(20,1.27)-0.0138100],_
+[1.28,0.0136655,En(20,1.28),En(20,1.28)-0.0136655],_
+[1.29,0.0135226,En(20,1.29),En(20,1.29)-0.0135226],_
+[1.30,0.0133811,En(20,1.30),En(20,1.30)-0.0133811],_
+[1.31,0.0132412,En(20,1.31),En(20,1.31)-0.0132412],_
+[1.32,0.0131027,En(20,1.32),En(20,1.32)-0.0131027],_
+[1.33,0.0129657,En(20,1.33),En(20,1.33)-0.0129657],_
+[1.34,0.0128301,En(20,1.34),En(20,1.34)-0.0128301],_
+[1.35,0.0126959,En(20,1.35),En(20,1.35)-0.0126959],_
+[1.36,0.0125631,En(20,1.36),En(20,1.36)-0.0125631],_
+[1.37,0.0124317,En(20,1.37),En(20,1.37)-0.0124317],_
+[1.38,0.0123017,En(20,1.38),En(20,1.38)-0.0123017],_
+[1.39,0.0121731,En(20,1.39),En(20,1.39)-0.0121731],_
+[1.40,0.0120458,En(20,1.40),En(20,1.40)-0.0120458],_
+[1.41,0.0119198,En(20,1.41),En(20,1.41)-0.0119198],_
+[1.42,0.0117952,En(20,1.42),En(20,1.42)-0.0117952],_
+[1.43,0.0116719,En(20,1.43),En(20,1.43)-0.0116719],_
+[1.44,0.0115499,En(20,1.44),En(20,1.44)-0.0115499],_
+[1.45,0.0114291,En(20,1.45),En(20,1.45)-0.0114291],_
+[1.46,0.0113096,En(20,1.46),En(20,1.46)-0.0113096],_
+[1.47,0.0111914,En(20,1.47),En(20,1.47)-0.0111914],_
+[1.48,0.0110744,En(20,1.48),En(20,1.48)-0.0110744],_
+[1.49,0.0109586,En(20,1.49),En(20,1.49)-0.0109586],_
+[1.50,0.0108440,En(20,1.50),En(20,1.50)-0.0108440],_
+[1.51,0.0107307,En(20,1.51),En(20,1.51)-0.0107307],_
+[1.52,0.0106185,En(20,1.52),En(20,1.52)-0.0106185],_
+[1.53,0.0105075,En(20,1.53),En(20,1.53)-0.0105075],_
+[1.54,0.0103977,En(20,1.54),En(20,1.54)-0.0103977],_
+[1.55,0.0102890,En(20,1.55),En(20,1.55)-0.0102890],_
+[1.56,0.0101815,En(20,1.56),En(20,1.56)-0.0101815],_
+[1.57,0.0100750,En(20,1.57),En(20,1.57)-0.0100750],_
+[1.58,0.0099697,En(20,1.58),En(20,1.58)-0.0099697],_
+[1.59,0.0098656,En(20,1.59),En(20,1.59)-0.0098656],_
+[1.60,0.0097624,En(20,1.60),En(20,1.60)-0.0097624],_
+[1.61,0.0096604,En(20,1.61),En(20,1.61)-0.0096604],_
+[1.62,0.0095595,En(20,1.62),En(20,1.62)-0.0095595],_
+[1.63,0.0094596,En(20,1.63),En(20,1.63)-0.0094596],_
+[1.64,0.0093607,En(20,1.64),En(20,1.64)-0.0093607],_
+[1.65,0.0092629,En(20,1.65),En(20,1.65)-0.0092629],_
+[1.66,0.0091661,En(20,1.66),En(20,1.66)-0.0091661],_
+[1.67,0.0090703,En(20,1.67),En(20,1.67)-0.0090703],_
+[1.68,0.0089756,En(20,1.68),En(20,1.68)-0.0089756],_
+[1.69,0.0088818,En(20,1.69),En(20,1.69)-0.0088818],_
+[1.70,0.0087890,En(20,1.70),En(20,1.70)-0.0087890],_
+[1.71,0.0086972,En(20,1.71),En(20,1.71)-0.0086972],_
+[1.72,0.0086063,En(20,1.72),En(20,1.72)-0.0086063],_
+[1.73,0.0085164,En(20,1.73),En(20,1.73)-0.0085164],_
+[1.74,0.0084274,En(20,1.74),En(20,1.74)-0.0084274],_
+[1.75,0.0083394,En(20,1.75),En(20,1.75)-0.0083394],_
+[1.76,0.0082522,En(20,1.76),En(20,1.76)-0.0082522],_
+[1.77,0.0081660,En(20,1.77),En(20,1.77)-0.0081660],_
+[1.78,0.0080807,En(20,1.78),En(20,1.78)-0.0080807],_
+[1.79,0.0079963,En(20,1.79),En(20,1.79)-0.0079963],_
+[1.80,0.0079128,En(20,1.80),En(20,1.80)-0.0079128],_
+[1.81,0.0078302,En(20,1.81),En(20,1.81)-0.0078302],_
+[1.82,0.0077484,En(20,1.82),En(20,1.82)-0.0077484],_
+[1.83,0.0076674,En(20,1.83),En(20,1.83)-0.0076674],_
+[1.84,0.0075874,En(20,1.84),En(20,1.84)-0.0075874],_
+[1.85,0.0075081,En(20,1.85),En(20,1.85)-0.0075081],_
+[1.86,0.0074297,En(20,1.86),En(20,1.86)-0.0074297],_
+[1.87,0.0073521,En(20,1.87),En(20,1.87)-0.0073521],_
+[1.88,0.0072753,En(20,1.88),En(20,1.88)-0.0072753],_
+[1.89,0.0071993,En(20,1.89),En(20,1.89)-0.0071993],_
+[1.90,0.0071242,En(20,1.90),En(20,1.90)-0.0071242],_
+[1.91,0.0070498,En(20,1.91),En(20,1.91)-0.0070498],_
+[1.92,0.0069762,En(20,1.92),En(20,1.92)-0.0069762],_
+[1.93,0.0069033,En(20,1.93),En(20,1.93)-0.0069033],_
+[1.94,0.0068312,En(20,1.94),En(20,1.94)-0.0068312],_
+[1.95,0.0067599,En(20,1.95),En(20,1.95)-0.0067599],_
+[1.96,0.0066893,En(20,1.96),En(20,1.96)-0.0066893],_
+[1.97,0.0066195,En(20,1.97),En(20,1.97)-0.0066195],_
+[1.98,0.0065504,En(20,1.98),En(20,1.98)-0.0065504],_
+[1.99,0.0064820,En(20,1.99),En(20,1.99)-0.0064820],_
+[2.00,0.0064143,En(20,2.00),En(20,2.00)-0.0064143]]
+--R 
+--R
+--R   (7)
+--R   [[1.0E-2,5.2079E-2,5.2078954179335148E-2,- 4.5820664852647131E-8],
+--R    [2.0E-2,5.1532099999999997E-2,5.1532149651352818E-2,4.9651352820867523E-8],
+--R
+--R     [2.9999999999999999E-2, 5.0991099999999998E-2, 5.0991103854550281E-2,
+--R      3.8545502831222045E-9]
+--R     ,
+--R
+--R     [4.0000000000000001E-2, 5.0455800000000002E-2, 5.0455755932602576E-2,
+--R      - 4.4067397425573418E-8]
+--R     ,
+--R
+--R     [5.0000000000000003E-2, 4.9925999999999998E-2, 4.9926045674777729E-2,
+--R      4.5674777730819738E-8]
+--R     ,
+--R
+--R     [5.9999999999999998E-2, 4.9401899999999999E-2, 4.9401913509057829E-2,
+--R      1.3509057830707327E-8]
+--R     ,
+--R
+--R     [7.0000000000000007E-2, 4.8883299999999998E-2, 4.8883300495333924E-2,
+--R      4.9533392665335185E-10]
+--R     ,
+--R
+--R     [8.0000000000000002E-2, 4.8370200000000002E-2, 4.83701483186737E-2,
+--R      - 5.1681326301844521E-8]
+--R     ,
+--R
+--R     [8.9999999999999997E-2, 4.7862399999999999E-2, 4.786239928266129E-2,
+--R      - 7.1733870926626864E-10]
+--R     ,
+--R
+--R     [0.10000000000000001, 4.7359999999999999E-2, 4.7359996302808287E-2,
+--R      - 3.6971917125039333E-9]
+--R     ,
+--R    [0.11,4.6862899999999999E-2,4.6862882900035485E-2,- 1.7099964513822563E-8],
+--R    [0.12,4.6371000000000002E-2,4.6371003194224242E-2,3.1942242392779541E-9],
+--R    [0.13,4.5884300000000003E-2,4.5884301897836918E-2,1.8978369153987984E-9],
+--R
+--R     [0.14000000000000001, 4.5402699999999997E-2, 4.5402724309605645E-2,
+--R      2.430960564792084E-8]
+--R     ,
+--R
+--R     [0.14999999999999999, 4.4926199999999999E-2, 4.4926216308288566E-2,
+--R      1.6308288566801998E-8]
+--R     ,
+--R    [0.16,4.44547E-2,4.4454724346493016E-2,2.4346493016080828E-8],
+--R
+--R     [0.17000000000000001, 4.3988199999999998E-2, 4.398819544456465E-2,
+--R      - 4.5554353483856502E-9]
+--R     ,
+--R
+--R     [0.17999999999999999, 4.3526599999999999E-2, 4.3526577184542115E-2,
+--R      - 2.2815457884073354E-8]
+--R     ,
+--R    [0.19,4.3069799999999998E-2,4.3069817704176359E-2,1.7704176361044155E-8],
+--R
+--R     [0.20000000000000001, 4.26179E-2, 4.2617865691013848E-2,
+--R      - 3.4308986152087328E-8]
+--R     ,
+--R
+--R     [0.20999999999999999, 4.2170699999999998E-2, 4.2170670376543248E-2,
+--R      - 2.962345675011635E-8]
+--R     ,
+--R    [0.22,4.17282E-2,4.1728181530404598E-2,- 1.8469595401693351E-8],
+--R
+--R     [0.23000000000000001, 4.1290300000000002E-2, 4.1290349454660515E-2,
+--R      4.9454660512593396E-8]
+--R     ,
+--R    [0.23999999999999999,4.08571E-2,4.0857124978128601E-2,2.4978128600194882E-8]
+--R     ,
+--R    [0.25,4.0428499999999999E-2,4.0428459450774591E-2,- 4.0549225407970901E-8],
+--R    [0.26000000000000001,4.00043E-2,4.0004304738165339E-2,4.7381653392464251E-9]
+--R     ,
+--R
+--R     [0.27000000000000002, 3.9584599999999998E-2, 3.9584613215981258E-2,
+--R      1.3215981260750187E-8]
+--R     ,
+--R
+--R     [0.28000000000000003, 3.9169299999999997E-2, 3.916933776458735E-2,
+--R      3.7764587353106283E-8]
+--R     ,
+--R
+--R     [0.28999999999999998, 3.8758399999999998E-2, 3.8758431763662324E-2,
+--R      3.1763662325379194E-8]
+--R     ,
+--R
+--R     [0.29999999999999999, 3.8351799999999998E-2, 3.8351849086885194E-2,
+--R      4.908688519544846E-8]
+--R     ,
+--R    [0.31,3.7949499999999997E-2,3.7949544096678632E-2,4.4096678634975017E-8],
+--R
+--R     [0.32000000000000001, 3.7551500000000002E-2, 3.7551471639008578E-2,
+--R      - 2.8360991423392878E-8]
+--R     ,
+--R
+--R     [0.33000000000000002, 3.7157599999999999E-2, 3.7157587038239355E-2,
+--R      - 1.2961760643970255E-8]
+--R     ,
+--R
+--R     [0.34000000000000002, 3.6767800000000003E-2, 3.6767846092043928E-2,
+--R      4.6092043924639281E-8]
+--R     ,
+--R
+--R     [0.34999999999999998, 3.6382200000000003E-2, 3.6382205066368474E-2,
+--R      5.0663684705853917E-9]
+--R     ,
+--R
+--R     [0.35999999999999999, 3.6000600000000001E-2, 3.6000620690450777E-2,
+--R      2.0690450776295055E-8]
+--R     ,
+--R    [0.37,3.5623099999999998E-2,3.5623050151891968E-2,- 4.9848108030214888E-8],
+--R    [0.38,3.5249500000000003E-2,3.5249451091780772E-2,- 4.8908219231480476E-8],
+--R
+--R     [0.39000000000000001, 3.4879800000000002E-2, 3.4879781599870076E-2,
+--R      - 1.8400129926654518E-8]
+--R     ,
+--R
+--R     [0.40000000000000002, 3.4514000000000003E-2, 3.4514000209804857E-2,
+--R      2.0980485404553662E-10]
+--R     ,
+--R
+--R     [0.40999999999999998, 3.4152099999999998E-2, 3.4152065894401229E-2,
+--R      - 3.410559876876329E-8]
+--R     ,
+--R
+--R     [0.41999999999999998, 3.3793900000000002E-2, 3.3793938060975852E-2,
+--R      3.8060975850184864E-8]
+--R     ,
+--R
+--R     [0.42999999999999999, 3.34396E-2, 3.3439576546725337E-2,
+--R      - 2.3453274662632584E-8]
+--R     ,
+--R    [0.44,3.3088899999999997E-2,3.308894161415496E-2,4.1614154962232863E-8],
+--R
+--R     [0.45000000000000001, 3.2742E-2, 3.2741993946556171E-2,
+--R      - 6.0534438295345439E-9]
+--R     ,
+--R
+--R     [0.46000000000000002, 3.2398700000000002E-2, 3.2398694643532566E-2,
+--R      - 5.3564674362682752E-9]
+--R     ,
+--R
+--R     [0.46999999999999997, 3.2058999999999997E-2, 3.2059005216573518E-2,
+--R      5.216573520372414E-9]
+--R     ,
+--R
+--R     [0.47999999999999998, 3.1722899999999998E-2, 3.1722887584675112E-2,
+--R      - 1.2415324886216883E-8]
+--R     ,
+--R
+--R     [0.48999999999999999, 3.1390300000000003E-2, 3.1390304070007917E-2,
+--R      4.070007914025453E-9]
+--R     ,
+--R    [0.5,3.1061200000000001E-2,3.1061217393630984E-2,1.7393630983436603E-8],
+--R
+--R     [0.51000000000000001, 3.0735599999999998E-2, 3.0735590671251607E-2,
+--R      - 9.3287483918236269E-9]
+--R     ,
+--R
+--R     [0.52000000000000002, 3.04134E-2, 3.0413387409030435E-2,
+--R      - 1.2590969565573484E-8]
+--R     ,
+--R
+--R     [0.53000000000000003, 3.0094599999999999E-2, 3.009457149943125E-2,
+--R      - 2.8500568748784927E-8]
+--R     ,
+--R
+--R     [0.54000000000000004, 2.9779099999999999E-2, 2.9779107217115259E-2,
+--R      7.217115259583462E-9]
+--R     ,
+--R
+--R     [0.55000000000000004, 2.9467E-2, 2.9466959214879015E-2,
+--R      - 4.0785120985348255E-8]
+--R     ,
+--R
+--R     [0.56000000000000005, 2.9158099999999999E-2, 2.9158092519635862E-2,
+--R      - 7.4803641371412599E-9]
+--R     ,
+--R
+--R     [0.56999999999999995, 2.88525E-2, 2.8852472528440212E-2,
+--R      - 2.7471559787412003E-8]
+--R     ,
+--R
+--R     [0.57999999999999996, 2.8550099999999998E-2, 2.8550065004554304E-2,
+--R      - 3.4995445694074867E-8]
+--R     ,
+--R    [0.58999999999999997,2.82508E-2,2.8250836073556898E-2,3.6073556898552628E-8]
+--R     ,
+--R
+--R     [0.59999999999999998, 2.7954799999999998E-2, 2.7954752219493562E-2,
+--R      - 4.7780506436806425E-8]
+--R     ,
+--R
+--R     [0.60999999999999999, 2.76618E-2, 2.7661780281068072E-2,
+--R      - 1.9718931928286443E-8]
+--R     ,
+--R    [0.62,2.7371900000000001E-2,2.7371887447874325E-2,- 1.2552125675663328E-8],
+--R    [0.63,2.7085000000000001E-2,2.7085041256668666E-2,4.1256668664724216E-8],
+--R
+--R     [0.64000000000000001, 2.6801200000000001E-2, 2.6801209587681844E-2,
+--R      9.5876818428930477E-9]
+--R     ,
+--R
+--R     [0.65000000000000002, 2.65204E-2, 2.6520360660970379E-2,
+--R      - 3.9339029620638621E-8]
+--R     ,
+--R
+--R     [0.66000000000000003, 2.6242499999999998E-2, 2.6242463032806879E-2,
+--R      - 3.6967193119130659E-8]
+--R     ,
+--R
+--R     [0.67000000000000004, 2.5967500000000001E-2, 2.5967485592108871E-2,
+--R      - 1.4407891130163719E-8]
+--R     ,
+--R
+--R     [0.68000000000000005, 2.56954E-2, 2.5695397556905687E-2,
+--R      - 2.4430943136588557E-9]
+--R     ,
+--R
+--R     [0.68999999999999995, 2.5426199999999999E-2, 2.5426168470843124E-2,
+--R      - 3.1529156875598208E-8]
+--R     ,
+--R
+--R     [0.69999999999999996, 2.51598E-2, 2.5159768199725301E-2,
+--R      - 3.1800274698234876E-8]
+--R     ,
+--R
+--R     [0.70999999999999996, 2.48962E-2, 2.489616692809353E-2,
+--R      - 3.3071906470338863E-8]
+--R     ,
+--R
+--R     [0.71999999999999997, 2.4635299999999999E-2, 2.4635335155841546E-2,
+--R      3.5155841546924416E-8]
+--R     ,
+--R
+--R     [0.72999999999999998, 2.4377200000000002E-2, 2.4377243694866949E-2,
+--R      4.3694866946886179E-8]
+--R     ,
+--R
+--R     [0.73999999999999999, 2.4121900000000002E-2, 2.4121863665758296E-2,
+--R      - 3.6334241705626713E-8]
+--R     ,
+--R    [0.75,2.38692E-2,2.386916649451758E-2,- 3.3505482419787791E-8],
+--R
+--R     [0.76000000000000001, 2.3619100000000001E-2, 2.3619123909317606E-2,
+--R      2.3909317605624869E-8]
+--R     ,
+--R
+--R     [0.77000000000000002, 2.3371699999999999E-2, 2.3371707937294008E-2,
+--R      7.9372940095523425E-9]
+--R     ,
+--R
+--R     [0.78000000000000003, 2.3126899999999999E-2, 2.3126890901371419E-2,
+--R      - 9.0986285797289845E-9]
+--R     ,
+--R
+--R     [0.79000000000000004, 2.2884600000000001E-2, 2.2884645417123543E-2,
+--R      4.5417123541169335E-8]
+--R     ,
+--R
+--R     [0.80000000000000004, 2.2644899999999999E-2, 2.2644944389666643E-2,
+--R      4.4389666643829262E-8]
+--R     ,
+--R
+--R     [0.81000000000000005, 2.2407799999999999E-2, 2.2407761010586214E-2,
+--R      - 3.8989413784357163E-8]
+--R     ,
+--R
+--R     [0.81999999999999995, 2.2173100000000001E-2, 2.2173068754896382E-2,
+--R      - 3.124510361898758E-8]
+--R     ,
+--R    [0.82999999999999996,2.19408E-2,2.1940841378031716E-2,4.1378031716277075E-8]
+--R     ,
+--R
+--R     [0.83999999999999997, 2.1711100000000001E-2, 2.1711052912871148E-2,
+--R      - 4.708712885229116E-8]
+--R     ,
+--R
+--R     [0.84999999999999998, 2.1483700000000001E-2, 2.1483677666793578E-2,
+--R      - 2.2333206423086338E-8]
+--R     ,
+--R
+--R     [0.85999999999999999, 2.1258699999999998E-2, 2.1258690218764878E-2,
+--R      - 9.7812351204651371E-9]
+--R     ,
+--R    [0.87,2.1036099999999999E-2,2.1036065416455953E-2,- 3.4583544045868608E-8],
+--R    [0.88,2.0815799999999999E-2,2.0815778373391495E-2,- 2.162660850402176E-8],
+--R
+--R     [0.89000000000000001, 2.0597799999999999E-2, 2.0597804466129153E-2,
+--R      4.4661291540015746E-9]
+--R     ,
+--R    [0.90000000000000002,2.03821E-2,2.0382119331468756E-2,1.9331468755628967E-8]
+--R     ,
+--R
+--R     [0.91000000000000003, 2.0168700000000001E-2, 2.0168698863691235E-2,
+--R      - 1.136308765831151E-9]
+--R     ,
+--R    [0.92000000000000004,1.99575E-2,1.9957519211827056E-2,1.9211827056303532E-8]
+--R     ,
+--R
+--R     [0.93000000000000005, 1.9748600000000002E-2, 1.9748556776953658E-2,
+--R      - 4.3223046343465743E-8]
+--R     ,
+--R
+--R     [0.93999999999999995, 1.9541800000000002E-2, 1.9541788209521748E-2,
+--R      - 1.1790478253448367E-8]
+--R     ,
+--R
+--R     [0.94999999999999996, 1.9337199999999999E-2, 1.9337190406710072E-2,
+--R      - 9.5932899263351246E-9]
+--R     ,
+--R
+--R     [0.95999999999999996, 1.9134700000000001E-2, 1.9134740509808349E-2,
+--R      4.0509808348077048E-8]
+--R     ,
+--R
+--R     [0.96999999999999997, 1.8934400000000001E-2, 1.8934415901628112E-2,
+--R      1.5901628111492094E-8]
+--R     ,
+--R
+--R     [0.97999999999999998, 1.8736200000000001E-2, 1.8736194203941098E-2,
+--R      - 5.7960589036620824E-9]
+--R     ,
+--R
+--R     [0.98999999999999999, 1.85401E-2, 1.8540053274944939E-2,
+--R      - 4.6725055061203058E-8]
+--R     ,
+--R    [1.,1.8346000000000001E-2,1.8345971206755872E-2,- 2.8793244129243778E-8],
+--R    [1.01,1.8153900000000001E-2,1.8153926322928098E-2,2.6322928097649578E-8],
+--R    [1.02,1.7963900000000001E-2,1.7963897175999596E-2,- 2.8240004050494871E-9],
+--R    [1.03,1.7775900000000001E-2,1.7775862545064098E-2,- 3.745493590279203E-8],
+--R    [1.04,1.7589799999999999E-2,1.7589801433368843E-2,1.433368843756222E-9],
+--R    [1.05,1.74057E-2,1.7405693065937998E-2,- 6.9340620016677956E-9],
+--R
+--R     [1.0600000000000001, 1.7223499999999999E-2, 1.7223516887221315E-2,
+--R      1.6887221315764478E-8]
+--R     ,
+--R
+--R     [1.0700000000000001, 1.7043300000000001E-2, 1.7043252558767878E-2,
+--R      - 4.744123212330198E-8]
+--R     ,
+--R
+--R     [1.0800000000000001, 1.6864899999999999E-2, 1.6864879956924574E-2,
+--R      - 2.0043075425052459E-8]
+--R     ,
+--R
+--R     [1.0900000000000001, 1.6688399999999999E-2, 1.6688379170559084E-2,
+--R      - 2.082944091513772E-8]
+--R     ,
+--R
+--R     [1.1000000000000001, 1.6513699999999999E-2, 1.6513730498807128E-2,
+--R      3.0498807129103467E-8]
+--R     ,
+--R
+--R     [1.1100000000000001, 1.6340899999999998E-2, 1.6340914448843669E-2,
+--R      1.4448843670133993E-8]
+--R     ,
+--R
+--R     [1.1200000000000001, 1.6169900000000001E-2, 1.6169911733677846E-2,
+--R      1.1733677845321422E-8]
+--R     ,
+--R    [1.1299999999999999,1.60007E-2,1.6000703269971401E-2,3.269971401292926E-9],
+--R
+--R     [1.1399999999999999, 1.5833300000000002E-2, 1.5833270175880269E-2,
+--R      - 2.9824119732874133E-8]
+--R     ,
+--R    [1.1499999999999999,1.56676E-2,1.566759376891921E-2,- 6.2310807902310472E-9]
+--R     ,
+--R
+--R     [1.1599999999999999, 1.55037E-2, 1.5503655563849129E-2,
+--R      - 4.4436150871754454E-8]
+--R     ,
+--R    [1.1699999999999999,1.53414E-2,1.5341437270586872E-2,3.7270586871959721E-8],
+--R
+--R     [1.1799999999999999, 1.5180900000000001E-2, 1.5180920792137275E-2,
+--R      2.079213727405882E-8]
+--R     ,
+--R
+--R     [1.1899999999999999, 1.50221E-2, 1.5022088222547223E-2,
+--R      - 1.1777452776917663E-8]
+--R     ,
+--R    [1.2,1.48649E-2,1.4864921844881475E-2,2.1844881474900046E-8],
+--R    [1.21,1.4709399999999999E-2,1.4709404129220015E-2,4.129220016260704E-9],
+--R    [1.22,1.4555500000000001E-2,1.4555517730676726E-2,1.7730676725447037E-8],
+--R    [1.23,1.44032E-2,1.4403245487439129E-2,4.5487439129590634E-8],
+--R    [1.24,1.4252600000000001E-2,1.4252570418828979E-2,- 2.9581171021378361E-8],
+--R    [1.25,1.41035E-2,1.4103475723383493E-2,- 2.427661650698798E-8],
+--R    [1.26,1.39559E-2,1.395594477695699E-2,4.4776956989456274E-8],
+--R    [1.27,1.3809999999999999E-2,1.3809961130842716E-2,- 3.8869157283419331E-8],
+--R    [1.28,1.3665500000000001E-2,1.3665508509914652E-2,8.5099146514278079E-9],
+--R    [1.29,1.3522599999999999E-2,1.3522570810789076E-2,- 2.9189210923319386E-8],
+--R    [1.3,1.33811E-2,1.338113210000569E-2,3.2100005689997269E-8],
+--R
+--R     [1.3100000000000001, 1.32412E-2, 1.3241176612228069E-2,
+--R      - 2.3387771930921675E-8]
+--R     ,
+--R    [1.3200000000000001,1.31027E-2,1.3102688748463267E-2,- 1.125153673356416E-8]
+--R     ,
+--R
+--R     [1.3300000000000001, 1.29657E-2, 1.2965653074300341E-2,
+--R      - 4.6925699659361442E-8]
+--R     ,
+--R
+--R     [1.3400000000000001, 1.2830100000000001E-2, 1.2830054318167606E-2,
+--R      - 4.5681832394964261E-8]
+--R     ,
+--R    [1.3500000000000001,1.26959E-2,1.2695877369608423E-2,- 2.263039157630875E-8]
+--R     ,
+--R
+--R     [1.3600000000000001, 1.2563100000000001E-2, 1.2563107277575319E-2,
+--R      7.2775753184178837E-9]
+--R     ,
+--R    [1.3700000000000001,1.24317E-2,1.2431729248742227E-2,2.9248742226817281E-8],
+--R    [1.3799999999999999,1.23017E-2,1.2301728645834703E-2,2.8645834702564765E-8],
+--R
+--R     [1.3899999999999999, 1.2173099999999999E-2, 1.2173090985977835E-2,
+--R      - 9.0140221641055174E-9]
+--R     ,
+--R
+--R     [1.3999999999999999, 1.2045800000000001E-2, 1.2045801939061785E-2,
+--R      1.9390617844033953E-9]
+--R     ,
+--R
+--R     [1.4099999999999999, 1.1919799999999999E-2, 1.1919847326124635E-2,
+--R      4.7326124635524436E-8]
+--R     ,
+--R    [1.4199999999999999,1.17952E-2,1.1795213117752473E-2,1.3117752472799338E-8],
+--R
+--R     [1.4299999999999999, 1.1671900000000001E-2, 1.1671885432496448E-2,
+--R      - 1.4567503552401218E-8]
+--R     ,
+--R
+--R     [1.4399999999999999, 1.15499E-2, 1.1549850535306669E-2,
+--R      - 4.9464693330919518E-8]
+--R     ,
+--R    [1.45,1.1429099999999999E-2,1.1429094835982728E-2,- 5.1640172710892829E-9],
+--R    [1.46,1.13096E-2,1.1309604887640717E-2,4.8876407175019176E-9],
+--R    [1.47,1.1191400000000001E-2,1.1191367385196493E-2,- 3.2614803507219348E-8],
+--R    [1.48,1.10744E-2,1.1074369163865097E-2,- 3.0836134902456624E-8],
+--R    [1.49,1.0958600000000001E-2,1.0958597197676098E-2,- 2.8023239024427271E-9],
+--R    [1.5,1.0843999999999999E-2,1.0844038598004712E-2,3.8598004712536715E-8],
+--R    [1.51,1.0730699999999999E-2,1.0730680612118525E-2,- 1.9387881473875712E-8],
+--R    [1.52,1.0618499999999999E-2,1.0618510621739656E-2,1.062173965622748E-8],
+--R    [1.53,1.0507499999999999E-2,1.05075161416222E-2,1.6141622200330219E-8],
+--R    [1.54,1.0397699999999999E-2,1.0397684818144773E-2,- 1.5181855226101271E-8],
+--R    [1.55,1.0289E-2,1.0289004427918007E-2,4.4279180079487279E-9],
+--R
+--R     [1.5600000000000001, 1.01815E-2, 1.0181462876406836E-2,
+--R      - 3.7123593163088109E-8]
+--R     ,
+--R
+--R     [1.5700000000000001, 1.0075000000000001E-2, 1.0075048196567427E-2,
+--R      4.8196567426286863E-8]
+--R     ,
+--R
+--R     [1.5800000000000001, 9.9696999999999997E-3, 9.9697485474985574E-3,
+--R      4.8547498557663382E-8]
+--R     ,
+--R
+--R     [1.5900000000000001, 9.8656000000000004E-3, 9.8655522131073474E-3,
+--R      - 4.7786892653015056E-8]
+--R     ,
+--R
+--R     [1.6000000000000001, 9.7623999999999992E-3, 9.7624476007891394E-3,
+--R      4.7600789140206379E-8]
+--R     ,
+--R
+--R     [1.6100000000000001, 9.6603999999999995E-3, 9.660423240121405E-3,
+--R      2.3240121405435077E-8]
+--R     ,
+--R
+--R     [1.6200000000000001, 9.5595000000000003E-3, 9.5594677815715092E-3,
+--R      - 3.2218428491076478E-8]
+--R     ,
+--R
+--R     [1.6299999999999999, 9.4596000000000003E-3, 9.4595699952182213E-3,
+--R      - 3.0004781778961154E-8]
+--R     ,
+--R
+--R     [1.6399999999999999, 9.3606999999999996E-3, 9.3607187694867526E-3,
+--R      1.8769486753028586E-8]
+--R     ,
+--R
+--R     [1.6499999999999999, 9.2628999999999993E-3, 9.2629031098972782E-3,
+--R      3.1098972789328494E-9]
+--R     ,
+--R
+--R     [1.6599999999999999, 9.1660999999999999E-3, 9.1661121378267089E-3,
+--R      1.2137826709002209E-8]
+--R     ,
+--R
+--R     [1.6699999999999999, 9.0702999999999999E-3, 9.0703350892836175E-3,
+--R      3.5089283617617539E-8]
+--R     ,
+--R
+--R     [1.6799999999999999, 8.9756000000000002E-3, 8.9755613136961645E-3,
+--R      - 3.8686303835758218E-8]
+--R     ,
+--R
+--R     [1.6899999999999999, 8.8818000000000005E-3, 8.8817802727129049E-3,
+--R      - 1.9727287095538948E-8]
+--R     ,
+--R    [1.7,8.7889999999999999E-3,8.7889815390163051E-3,- 1.8460983694859601E-8],
+--R    [1.71,8.6972000000000004E-3,8.6971547951488551E-3,- 4.5204851145327907E-8],
+--R    [1.72,8.6063000000000008E-3,8.6062898323516594E-3,- 1.0167648341330437E-8],
+--R    [1.73,8.5164000000000004E-3,8.5163765494153266E-3,- 2.345058467377592E-8],
+--R    [1.74,8.4273999999999998E-3,8.4274049515430643E-3,4.9515430644575531E-9],
+--R    [1.75,8.3394000000000003E-3,8.3393651492258501E-3,- 3.4850774150232966E-8],
+--R    [1.76,8.2521999999999995E-3,8.2522473571295107E-3,4.7357129511274576E-8],
+--R    [1.77,8.1659999999999996E-3,8.1660418929936432E-3,4.1892993643544152E-8],
+--R    [1.78,8.0806999999999997E-3,8.0807391765421923E-3,3.9176542192612129E-8],
+--R    [1.79,7.9962999999999996E-3,7.9963297284055979E-3,2.9728405598339336E-8],
+--R    [1.8,7.9127999999999993E-3,7.9128041690543771E-3,4.1690543777644917E-9],
+--R
+--R     [1.8100000000000001, 7.8302000000000007E-3, 7.8301532177440097E-3,
+--R      - 4.6782255990959754E-8]
+--R     ,
+--R
+--R     [1.8200000000000001, 7.7483999999999999E-3, 7.7483676914710427E-3,
+--R      - 3.2308528957226967E-8]
+--R     ,
+--R
+--R     [1.8300000000000001, 7.6674000000000004E-3, 7.6674385039402267E-3,
+--R      3.8503940226301825E-8]
+--R     ,
+--R
+--R     [1.8400000000000001, 7.5874000000000002E-3, 7.5873566645426526E-3,
+--R      - 4.3335457347581929E-8]
+--R     ,
+--R
+--R     [1.8500000000000001, 7.5081000000000002E-3, 7.50811327734469E-3,
+--R      1.327734468984515E-8]
+--R     ,
+--R    [1.8600000000000001,7.4297E-3,7.429699540087673E-3,- 4.5991232697217832E-10]
+--R     ,
+--R
+--R     [1.8700000000000001, 7.3521000000000003E-3, 7.3521067431981824E-3,
+--R      6.743198182126986E-9]
+--R     ,
+--R
+--R     [1.8799999999999999, 7.2753000000000002E-3, 7.2753262688088375E-3,
+--R      2.6268808837361102E-8]
+--R     ,
+--R
+--R     [1.8899999999999999, 7.1992999999999996E-3, 7.1993495897894446E-3,
+--R      4.9589789444942634E-8]
+--R     ,
+--R
+--R     [1.8999999999999999, 7.1241999999999998E-3, 7.1241682687884587E-3,
+--R      - 3.1731211541131954E-8]
+--R     ,
+--R
+--R     [1.9099999999999999, 7.0498000000000002E-3, 7.049773957284575E-3,
+--R      - 2.6042715425139695E-8]
+--R     ,
+--R
+--R     [1.9199999999999999, 6.9762000000000001E-3, 6.9761583946483935E-3,
+--R      - 4.1605351606618934E-8]
+--R     ,
+--R
+--R     [1.9299999999999999, 6.9033000000000002E-3, 6.9033134072140311E-3,
+--R      1.3407214030820847E-8]
+--R     ,
+--R
+--R     [1.9399999999999999, 6.8311999999999999E-3, 6.8312309073605745E-3,
+--R      3.0907360574518317E-8]
+--R     ,
+--R    [1.95,6.7599000000000001E-3,6.759902892603269E-3,2.8926032688905701E-9],
+--R    [1.96,6.6892999999999996E-3,6.6893214446943419E-3,2.1444694342336035E-8],
+--R    [1.97,6.6195000000000004E-3,6.6194787287333721E-3,- 2.1271266628306029E-8],
+--R    [1.98,6.5503999999999996E-3,6.5503669922870687E-3,- 3.3007712930965827E-8],
+--R    [1.99,6.4819999999999999E-3,6.4819785645183897E-3,- 2.1435481610196372E-8],
+--R    [2.,6.4143000000000004E-3,6.4143058553248998E-3,5.8553248994189233E-9]]
+--R                               Type: List List OnePointCompletion DoubleFloat
+--E 7
+)spool 
+)lisp (bye)
+ 
+@
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} Abramowitz and Stegun,``Handbook of Mathematical Functions'',
+Dover Publications, Inc. New York 1965. pp245-248
+\end{thebibliography}
+\end{document}
+
